@@ -10,6 +10,7 @@
 #include <map>
 #include <set>
 #include <vector>
+#include "util/item_set.hpp"
 
 namespace horizon {
 using json = nlohmann::json;
@@ -79,6 +80,8 @@ public:
 
     std::string get_net_name(const UUID &uu) const;
 
+    ItemSet get_pool_items_used() const;
+
     json serialize();
 
 private:
