@@ -1,13 +1,12 @@
 #pragma once
 #include "nlohmann/json_fwd.hpp"
 #include "util/uuid.hpp"
-#include "util/uuid_provider.hpp"
 #include <stdint.h>
 
 namespace horizon {
 using json = nlohmann::json;
 
-class NetClass : public UUIDProvider {
+class NetClass {
 public:
     NetClass(const UUID &uu, const json &j);
     NetClass(const UUID &uu);
