@@ -9,6 +9,8 @@
 #include "nlohmann/json.hpp"
 #include "pool/ipool.hpp"
 #include "pool/pool_cached.hpp"
+#include "common/junction_util.hpp"
+#include "util/bbox_accumulator.hpp"
 
 namespace horizon {
 
@@ -32,7 +34,12 @@ BoardColors::BoardColors() : solder_mask({0, .5, 0}), substrate({.2, .15, 0})
 {
 }
 
-static const unsigned int app_version = 0;
+static const unsigned int app_version = 2;
+
+unsigned int Board::get_app_version()
+{
+    return app_version;
+}
 
 Board::Board(const UUID &uu, const json &j, Block &iblock, IPool &pool, ViaPadstackProvider &vpp)
     : uuid(uu), block(&iblock), name(j.at("name").get<std::string>()), version(app_version, j),
@@ -205,7 +212,8 @@ Board::Board(const UUID &uu, const json &j, Block &iblock, IPool &pool, ViaPadst
         const json &o = j["decals"];
         for (auto it = o.cbegin(); it != o.cend(); ++it) {
             auto u = UUID(it.key());
-            load_and_log(decals, ObjectType::DECAL, std::forward_as_tuple(u, it.value(), pool), Logger::Domain::BOARD);
+            load_and_log(decals, ObjectType::DECAL, std::forward_as_tuple(u, it.value(), pool, *this),
+                         Logger::Domain::BOARD);
         }
     }
     if (j.count("rules")) {
@@ -322,7 +330,8 @@ Board::Board(const Board &brd, CopyMode copy_mode)
                          std::forward_as_tuple(shallow_copy, it.second));
         }
     }
-    update_refs();
+    if (copy_mode == CopyMode::DEEP)
+        update_refs();
 }
 
 Board::Board(const Board &brd) : Board(brd, CopyMode::DEEP)
@@ -389,6 +398,44 @@ void Board::update_refs()
     }
 }
 
+void Board::update_junction_connections()
+{
+    for (auto &[uu, it] : junctions) {
+        it.clear();
+        it.connected_connection_lines.clear();
+        it.connected_tracks.clear();
+        it.connected_vias.clear();
+        it.has_via = false;
+        it.needs_via = false;
+    }
+    for (auto &[uu, it] : tracks) {
+        for (const auto &it_ft : {it.from, it.to}) {
+            if (it_ft.is_junc()) {
+                auto &ju = *it_ft.junc;
+                ju.connected_tracks.push_back(uu);
+                ju.layer.merge(it.layer);
+                if (ju.layer.is_multilayer())
+                    ju.needs_via = true;
+            }
+        }
+    }
+
+    JunctionUtil::update(lines);
+    JunctionUtil::update(arcs);
+
+    for (auto &[uu, it] : connection_lines) {
+        for (const auto &it_ft : {it.from, it.to}) {
+            if (it_ft.is_junc())
+                it_ft.junc->connected_connection_lines.push_back(uu);
+        }
+    }
+    for (auto &[uu, it] : vias) {
+        it.junction->has_via = true;
+        it.junction->layer = LayerRange(BoardLayers::TOP_COPPER, BoardLayers::BOTTOM_COPPER);
+        it.junction->connected_vias.push_back(uu);
+    }
+}
+
 unsigned int Board::get_n_inner_layers() const
 {
     return n_inner_layers;
@@ -435,8 +482,9 @@ void Board::update_pdf_export_settings(PDFExportSettings &settings)
 {
     auto layers_from_board = get_layers();
     // remove layers not on board
-    map_erase_if(settings.layers,
-                 [&layers_from_board](const auto &it) { return layers_from_board.count(it.first) == 0; });
+    map_erase_if(settings.layers, [&layers_from_board](const auto &it) {
+        return it.first != PDFExportSettings::HOLES_LAYER && layers_from_board.count(it.first) == 0;
+    });
 
     // add new layers
     auto add_layer = [&settings](int l, bool enable = true) {
@@ -445,6 +493,9 @@ void Board::update_pdf_export_settings(PDFExportSettings &settings)
                 std::forward_as_tuple(l, Color(0, 0, 0), PDFExportSettings::Layer::Mode::OUTLINE, enable));
     };
 
+    // add holes layer
+    add_layer(PDFExportSettings::HOLES_LAYER, false);
+
     add_layer(BoardLayers::OUTLINE_NOTES);
     add_layer(BoardLayers::L_OUTLINE);
     add_layer(BoardLayers::TOP_PASTE, false);
@@ -483,6 +534,13 @@ void Board::flip_package_layer(int &layer) const
     }
 }
 
+int Board::get_package_layer(bool flip, int layer) const
+{
+    if (flip)
+        flip_package_layer(layer);
+    return layer;
+}
+
 void Board::propagate_nets()
 {
     // reset
@@ -554,14 +612,11 @@ void Board::propagate_nets()
 
 void Board::vacuum_junctions()
 {
-    for (auto it = junctions.begin(); it != junctions.end();) {
-        if (it->second.connection_count == 0 && it->second.has_via == false) {
-            it = junctions.erase(it);
-        }
-        else {
-            it++;
-        }
-    }
+    map_erase_if(junctions, [this](auto &x) {
+        const BoardJunction &ju = x.second;
+        return (ju.connected_lines.size() == 0) && (ju.connected_arcs.size() == 0) && (ju.connected_tracks.size() == 0)
+               && (ju.connected_vias.size() == 0);
+    });
 }
 
 
@@ -576,7 +631,13 @@ static std::string replace_text_map(const std::string &s, const std::map<std::st
     return replace_placeholders(s, fn, true);
 }
 
-void Board::expand(bool careful)
+void Board::expand()
+{
+    expand_flags = EXPAND_ALL;
+    expand_some();
+}
+
+void Board::expand_some()
 {
     delete_dependants();
     warnings.clear();
@@ -585,50 +646,27 @@ void Board::expand(bool careful)
         it.second.overridden = false;
     }
 
-    expand_packages();
-    expand_decals();
+    if (expand_flags & EXPAND_PACKAGES)
+        expand_packages();
 
-    for (auto &it : junctions) {
-        it.second.layer = 10000;
-        it.second.has_via = false;
-        it.second.needs_via = false;
-        it.second.connection_count = 0;
+    for (auto &[uu, pkg] : packages) {
+        pkg.update_texts(*this);
     }
 
+    update_junction_connections();
+
     for (const auto &it : tracks) {
-        for (const auto &it_ft : {it.second.from, it.second.to}) {
-            if (it_ft.is_junc()) {
-                auto ju = it_ft.junc;
-                ju->connection_count++;
-                ju->layer.merge(it.second.layer);
-                if (ju->layer.is_multilayer())
-                    ju->needs_via = true;
-            }
-        }
+
         if (it.second.from.get_position() == it.second.to.get_position()) {
             warnings.emplace_back(it.second.from.get_position(), "Zero length track");
         }
     }
 
-    for (const auto &it : lines) {
-        it.second.from->connection_count++;
-        it.second.to->connection_count++;
-        for (const auto &ju : {it.second.from, it.second.to}) {
-            ju->layer.merge(it.second.layer);
-        }
-    }
-    for (const auto &it : arcs) {
-        it.second.from->connection_count++;
-        it.second.to->connection_count++;
-        it.second.center->connection_count++;
-        for (const auto &ju : {it.second.from, it.second.to, it.second.center}) {
-            ju->layer.merge(it.second.layer);
-        }
-    }
-
     auto params = rules.get_parameters();
-    for (auto &it : vias) {
-        it.second.expand(*this);
+    if (expand_flags & EXPAND_VIAS) {
+        for (auto &it : vias) {
+            it.second.expand(*this);
+        }
     }
     for (auto &it : holes) {
         it.second.padstack = *it.second.pool_padstack;
@@ -685,38 +723,16 @@ void Board::expand(bool careful)
         }
     }
 
-    if (expand_flags & EXPAND_AIRWIRES)
+    if (expand_flags & EXPAND_ALL_AIRWIRES)
+        update_all_airwires();
+    else if (expand_flags & EXPAND_AIRWIRES)
         update_airwires(false, airwires_expand);
 
-    expand_flags = EXPAND_ALL;
-    packages_expand.clear();
+    expand_flags = EXPAND_NONE;
     airwires_expand.clear();
 }
 
-void Board::expand_decals()
-{
-    for (auto &[uu, dec] : decals) {
-        dec.decal = *dec.pool_decal;
-        dec.placement.mirror = dec.flip;
-        if (dec.flip) {
-            for (auto &it2 : dec.decal.lines) {
-                flip_package_layer(it2.second.layer);
-            }
-            for (auto &it2 : dec.decal.arcs) {
-                flip_package_layer(it2.second.layer);
-            }
-            for (auto &it2 : dec.decal.texts) {
-                flip_package_layer(it2.second.layer);
-            }
-            for (auto &it2 : dec.decal.polygons) {
-                flip_package_layer(it2.second.layer);
-            }
-        }
-        dec.apply_scale();
-    }
-}
-
-void Board::expand_packages()
+ParameterSet Board::get_parameters() const
 {
     auto params = rules.get_parameters();
     ParameterSet pset = {
@@ -724,158 +740,41 @@ void Board::expand_packages()
             {ParameterID::PASTE_MASK_CONTRACTION, params->paste_mask_contraction},
             {ParameterID::SOLDER_MASK_EXPANSION, params->solder_mask_expansion},
             {ParameterID::HOLE_SOLDER_MASK_EXPANSION, params->hole_solder_mask_expansion},
-
     };
+    return pset;
+}
+
+void Board::expand_packages()
+{
+    const auto pset = get_parameters();
 
-    bool expanded_package = false;
     for (auto &it : packages) {
-        it.second.pool_package = it.second.component->part->package;
-        if ((expand_flags & EXPAND_PACKAGES) && (packages_expand.size() == 0 || packages_expand.count(it.first))) {
-            it.second.model = it.second.component->part->get_model();
-            expanded_package = true;
-            if (it.second.alternate_package) {
-                std::set<std::string> pads_from_primary, pads_from_alt;
-                for (const auto &it_pad : it.second.pool_package->pads) {
-                    if (it_pad.second.padstack.type != Padstack::Type::MECHANICAL)
-                        pads_from_primary.insert(it_pad.second.name);
-                }
-                bool alt_valid = true;
-                for (const auto &it_pad : it.second.alternate_package->pads) {
-                    if (it_pad.second.padstack.type != Padstack::Type::MECHANICAL) {
-                        if (!pads_from_alt.insert(it_pad.second.name).second) { // duplicate pad name
-                            alt_valid = false;
-                        }
-                    }
-                }
-                if (!alt_valid || pads_from_alt != pads_from_primary) { // alt pkg isn't pad-equal
-                    it.second.package = *it.second.pool_package;
-                    warnings.emplace_back(it.second.placement.shift, "Incompatible alt pkg");
-                }
-                else {
-                    it.second.package = *it.second.alternate_package;
-
-                    // need to adjust pad uuids to primary package
-                    map_erase_if(it.second.package.pads,
-                                 [](const auto &x) { return x.second.padstack.type != Padstack::Type::MECHANICAL; });
-                    std::map<std::string, UUID> pad_uuids;
-                    for (const auto &it_pad : it.second.pool_package->pads) {
-                        if (it_pad.second.padstack.type != Padstack::Type::MECHANICAL)
-                            assert(pad_uuids.emplace(it_pad.second.name, it_pad.first).second); // no duplicates
-                    }
-                    for (const auto &it_pad : it.second.alternate_package->pads) {
-                        if (it_pad.second.padstack.type != Padstack::Type::MECHANICAL) {
-                            auto uu = pad_uuids.at(it_pad.second.name);
-                            auto &pad = it.second.package.pads.emplace(uu, it_pad.second).first->second;
-                            pad.uuid = uu;
-                        }
-                    }
-
-                    if (it.second.package.models.size() == 1) { // alt pkg only has one model
-                        it.second.model = it.second.package.models.begin()->first;
-                    }
-                }
-            }
-            else {
-                it.second.package = *it.second.pool_package;
-            }
-
-            it.second.placement.mirror = it.second.flip;
-            for (auto &it2 : it.second.package.pads) {
-                it2.second.padstack.expand_inner(n_inner_layers);
-            }
-
-            if (it.second.flip) {
-                for (auto &it2 : it.second.package.lines) {
-                    flip_package_layer(it2.second.layer);
-                }
-                for (auto &it2 : it.second.package.arcs) {
-                    flip_package_layer(it2.second.layer);
-                }
-                for (auto &it2 : it.second.package.texts) {
-                    flip_package_layer(it2.second.layer);
-                }
-                for (auto &it2 : it.second.package.polygons) {
-                    flip_package_layer(it2.second.layer);
-                }
-                for (auto &it2 : it.second.package.pads) {
-                    if (it2.second.padstack.type == Padstack::Type::TOP) {
-                        it2.second.padstack.type = Padstack::Type::BOTTOM;
-                    }
-                    else if (it2.second.padstack.type == Padstack::Type::BOTTOM) {
-                        it2.second.padstack.type = Padstack::Type::TOP;
-                    }
-                    for (auto &it3 : it2.second.padstack.polygons) {
-                        flip_package_layer(it3.second.layer);
-                    }
-                    for (auto &it3 : it2.second.padstack.shapes) {
-                        flip_package_layer(it3.second.layer);
-                    }
-                }
-            }
-        }
-        auto r = it.second.package.apply_parameter_set(pset);
-
-        it.second.texts.erase(std::remove_if(it.second.texts.begin(), it.second.texts.end(),
-                                             [this](const auto &a) { return texts.count(a.uuid) == 0; }),
-                              it.second.texts.end());
-
-        for (auto &it_text : it.second.package.texts) {
-            it_text.second.text = it.second.replace_text(it_text.second.text);
-        }
-        for (auto it_text : it.second.texts) {
-            it_text->text_override = it.second.replace_text(it_text->text, &it_text->overridden);
+        if (it.second.update_package(*this) == false)
+            warnings.emplace_back(it.second.placement.shift, "Incompatible alt pkg");
+        if (auto err = it.second.package.apply_parameter_set(pset)) {
+            Logger::log_critical("Package " + it.second.component->refdes + " parameter program failed",
+                                 Logger::Domain::BOARD, err.value());
         }
     }
 
-    if (expanded_package)
-        update_refs();
+    update_refs();
 
     // assign nets to pads based on netlist
     for (auto &it : packages) {
-        for (auto &it_pad : it.second.package.pads) {
-            it_pad.second.is_nc = false;
-            if (it.second.component->part->pad_map.count(it_pad.first)) {
-                const auto &pad_map_item = it.second.component->part->pad_map.at(it_pad.first);
-                auto pin_path = UUIDPath<2>(pad_map_item.gate->uuid, pad_map_item.pin->uuid);
-                if (it.second.component->connections.count(pin_path)) {
-                    const auto &conn = it.second.component->connections.at(pin_path);
-                    it_pad.second.net = conn.net;
-                    if (conn.net) {
-                        it_pad.second.secondary_text = conn.net->name;
-                    }
-                    else {
-                        it_pad.second.secondary_text = "NC";
-                        it_pad.second.is_nc = true;
-                    }
-                }
-                else {
-                    it_pad.second.net = nullptr;
-                    it_pad.second.secondary_text = "("
-                                                   + it.second.component->part->entity->gates.at(pin_path.at(0))
-                                                             .unit->pins.at(pin_path.at(1))
-                                                             .primary_name
-                                                   + ")";
-                }
-            }
-            else {
-                it_pad.second.net = nullptr;
-                it_pad.second.secondary_text = "NC";
-                it_pad.second.is_nc = true;
-            }
-        }
+        it.second.update_nets();
     }
 }
 
 void Board::disconnect_package(BoardPackage *pkg)
 {
-    std::map<Pad *, Junction *> pad_junctions;
+    std::map<Pad *, BoardJunction *> pad_junctions;
     for (auto &it_track : tracks) {
         Track *tr = &it_track.second;
         // if((line->to_symbol && line->to_symbol->uuid == it.uuid) ||
         // (line->from_symbol &&line->from_symbol->uuid == it.uuid)) {
         for (auto it_ft : {&tr->to, &tr->from}) {
             if (it_ft->package == pkg) {
-                Junction *j = nullptr;
+                BoardJunction *j = nullptr;
                 if (pad_junctions.count(it_ft->pad)) {
                     j = pad_junctions.at(it_ft->pad);
                 }
@@ -886,6 +785,7 @@ void Board::disconnect_package(BoardPackage *pkg)
                 }
                 auto c = it_ft->get_position();
                 j->position = c;
+                j->net = it_ft->pad->net;
                 it_ft->connect(j);
             }
         }
@@ -981,7 +881,7 @@ void Board::smash_package_silkscreen_graphics(BoardPackage *pkg)
     auto tr = pkg->placement;
     if (pkg->flip)
         tr.invert_angle();
-    auto get_junction = [&junction_xlat, this, pkg, tr](Junction *ju) {
+    auto get_junction = [&junction_xlat, this, pkg, tr](Junction *ju) -> Junction * {
         if (junction_xlat.count(ju)) {
             return junction_xlat.at(ju);
         }
@@ -1127,20 +1027,13 @@ std::vector<KeepoutContour> Board::get_keepout_contours() const
 }
 std::pair<Coordi, Coordi> Board::get_bbox() const
 {
-    Coordi a, b;
-    bool found = false;
+    BBoxAccumulator<Coordi::type> acc;
     for (const auto &it : polygons) {
         if (it.second.layer == BoardLayers::L_OUTLINE) { // outline
-            found = true;
-            for (const auto &v : it.second.vertices) {
-                a = Coordi::min(a, v.position);
-                b = Coordi::max(b, v.position);
-            }
+            acc.accumulate(it.second.get_bbox());
         }
     }
-    if (!found)
-        return {{-10_mm, -10_mm}, {10_mm, 10_mm}};
-    return {a, b};
+    return acc.get_or({{-10_mm, -10_mm}, {10_mm, 10_mm}});
 }
 
 std::map<const BoardPackage *, PnPRow> Board::get_PnP(const PnPExportSettings &settings) const
@@ -1280,4 +1173,27 @@ void Board::load_pictures(const std::string &dir)
     pictures_load({&pictures}, dir, "brd");
 }
 
+ItemSet Board::get_pool_items_used() const
+{
+    ItemSet items_needed;
+
+    for (const auto &it_pkg : packages) {
+        // don't use pool_package because of alternate pkg
+        items_needed.emplace(ObjectType::PACKAGE, it_pkg.second.package.uuid);
+        for (const auto &it_pad : it_pkg.second.package.pads) {
+            items_needed.emplace(ObjectType::PADSTACK, it_pad.second.pool_padstack->uuid);
+        }
+    }
+    for (const auto &it_via : vias) {
+        items_needed.emplace(ObjectType::PADSTACK, it_via.second.vpp_padstack->uuid);
+    }
+    for (const auto &it_hole : holes) {
+        items_needed.emplace(ObjectType::PADSTACK, it_hole.second.pool_padstack->uuid);
+    }
+    for (const auto &it_decal : decals) {
+        items_needed.emplace(ObjectType::DECAL, it_decal.second.get_decal().uuid);
+    }
+    return items_needed;
+}
+
 } // namespace horizon
