@@ -6,7 +6,7 @@
 #include "clipper/clipper.hpp"
 #include "common/dimension.hpp"
 #include "common/hole.hpp"
-#include "common/junction.hpp"
+#include "board_junction.hpp"
 #include "common/layer_provider.hpp"
 #include "common/polygon.hpp"
 #include "common/keepout.hpp"
@@ -14,7 +14,6 @@
 #include "fab_output_settings.hpp"
 #include "nlohmann/json_fwd.hpp"
 #include "plane.hpp"
-#include "pool/pool.hpp"
 #include "track.hpp"
 #include "util/uuid.hpp"
 #include "util/warning.hpp"
@@ -27,9 +26,8 @@
 #include "included_board.hpp"
 #include "board_panel.hpp"
 #include "common/picture.hpp"
-#include <fstream>
-#include <map>
-#include <vector>
+#include "board_decal.hpp"
+#include "util/file_version.hpp"
 
 namespace horizon {
 using json = nlohmann::json;
@@ -51,18 +49,20 @@ private:
     void vacuum_junctions();
 
 public:
-    Board(const UUID &uu, const json &, Block &block, Pool &pool, ViaPadstackProvider &vpp);
-    static Board new_from_file(const std::string &filename, Block &block, Pool &pool, ViaPadstackProvider &vpp);
+    Board(const UUID &uu, const json &, Block &block, IPool &pool, ViaPadstackProvider &vpp);
+    static Board new_from_file(const std::string &filename, Block &block, IPool &pool, ViaPadstackProvider &vpp);
     Board(const UUID &uu, Block &block);
+    static unsigned int get_app_version();
 
-    void expand(bool careful = false);
-    void expand_packages();
+    void expand();
+    void expand_some();
 
     Board(const Board &brd);
     Board(shallow_copy_t sh, const Board &brd);
     void operator=(const Board &brd) = delete;
     void update_refs();
-    void update_airwires(bool fast = false, const std::set<UUID> &nets = {});
+    void update_junction_connections();
+    void update_airwires(bool fast, const std::set<UUID> &nets);
     void disconnect_package(BoardPackage *pkg);
 
     void smash_package(BoardPackage *pkg);
@@ -92,7 +92,7 @@ public:
     std::map<UUID, Polygon> polygons;
     std::map<UUID, BoardHole> holes;
     std::map<UUID, BoardPackage> packages;
-    std::map<UUID, Junction> junctions;
+    std::map<UUID, BoardJunction> junctions;
     std::map<UUID, Track> tracks;
     std::map<UUID, Via> vias;
     std::map<UUID, Text> texts;
@@ -105,6 +105,7 @@ public:
     std::map<UUID, IncludedBoard> included_boards;
     std::map<UUID, BoardPanel> board_panels;
     std::map<UUID, Picture> pictures;
+    std::map<UUID, BoardDecal> decals;
 
     std::vector<Warning> warnings;
 
@@ -129,28 +130,50 @@ public:
     STEPExportSettings step_export_settings;
     PnPExportSettings pnp_export_settings;
 
-    ClipperLib::Paths obstacles;
-    ClipperLib::Path track_path;
+    FileVersion version;
 
     enum ExpandFlags {
+        EXPAND_NONE = 0,
         EXPAND_ALL = 0xff,
         EXPAND_PROPAGATE_NETS = (1 << 0),
         EXPAND_AIRWIRES = (1 << 1),
-        EXPAND_PACKAGES = (1 << 2)
+        EXPAND_PACKAGES = (1 << 2),
+        EXPAND_VIAS = (1 << 3),
+        EXPAND_ALL_AIRWIRES = (1 << 4),
     };
 
     ExpandFlags expand_flags = EXPAND_ALL;
-    std::set<UUID> packages_expand;
     std::set<UUID> airwires_expand;
 
     json serialize() const;
     void save_pictures(const std::string &dir) const;
     void load_pictures(const std::string &dir);
 
+    ItemSet get_pool_items_used() const;
+
+    void flip_package_layer(int &layer) const;
+    int get_package_layer(bool flip, int layer) const;
+    ParameterSet get_parameters() const;
+
 private:
     unsigned int n_inner_layers = 0;
     ClipperLib::Paths get_thermals(class Plane *plane, const class CanvasPads *ca) const;
-    void flip_package_layer(int &layer) const;
+    void update_all_airwires();
+    void update_airwire(bool fast, const UUID &net);
+
     Board(const Board &brd, CopyMode copy_mode);
+    void expand_packages();
 };
+
+inline Board::ExpandFlags operator|(Board::ExpandFlags a, Board::ExpandFlags b)
+{
+    return static_cast<Board::ExpandFlags>(static_cast<int>(a) | static_cast<int>(b));
+}
+
+inline Board::ExpandFlags operator|=(Board::ExpandFlags &a, Board::ExpandFlags b)
+{
+    return a = (a | b);
+}
+
+
 } // namespace horizon
