@@ -12,6 +12,7 @@
 #include "rule_preflight_checks.hpp"
 #include "rule_clearance_copper_keepout.hpp"
 #include "rule_layer_pair.hpp"
+#include "rule_clearance_same_net.hpp"
 #include "rules/rules.hpp"
 #include "util/uuid.hpp"
 
@@ -24,17 +25,17 @@ public:
     BoardRules(const BoardRules &other);
     void operator=(const BoardRules &other);
 
-    void load_from_json(const json &j);
-    RulesCheckResult check(RuleID id, const class Board *b, class RulesCheckCache &cache,
+    void load_from_json(const json &j) override;
+    RulesCheckResult check(RuleID id, const class Board &b, class RulesCheckCache &cache,
                            check_status_cb_t status_cb) const;
-    void apply(RuleID id, class Board *b, class ViaPadstackProvider &vpp) const;
-    json serialize() const;
-    std::set<RuleID> get_rule_ids() const;
+    void apply(RuleID id, class Board &b, class ViaPadstackProvider &vpp) const;
+    json serialize() const override;
+    std::set<RuleID> get_rule_ids() const override;
     const Rule *get_rule(RuleID id) const override;
     const Rule *get_rule(RuleID id, const UUID &uu) const override;
     std::map<UUID, const Rule *> get_rules(RuleID id) const override;
-    void remove_rule(RuleID id, const UUID &uu);
-    Rule *add_rule(RuleID id);
+    void remove_rule(RuleID id, const UUID &uu) override;
+    Rule *add_rule(RuleID id) override;
     void cleanup(const class Block *block);
 
     uint64_t get_default_track_width(const class Net *net, int layer) const;
@@ -42,6 +43,7 @@ public:
     const RuleClearanceCopperOther *get_clearance_copper_other(const Net *net, int layer) const;
     const RuleDiffpair *get_diffpair(const NetClass *net_class, int layer) const;
     const RuleClearanceCopperKeepout *get_clearance_copper_keepout(const Net *net, const KeepoutContour *contour) const;
+    const RuleClearanceSameNet *get_clearance_same_net(const Net *net, int layer) const;
     uint64_t get_max_clearance() const;
 
     const RuleParameters *get_parameters() const;
@@ -53,6 +55,14 @@ public:
 
     int get_layer_pair(const Net *net, int layer) const;
 
+    json export_rules(const class RulesExportInfo &export_info, const Board &brd) const;
+    void import_rules(const json &j, const RuleImportMap &import_map) override;
+
+    bool can_export() const override
+    {
+        return true;
+    }
+
 private:
     std::map<UUID, RuleHoleSize> rule_hole_size;
     std::map<UUID, RuleTrackWidth> rule_track_width;
@@ -63,6 +73,7 @@ private:
     std::map<UUID, RuleDiffpair> rule_diffpair;
     std::map<UUID, RuleClearanceCopperKeepout> rule_clearance_copper_keepout;
     std::map<UUID, RuleLayerPair> rule_layer_pair;
+    std::map<UUID, RuleClearanceSameNet> rule_clearance_same_net;
 
     std::vector<const RuleClearanceCopper *> rule_sorted_clearance_copper;
     void update_sorted();
@@ -71,14 +82,18 @@ private:
     RuleParameters rule_parameters;
     RulePreflightChecks rule_preflight_checks;
 
-    RulesCheckResult check_track_width(const class Board *b) const;
-    RulesCheckResult check_hole_size(const class Board *b) const;
-    RulesCheckResult check_clearance_copper(const class Board *b, class RulesCheckCache &cache,
+    RulesCheckResult check_track_width(const class Board &b) const;
+    RulesCheckResult check_hole_size(const class Board &b) const;
+    RulesCheckResult check_clearance_copper(const class Board &b, class RulesCheckCache &cache,
                                             check_status_cb_t status_cb) const;
-    RulesCheckResult check_clearance_copper_non_copper(const class Board *b, class RulesCheckCache &cache,
+    RulesCheckResult check_clearance_copper_non_copper(const class Board &b, class RulesCheckCache &cache,
                                                        check_status_cb_t status_cb) const;
-    RulesCheckResult check_preflight(const class Board *b) const;
-    RulesCheckResult check_clearance_copper_keepout(const class Board *b, class RulesCheckCache &cache,
+    RulesCheckResult check_preflight(const class Board &b) const;
+    RulesCheckResult check_clearance_copper_keepout(const class Board &b, class RulesCheckCache &cache,
                                                     check_status_cb_t status_cb) const;
+    RulesCheckResult check_clearance_same_net(const class Board &b, class RulesCheckCache &cache,
+                                              check_status_cb_t status_cb) const;
+
+    json serialize_or_export(Rule::SerializeMode mode) const;
 };
 } // namespace horizon
