@@ -7,11 +7,12 @@ namespace horizon {
 class RuleClearanceCopper : public Rule {
 public:
     RuleClearanceCopper(const UUID &uu);
-    RuleClearanceCopper(const UUID &uu, const json &j);
+    RuleClearanceCopper(const UUID &uu, const json &j, const RuleImportMap &import_map);
     json serialize() const override;
 
     std::string get_brief(const class Block *block = nullptr) const override;
     bool is_match_all() const override;
+    bool can_export() const override;
 
     RuleMatch match_1;
     RuleMatch match_2;
