@@ -7,10 +7,14 @@ namespace horizon {
 class RuleDiffpair : public Rule {
 public:
     RuleDiffpair(const UUID &uu);
-    RuleDiffpair(const UUID &uu, const json &j);
+    RuleDiffpair(const UUID &uu, const json &j, const RuleImportMap &import_map);
     json serialize() const override;
 
     std::string get_brief(const class Block *block = nullptr) const override;
+    bool can_export() const override
+    {
+        return true;
+    }
 
     UUID net_class;
     int layer = 10000;
