@@ -18,11 +18,12 @@ public:
     };
 
     RuleTrackWidth(const UUID &uu);
-    RuleTrackWidth(const UUID &uu, const json &j);
+    RuleTrackWidth(const UUID &uu, const json &j, const RuleImportMap &import_map);
     json serialize() const override;
 
     std::string get_brief(const class Block *block = nullptr) const override;
     bool is_match_all() const override;
+    bool can_export() const override;
 
     RuleMatch match;
     std::map<int, Widths> widths;
