@@ -11,8 +11,8 @@ RuleVia::RuleVia(const UUID &uu) : Rule(uu)
     parameter_set[ParameterID::HOLE_DIAMETER] = .2_mm;
 }
 
-RuleVia::RuleVia(const UUID &uu, const json &j)
-    : Rule(uu, j), match(j.at("match")), padstack(j.at("padstack").get<std::string>()),
+RuleVia::RuleVia(const UUID &uu, const json &j, const RuleImportMap &import_map)
+    : Rule(uu, j, import_map), match(j.at("match"), import_map), padstack(j.at("padstack").get<std::string>()),
       parameter_set(parameter_set_from_json(j.at("parameter_set")))
 {
     id = RuleID::VIA;
@@ -37,4 +37,9 @@ bool RuleVia::is_match_all() const
     return match.mode == RuleMatch::Mode::ALL;
 }
 
+bool RuleVia::can_export() const
+{
+    return match.can_export();
+}
+
 } // namespace horizon
