@@ -20,5 +20,8 @@ public:
     enum class CursorSize { DEFAULT, LARGE, FULL };
     CursorSize cursor_size = CursorSize::DEFAULT;
     CursorSize cursor_size_tool = CursorSize::LARGE;
+    float min_line_width = 1.5;
+    float min_selectable_size = 20;
+    float snap_radius = 30;
 };
 } // namespace horizon
