@@ -34,10 +34,10 @@ public:
     void update(const class Sheet &sheet);
     void update(const class Padstack &padstack, bool edit = true);
     void update(const class Package &pkg, bool edit = true);
-    void update(const class Buffer &buf, class LayerProvider *lp);
     enum class PanelMode { INCLUDE, SKIP };
     void update(const class Board &brd, PanelMode mode = PanelMode::INCLUDE);
     void update(const class Frame &fr, bool edit = true);
+    void update(const class Decal &dec, bool edit = true);
 
     ObjectRef add_line(const std::deque<Coordi> &pts, int64_t width, ColorP color, int layer);
     void remove_obj(const ObjectRef &r);
@@ -60,6 +60,7 @@ public:
     void set_layer_color(int layer, const Color &color);
 
     bool layer_is_visible(int layer) const;
+    bool layer_is_visible(LayerRange layer) const;
 
     bool show_all_junctions_in_schematic = false;
     bool show_text_in_tracks = false;
@@ -70,6 +71,11 @@ public:
         return false;
     };
 
+    virtual float get_view_angle() const
+    {
+        return 0;
+    }
+
     std::pair<Coordf, Coordf> get_bbox(bool visible_only = true) const;
 
     static const int first_overlay_layer = 30000;
@@ -95,6 +101,7 @@ protected:
 
     void render(const class Symbol &sym, bool on_sheet = false, bool smashed = false, ColorP co = ColorP::FROM_LAYER);
     void render(const class Junction &junc, bool interactive = true, ObjectType mode = ObjectType::INVALID);
+    void render(const class SchematicJunction &junc);
     void render(const class Line &line, bool interactive = true, ColorP co = ColorP::FROM_LAYER);
     void render(const class SymbolPin &pin, bool interactive = true, ColorP co = ColorP::FROM_LAYER);
     void render(const class Arc &arc, bool interactive = true, ColorP co = ColorP::FROM_LAYER);
@@ -115,7 +122,6 @@ protected:
                 bool omit_silkscreen = false, bool omit_outline = false);
     void render_pad_overlay(const class Pad &pad);
     void render(const class Pad &pad);
-    void render(const class Buffer &buf);
     enum class OutlineMode { INCLUDE, OMIT };
     void render(const class Board &brd, bool interactive = true, PanelMode mode = PanelMode::INCLUDE,
                 OutlineMode outline_mode = OutlineMode::INCLUDE);
@@ -128,6 +134,8 @@ protected:
     void render(const class ConnectionLine &line);
     void render(const class BoardPanel &panel);
     void render(const class Picture &pic);
+    void render(const class Decal &decal, bool interactive = true);
+    void render(const class BoardDecal &decal);
 
     bool needs_push = true;
     virtual void request_push() = 0;
@@ -144,10 +152,12 @@ protected:
     void draw_box(const Coord<float> &o, float size, ColorP color = ColorP::FROM_LAYER, int layer = 10000,
                   bool tr = true, uint64_t width = 0);
     void draw_arc(const Coord<float> &center, float radius, float a0, float a1, ColorP color = ColorP::FROM_LAYER,
-                  int layer = 10000, bool tr = true, uint64_t width = 0);
-    std::pair<Coordf, Coordf> draw_arc2(const Coord<float> &center, float radius0, float a0, float radius1, float a1,
-                                        ColorP color = ColorP::FROM_LAYER, int layer = 10000, bool tr = true,
-                                        uint64_t width = 0);
+                  int layer = 10000);
+    void draw_circle(const Coord<float> &center, float radius, ColorP color = ColorP::FROM_LAYER, int layer = 10000);
+    std::pair<Coordf, Coordf> draw_arc2(const Coord<float> &center, float radius0, float a0, float a1, ColorP color,
+                                        int layer, uint64_t width);
+    void draw_arc0(const Coord<float> &center, float radius0, float a0, float a1, ColorP color, int layer,
+                   uint64_t width);
     std::pair<Coordf, Coordf> draw_text0(const Coordf &p, float size, const std::string &rtext, int angle, bool flip,
                                          TextOrigin origin, ColorP color, int layer = 10000, uint64_t width = 0,
                                          bool draw = true, TextData::Font font = TextData::Font::SIMPLEX,
@@ -176,6 +186,10 @@ protected:
     void draw_lock(const Coordf &center, float size, ColorP color = ColorP::FROM_LAYER, int layer = 10000,
                    bool tr = true);
 
+    virtual bool img_layer_is_visible(int layer) const
+    {
+        return true;
+    }
     virtual void img_net(const class Net *net)
     {
     }
@@ -195,9 +209,6 @@ protected:
     virtual void img_patch_type(PatchType type)
     {
     }
-    virtual void img_text(const Text &txt, std::pair<Coordf, Coordf> &extents)
-    {
-    }
     virtual void img_draw_text(const Coordf &p, float size, const std::string &rtext, int angle, bool flip,
                                TextOrigin origin, int layer = 10000, uint64_t width = 0,
                                TextData::Font font = TextData::Font::SIMPLEX, bool center = false, bool mirror = false)
@@ -225,9 +236,9 @@ protected:
 
     TriangleInfo::Type triangle_type_current = TriangleInfo::Type::NONE;
 
-    std::map<std::pair<int, bool>, int> overlay_layers; // layer, ignore_flip -> overlay layer
+    std::map<std::pair<LayerRange, bool>, int> overlay_layers; // layer, ignore_flip -> overlay layer
     int overlay_layer_current = first_overlay_layer;
-    int get_overlay_layer(int layer, bool ignore_flip = false);
+    int get_overlay_layer(const LayerRange &layer, bool ignore_flip = false);
     bool is_overlay_layer(int overlay_layer, int layer) const;
 
     FragmentCache fragment_cache;
