@@ -4,6 +4,7 @@
 #include "common/layer_provider.hpp"
 #include "common/object_descr.hpp"
 #include "gl_util.hpp"
+#include "util/util.hpp"
 #include <glm/gtc/type_ptr.hpp>
 
 namespace horizon {
@@ -124,6 +125,8 @@ void DragSelection::Box::render()
 
 void DragSelection::Line::render()
 {
+    if (n_vertices < 2)
+        return;
     glUseProgram(program);
     glBindVertexArray(vao);
     glUniformMatrix3fv(screenmat_loc, 1, GL_FALSE, glm::value_ptr(ca.screenmat));
@@ -133,7 +136,7 @@ void DragSelection::Line::render()
     gl_color_to_uniform_3f(color_loc, co);
 
 
-    glDrawArrays(GL_LINE_STRIP, 0, vertices.size());
+    glDrawArrays(GL_LINE_STRIP, 0, n_vertices);
 
     glBindVertexArray(0);
     glUseProgram(0);
@@ -141,17 +144,21 @@ void DragSelection::Line::render()
 
 void DragSelection::Line::push()
 {
-    if (!vertices.size())
+    if (vertices.size() < 2) {
+        n_vertices = 0; // prevent rendering stale data
         return;
+    }
     glBindBuffer(GL_ARRAY_BUFFER, vbo);
-    auto n_vertices = vertices.size();
+    n_vertices = vertices.size();
     if (ca.selection_tool == CanvasGL::SelectionTool::PAINT) {
         glBufferData(GL_ARRAY_BUFFER, sizeof(Vertex) * n_vertices, vertices.data(), GL_STREAM_DRAW);
     }
     else {
         n_vertices += 1;
         glBufferData(GL_ARRAY_BUFFER, sizeof(Vertex) * n_vertices, nullptr, GL_STREAM_DRAW);
+        // buffer last vertex first to close lasso
         glBufferSubData(GL_ARRAY_BUFFER, 0, sizeof(Vertex), vertices.data() + (vertices.size() - 1));
+        // buffer all vertices
         glBufferSubData(GL_ARRAY_BUFFER, sizeof(Vertex), vertices.size() * sizeof(Vertex), vertices.data());
     }
     glBindBuffer(GL_ARRAY_BUFFER, 0);
@@ -204,6 +211,7 @@ void DragSelection::drag_begin(GdkEventButton *button_event)
             line.vertices.emplace_back(c.x, c.y);
             line.path.clear();
             line.path.emplace_back(c.x, c.y);
+            line.update();
         }
         ca.queue_draw();
     }
@@ -242,8 +250,6 @@ void DragSelection::drag_move(GdkEventMotion *motion_event)
             line.vertices.emplace_back(c.x, c.y);
             line.path.emplace_back(c.x, c.y);
             line.update();
-            ca.request_push(CanvasGL::PF_DRAG_SELECTION);
-            ca.request_push(CanvasGL::PF_SELECTABLES);
         }
         ca.queue_draw();
     }
@@ -276,9 +282,12 @@ void DragSelection::drag_end(GdkEventButton *button_event)
             std::cout << "click select" << std::endl;
             if (ca.selection_mode == CanvasGL::SelectionMode::HOVER) { // just select what was
                                                                        // selecte by hover select
-                ca.set_selection_mode(CanvasGL::SelectionMode::NORMAL);
-                ca.selectables.update_preview(ca.get_selection());
-                ca.s_signal_selection_changed.emit();
+                auto sel = ca.get_selection();
+                if (sel.size()) {
+                    ca.set_selection_mode(CanvasGL::SelectionMode::NORMAL);
+                    ca.selectables.update_preview(sel);
+                    ca.s_signal_selection_changed.emit();
+                }
             }
             else {
                 std::set<SelectableRef> selection;
@@ -298,15 +307,7 @@ void DragSelection::drag_end(GdkEventButton *button_event)
                         ca.clarify_menu->remove(*it);
                     }
                     for (const auto sr : sel_from_canvas) {
-                        std::string text = object_descriptions.at(sr.type).name;
-                        auto display_name = ca.s_signal_request_display_name.emit(sr.type, sr.uuid);
-                        if (display_name.size()) {
-                            text += " " + display_name;
-                        }
-                        auto layers = ca.layer_provider->get_layers();
-                        if (layers.count(sr.layer)) {
-                            text += " (" + layers.at(sr.layer).name + ")";
-                        }
+                        auto text = ca.s_signal_request_display_name.emit(sr);
                         Gtk::MenuItem *la = nullptr;
                         if (toggle) {
                             auto l = Gtk::manage(new Gtk::CheckMenuItem(text));
@@ -330,9 +331,6 @@ void DragSelection::drag_end(GdkEventButton *button_event)
                             else {
                                 ca.set_selection({sr}, false);
                             }
-#ifdef G_OS_WIN32 // work around a bug(?) in intel(?) GPU drivers on windows
-                            Glib::signal_idle().connect_once([this] { ca.queue_draw(); });
-#endif
                         });
                         la->signal_deselect().connect([this, selection, toggle] {
                             if (toggle) {
@@ -341,9 +339,6 @@ void DragSelection::drag_end(GdkEventButton *button_event)
                             else {
                                 ca.set_selection({}, false);
                             }
-#ifdef G_OS_WIN32 // work around a bug(?) in intel(?) GPU drivers on windows
-                            Glib::signal_idle().connect_once([this] { ca.queue_draw(); });
-#endif
                         });
                         la->signal_activate().connect([this, sr, selection, toggle] {
                             auto sel = selection;
@@ -398,35 +393,59 @@ void DragSelection::drag_end(GdkEventButton *button_event)
     }
 }
 
+static ClipperLib::IntPoint to_pt(const Coordf &p)
+{
+    return ClipperLib::IntPoint(p.x, p.y);
+}
+
 void DragSelection::Box::update()
 {
-    float xmin = std::min(sel_a.x, sel_b.x);
-    float xmax = std::max(sel_a.x, sel_b.x);
-    float ymin = std::min(sel_a.y, sel_b.y);
-    float ymax = std::max(sel_a.y, sel_b.y);
+    const auto sel_center = (sel_a + sel_b) / 2;
+    const auto sel_a_screen = ca.canvas2screen(sel_a);
+    const auto sel_b_screen = ca.canvas2screen(sel_b);
+    const auto sel_width = std::abs(sel_b_screen.x - sel_a_screen.x) / ca.scale;
+    const auto sel_height = std::abs(sel_b_screen.y - sel_a_screen.y) / ca.scale;
+    const auto sel_angle = (ca.flip_view ? -1 : 1) * ca.view_angle;
+    auto in_box = [sel_center, sel_width, sel_height, sel_angle](Coordf p) {
+        p -= sel_center;
+        p = p.rotate(sel_angle);
+        return std::abs(p.x) < sel_width / 2 && std::abs(p.y) < sel_height / 2;
+    };
+    auto sq = ca.selection_qualifier;
+
+    if (sq == CanvasGL::SelectionQualifier::AUTO) {
+        if (sel_a_screen.x < sel_b_screen.x)
+            sq = CanvasGL::SelectionQualifier::INCLUDE_BOX;
+        else
+            sq = CanvasGL::SelectionQualifier::TOUCH_BOX;
+    }
+
+    ClipperLib::Path clbox(4);
+    if (sq == CanvasGL::SelectionQualifier::TOUCH_BOX) {
+        const auto sz1 = Coordf(sel_width / 2, sel_height / 2).rotate(-sel_angle);
+        const auto sz2 = Coordf(sel_width / 2, sel_height / -2).rotate(-sel_angle);
+        clbox.at(0) = to_pt(sel_center + sz1);
+        clbox.at(1) = to_pt(sel_center + sz2);
+        clbox.at(2) = to_pt(sel_center - sz1);
+        clbox.at(3) = to_pt(sel_center - sz2);
+    }
+
     unsigned int i = 0;
     for (auto &it : ca.selectables.items) {
         it.set_flag(Selectable::Flag::PRELIGHT, false);
         if (ca.selection_filter.can_select(ca.selectables.items_ref[i])) {
-            auto sq = ca.selection_qualifier;
 
-            if (sq == CanvasGL::SelectionQualifier::AUTO) {
-                if (sel_a.x < sel_b.x)
-                    sq = CanvasGL::SelectionQualifier::INCLUDE_BOX;
-                else
-                    sq = CanvasGL::SelectionQualifier::TOUCH_BOX;
-            }
 
             if (sq == CanvasGL::SelectionQualifier::INCLUDE_ORIGIN) {
-                if (it.x > xmin && it.x < xmax && it.y > ymin && it.y < ymax) {
+                if (in_box({it.x, it.y})) {
                     it.set_flag(Selectable::Flag::PRELIGHT, true);
                 }
                 fill = true;
             }
             else if (sq == CanvasGL::SelectionQualifier::INCLUDE_BOX) {
                 auto corners = it.get_corners();
-                if (std::all_of(corners.begin(), corners.end(), [xmin, xmax, ymin, ymax](const auto &a) {
-                        return a.x > xmin && a.x < xmax && a.y > ymin && a.y < ymax;
+                if (std::all_of(corners.begin(), corners.end(), [in_box](const auto &a) {
+                        return in_box({a.x, a.y});
                     })) {
                     it.set_flag(Selectable::Flag::PRELIGHT, true);
                 }
@@ -434,12 +453,6 @@ void DragSelection::Box::update()
             }
             else if (sq == CanvasGL::SelectionQualifier::TOUCH_BOX) {
                 // possible optimisation: don't use clipper
-                ClipperLib::Path clbox(4);
-                clbox.at(0) = ClipperLib::IntPoint(xmin, ymin);
-                clbox.at(1) = ClipperLib::IntPoint(xmin, ymax);
-                clbox.at(2) = ClipperLib::IntPoint(xmax, ymax);
-                clbox.at(3) = ClipperLib::IntPoint(xmax, ymin);
-
                 ClipperLib::Path sel(4);
                 auto corners = it.get_corners();
                 for (size_t j = 0; j < 4; j++) {
