@@ -5,7 +5,6 @@
 #include "common/hole.hpp"
 #include "common/polygon.hpp"
 #include "common/text.hpp"
-#include "core/buffer.hpp"
 #include "layer_display.hpp"
 #include "package/pad.hpp"
 #include "poly2tri/poly2tri.h"
@@ -20,6 +19,7 @@
 #include "schematic/power_symbol.hpp"
 #include "schematic/sheet.hpp"
 #include "frame/frame.hpp"
+#include "pool/decal.hpp"
 #include "selectables.hpp"
 #include "selection_filter.hpp"
 #include "target.hpp"
@@ -27,6 +27,7 @@
 #include "util/util.hpp"
 #include "board/board_panel.hpp"
 #include "common/picture.hpp"
+#include "util/polygon_arc_removal_proxy.hpp"
 #include <algorithm>
 #include <ctime>
 #include <sstream>
@@ -34,6 +35,26 @@
 namespace horizon {
 
 void Canvas::render(const Junction &junc, bool interactive, ObjectType mode)
+{
+    ColorP c = ColorP::JUNCTION;
+    bool draw = true;
+
+    if (mode == ObjectType::BOARD)
+        draw = false;
+
+    object_ref_push(ObjectType::JUNCTION, junc.uuid);
+    if (draw) {
+        draw_cross(junc.position, 0.25_mm, c);
+    }
+    object_ref_pop();
+
+    if (interactive) {
+        selectables.append(junc.uuid, ObjectType::JUNCTION, junc.position, 0, junc.layer);
+        targets.emplace_back(junc.uuid, ObjectType::JUNCTION, transform.transform(junc.position), 0, junc.layer);
+    }
+}
+
+void Canvas::render(const SchematicJunction &junc)
 {
     ColorP c = ColorP::JUNCTION;
     if (junc.net) {
@@ -45,39 +66,28 @@ void Canvas::render(const Junction &junc, bool interactive, ObjectType mode)
     if (junc.bus) {
         c = ColorP::BUS;
     }
-    if (junc.warning) {
-        draw_error(junc.position, 2e5, "");
-    }
-    bool draw = true;
-
-    if (mode == ObjectType::BOARD)
-        draw = false;
-
-    auto layer = layer_display.count(junc.layer) ? junc.layer : 10000;
-
     object_ref_push(ObjectType::JUNCTION, junc.uuid);
-    if (draw) {
-        if (junc.connection_count == 2) {
-            if (show_all_junctions_in_schematic)
-                draw_plus(junc.position, 250000, c);
-        }
-        else if (junc.connection_count >= 3 && mode == ObjectType::SCHEMATIC) {
-            draw_line(junc.position, junc.position + Coordi(0, 1000), c, 0, true, 0.75_mm);
-            img_line(junc.position, junc.position + Coordi(0, 1000), 0.75_mm, 0, true);
-        }
-        else if (junc.has_via && mode == ObjectType::SCHEMATIC) {
-            // nop
-        }
-        else {
-            draw_cross(junc.position, 0.25_mm, c);
-        }
+
+    auto connection_count = junc.connected_net_lines.size() + junc.connected_power_symbols.size();
+    if (connection_count == 2) {
+        if (show_all_junctions_in_schematic)
+            draw_plus(junc.position, 250000, c);
+    }
+    else if (connection_count >= 3) {
+        draw_line(junc.position, junc.position + Coordi(0, 1000), c, 0, true, 0.75_mm);
+        img_line(junc.position, junc.position + Coordi(0, 1000), 0.75_mm, 0, true);
+    }
+    else if (junc.connected_bus_labels.size() || junc.connected_bus_rippers.size()
+             || junc.connected_net_labels.size()) {
+        // nop
+    }
+    else {
+        draw_cross(junc.position, 0.25_mm, c);
     }
     object_ref_pop();
 
-    if (interactive) {
-        selectables.append(junc.uuid, ObjectType::JUNCTION, junc.position, 0, layer);
-        targets.emplace_back(junc.uuid, ObjectType::JUNCTION, transform.transform(junc.position), 0, layer);
-    }
+    selectables.append(junc.uuid, ObjectType::JUNCTION, junc.position, 0, junc.layer);
+    targets.emplace_back(junc.uuid, ObjectType::JUNCTION, transform.transform(junc.position), 0, junc.layer);
 }
 
 void Canvas::render(const PowerSymbol &sym)
@@ -137,7 +147,7 @@ void Canvas::render(const PowerSymbol &sym)
         }
         else {
             draw_line({0, 0}, {0, 1_mm}, c, 0);
-            draw_arc({0, 1.75_mm}, 0.75_mm, 0, 2 * M_PI, ColorP::FROM_LAYER, 0, true, 0);
+            draw_circle({0, 1.75_mm}, 0.75_mm, ColorP::FROM_LAYER, 0);
             selectables.append(sym.uuid, ObjectType::POWER_SYMBOL, {0, 0}, {-.75_mm, 2.5_mm}, {.75_mm, 0_mm});
         }
         transform_restore();
@@ -272,8 +282,12 @@ void Canvas::render(const Track &track, bool interactive)
         set_lod_size(width);
         auto vec = (track.from.get_position() - track.to.get_position());
         auto length = sqrt(vec.mag_sq());
-        Placement p(center);
-        p.set_angle_rad(atan2(vec.y, vec.x));
+        Placement p;
+        p.set_angle_rad(get_view_angle());
+        if (get_flip_view())
+            p.invert_angle();
+        p.accumulate(Placement(center));
+        p.set_angle_rad(p.get_angle_rad() + atan2(vec.y, vec.x));
         if (get_flip_view()) {
             p.shift.x *= -1;
             p.invert_angle();
@@ -444,7 +458,7 @@ void Canvas::render(const SymbolPin &pin, bool interactive, ColorP co)
     }
 
     if (pin.decoration.dot) {
-        draw_arc(Coordf(-((int64_t)pin.length) + dot_size / 2, 0), dot_size / 2, 0, 2 * M_PI, c_main, 0, true, 0);
+        draw_circle(Coordf(-((int64_t)pin.length) + dot_size / 2, 0), dot_size / 2, c_main, 0);
     }
     if (pin.decoration.clock) {
         draw_line(Coordf(-(int64_t)pin.length, .375_mm), Coordf(-(int64_t)pin.length - .75_mm, 0), c_main, 0, true, 0);
@@ -586,10 +600,9 @@ void Canvas::render(const Arc &arc, bool interactive, ColorP co)
     Coordf b(arc.to->position);   // ,b,c;
     Coordf c = project_onto_perp_bisector(a, b, arc.center->position);
     float radius0 = sqrt(sq(c.x - a.x) + sq(c.y - a.y));
-    float radius1 = sqrt(sq(c.x - b.x) + sq(c.y - b.y));
     float a0 = atan2f(a.y - c.y, a.x - c.x);
     float a1 = atan2f(b.y - c.y, b.x - c.x);
-    auto bb = draw_arc2(c, radius0, a0, radius1, a1, co, arc.layer, true, arc.width);
+    auto bb = draw_arc2(c, radius0, a0, a1, co, arc.layer, arc.width);
     Coordf t(radius0, radius0);
     if (interactive)
         selectables.append(arc.uuid, ObjectType::ARC, c, bb.first, bb.second, 0, arc.layer);
@@ -637,9 +650,11 @@ void Canvas::render(const Text &text, bool interactive, ColorP co)
 
     img_patch_type(PatchType::TEXT);
     triangle_type_current = TriangleInfo::Type::TEXT;
+    object_ref_push(ObjectType::TEXT, text.uuid);
     auto extents = draw_text0(transform.shift, text.size, text.overridden ? text.text_override : text.text, angle, rev,
                               text.origin, co, text.layer, text.width, true, text.font, false, transform.mirror);
     triangle_type_current = TriangleInfo::Type::NONE;
+    object_ref_pop();
     // img_text_extents(text, extents);
     img_patch_type(PatchType::OTHER);
     transform_restore();
@@ -720,7 +735,7 @@ void Canvas::render(const BusRipper &ripper)
     auto connector_pos = ripper.get_connector_pos();
     img_auto_line = img_mode;
     draw_line(ripper.junction->position, connector_pos, c);
-    if (ripper.connection_count < 1) {
+    if (ripper.connections.size() < 1) {
         draw_box(connector_pos, 0.25_mm, c);
     }
     img_auto_line = false;
@@ -750,12 +765,29 @@ static const Coordf coordf_from_pt(const TPPLPoint &p)
     return Coordf(p.x, p.y);
 }
 
+static bool poly_is_rect(const Polygon &poly)
+{
+    if (poly.vertices.size() != 4)
+        return false;
+    for (size_t i = 0; i < 4; i++) {
+        const auto &p0 = poly.get_vertex(i).position;
+        const auto &p1 = poly.get_vertex(i + 1).position;
+        const auto &p2 = poly.get_vertex(i + 2).position;
+        const auto v0 = p1 - p0;
+        const auto v1 = p2 - p1;
+        if (v0.dot(v1) != 0)
+            return false;
+    }
+    return true;
+}
+
 void Canvas::render(const Polygon &ipoly, bool interactive, ColorP co)
 {
     img_polygon(ipoly);
     if (img_mode)
         return;
-    Polygon poly = ipoly.remove_arcs(64);
+    const PolygonArcRemovalProxy arc_removal_proxy{ipoly, 64};
+    const auto &poly = arc_removal_proxy.get();
     if (poly.vertices.size() == 0)
         return;
 
@@ -763,7 +795,7 @@ void Canvas::render(const Polygon &ipoly, bool interactive, ColorP co)
         return;
     if (auto plane = dynamic_cast<Plane *>(poly.usage.ptr)) {
         triangle_type_current = TriangleInfo::Type::PLANE_FILL;
-        auto tris = fragment_cache.get_triangles(*plane);
+        const auto &tris = fragment_cache.get_triangles(*plane);
         object_ref_push(ObjectType::PLANE, plane->uuid);
         begin_group(poly.layer);
         for (const auto &tri : tris) {
@@ -796,32 +828,41 @@ void Canvas::render(const Polygon &ipoly, bool interactive, ColorP co)
     }
     else { // normal polygon
         triangle_type_current = TriangleInfo::Type::POLYGON;
-        TPPLPoly po;
-        po.Init(poly.vertices.size());
-        po.SetHole(false);
-        {
-            size_t i = 0;
-            for (auto &it : poly.vertices) {
-                po[i].x = it.position.x;
-                po[i].y = it.position.y;
-                i++;
-            }
-        }
-        std::list<TPPLPoly> outpolys;
-        TPPLPartition part;
-        po.SetOrientation(TPPL_CCW);
-        part.Triangulate_EC(&po, &outpolys);
         begin_group(poly.layer);
-        for (auto &tri : outpolys) {
-            assert(tri.GetNumPoints() == 3);
-            Coordf p0 = transform.transform(coordf_from_pt(tri[0]));
-            Coordf p1 = transform.transform(coordf_from_pt(tri[1]));
-            Coordf p2 = transform.transform(coordf_from_pt(tri[2]));
-            add_triangle(poly.layer, p0, p1, p2, co);
+        if (poly_is_rect(poly)) {
+            const Coordf p0 = (poly.get_vertex(0).position + poly.get_vertex(1).position) / 2;
+            const Coordf p1 = (poly.get_vertex(2).position + poly.get_vertex(3).position) / 2;
+            const float width = sqrt((poly.get_vertex(0).position - poly.get_vertex(1).position).mag_sq());
+            add_triangle(poly.layer, transform.transform(p0), transform.transform(p1), Coordf(width, 1), co,
+                         TriangleInfo::FLAG_BUTT);
         }
-        for (size_t i = 0; i < poly.vertices.size(); i++) {
-            draw_line(poly.vertices[i].position, poly.vertices[(i + 1) % poly.vertices.size()].position, co,
-                      poly.layer);
+        else {
+            TPPLPoly po;
+            po.Init(poly.vertices.size());
+            po.SetHole(false);
+            {
+                size_t i = 0;
+                for (auto &it : poly.vertices) {
+                    po[i].x = it.position.x;
+                    po[i].y = it.position.y;
+                    i++;
+                }
+            }
+            std::list<TPPLPoly> outpolys;
+            TPPLPartition part;
+            po.SetOrientation(TPPL_CCW);
+            part.Triangulate_EC(&po, &outpolys);
+            for (auto &tri : outpolys) {
+                assert(tri.GetNumPoints() == 3);
+                Coordf p0 = transform.transform(coordf_from_pt(tri[0]));
+                Coordf p1 = transform.transform(coordf_from_pt(tri[1]));
+                Coordf p2 = transform.transform(coordf_from_pt(tri[2]));
+                add_triangle(poly.layer, p0, p1, p2, co);
+            }
+            for (size_t i = 0; i < poly.vertices.size(); i++) {
+                draw_line(poly.vertices[i].position, poly.vertices[(i + 1) % poly.vertices.size()].position, co,
+                          poly.layer);
+            }
         }
         end_group();
         triangle_type_current = TriangleInfo::Type::NONE;
@@ -893,7 +934,7 @@ void Canvas::render(const Shape &shape, bool interactive)
         auto w = shape.params.at(0);
         auto h = shape.params.at(1);
         add_triangle(shape.layer, transform.transform(Coordf(-w / 2, 0)), transform.transform(Coordf(w / 2, 0)),
-                     Coordf(h, NAN), ColorP::FROM_LAYER, TriangleInfo::FLAG_BUTT);
+                     Coordf(h, 0), ColorP::FROM_LAYER, TriangleInfo::FLAG_BUTT);
         transform_restore();
     }
     else if (shape.form == Shape::Form::OBROUND) {
@@ -919,26 +960,26 @@ void Canvas::render(const Hole &hole, bool interactive)
 
     transform_save();
     transform.accumulate(hole.placement);
-    int64_t d = hole.diameter / 2;
-    int64_t l = std::max((int64_t)hole.length / 2 - d, (int64_t)0);
+    const int64_t r = hole.diameter / 2;
+    const int64_t l = std::max((int64_t)hole.length / 2 - r, (int64_t)0);
     if (hole.shape == Hole::Shape::ROUND) {
-        draw_line(Coordf(), Coordf(100, 0), co, 10000, true, hole.diameter);
+        draw_circle(Coordf(), r);
         if (hole.plated) {
-            draw_line(Coordf(), Coordf(100, 0), co, 10000, true, hole.diameter * 0.9);
+            draw_circle(Coordf(), r * 0.9);
         }
         float x = hole.diameter / 2 / M_SQRT2;
         draw_line(Coordi(-x, -x), Coordi(x, x), co);
         draw_line(Coordi(x, -x), Coordi(-x, x), co);
         if (interactive)
-            selectables.append(hole.uuid, ObjectType::HOLE, Coordi(), Coordi(-d, -d), Coordi(d, d));
+            selectables.append(hole.uuid, ObjectType::HOLE, Coordi(), Coordi(-r, -r), Coordi(r, r));
     }
     else if (hole.shape == Hole::Shape::SLOT) {
-        draw_arc(Coordi(-l, 0), d, 0, 2 * M_PI, co);
-        draw_arc(Coordi(l, 0), d, 0, 2 * M_PI, co);
-        draw_line(Coordi(-l, -d), Coordi(l, -d), co);
-        draw_line(Coordi(-l, d), Coordi(l, d), co);
+        draw_circle(Coordi(-l, 0), r, co);
+        draw_circle(Coordi(l, 0), r, co);
+        draw_line(Coordi(-l, -r), Coordi(l, -r), co);
+        draw_line(Coordi(-l, r), Coordi(l, r), co);
         if (interactive)
-            selectables.append(hole.uuid, ObjectType::HOLE, Coordi(), Coordi(-l - d, -d), Coordi(l + d, +d));
+            selectables.append(hole.uuid, ObjectType::HOLE, Coordi(), Coordi(-l - r, -r), Coordi(l + r, +r));
     }
     if (interactive)
         targets.emplace_back(hole.uuid, ObjectType::HOLE, hole.placement.shift);
@@ -1007,7 +1048,7 @@ void Canvas::render(const Sheet &sheet)
         render(sheet.frame, true);
     }
     for (const auto &it : sheet.junctions) {
-        render(it.second, true, ObjectType::SCHEMATIC);
+        render(it.second);
     }
     for (const auto &it : sheet.symbols) {
         render(it.second);
@@ -1075,45 +1116,52 @@ void Canvas::render_pad_overlay(const Pad &pad)
     auto pad_width = abs(b.x - a.x);
     auto pad_height = abs(b.y - a.y);
 
-    std::set<int> text_layers;
+    int text_layer = 10000;
     switch (pad.padstack.type) {
     case Padstack::Type::TOP:
-        text_layers.emplace(get_overlay_layer(BoardLayers::TOP_COPPER, true));
+        text_layer = get_overlay_layer(BoardLayers::TOP_COPPER, true);
         break;
 
     case Padstack::Type::BOTTOM:
-        text_layers.emplace(get_overlay_layer(BoardLayers::BOTTOM_COPPER, true));
+        text_layer = get_overlay_layer(BoardLayers::BOTTOM_COPPER, true);
         break;
 
     default:
-        text_layers.emplace(get_overlay_layer(BoardLayers::TOP_COPPER, true));
-        text_layers.emplace(get_overlay_layer(BoardLayers::BOTTOM_COPPER, true));
+        text_layer = get_overlay_layer({BoardLayers::TOP_COPPER, BoardLayers::BOTTOM_COPPER}, true);
     }
 
-    Placement tr = transform;
+    Placement tr;
+    tr.set_angle_rad(get_view_angle());
+    if (get_flip_view())
+        tr.invert_angle();
+    {
+        Placement tr2 = transform;
+        if (tr2.mirror)
+            tr2.invert_angle();
+        tr2.mirror = false;
+        tr.accumulate(tr2);
+    }
     if (get_flip_view()) {
         tr.shift.x *= -1;
         tr.invert_angle();
     }
 
     set_lod_size(std::min(pad_height, pad_width));
-    for (const auto overlay_layer : text_layers) {
-        if (pad.secondary_text.size()) {
-            draw_bitmap_text_box(tr, pad_width, pad_height, pad.name, ColorP::TEXT_OVERLAY, overlay_layer,
-                                 TextBoxMode::UPPER);
-            draw_bitmap_text_box(tr, pad_width, pad_height, pad.secondary_text, ColorP::TEXT_OVERLAY, overlay_layer,
-                                 TextBoxMode::LOWER);
-        }
-        else {
-            draw_bitmap_text_box(tr, pad_width, pad_height, pad.name, ColorP::TEXT_OVERLAY, overlay_layer,
-                                 TextBoxMode::FULL);
-        }
+
+    if (pad.secondary_text.size()) {
+        draw_bitmap_text_box(tr, pad_width, pad_height, pad.name, ColorP::TEXT_OVERLAY, text_layer, TextBoxMode::UPPER);
+        draw_bitmap_text_box(tr, pad_width, pad_height, pad.secondary_text, ColorP::TEXT_OVERLAY, text_layer,
+                             TextBoxMode::LOWER);
     }
+    else {
+        draw_bitmap_text_box(tr, pad_width, pad_height, pad.name, ColorP::TEXT_OVERLAY, text_layer, TextBoxMode::FULL);
+    }
+
     set_lod_size(-1);
     transform_restore();
 }
 
-static int get_target_layer_for_padstack_type(Padstack::Type type)
+static LayerRange get_layer_for_padstack_type(Padstack::Type type)
 {
     if (type == Padstack::Type::TOP) {
         return BoardLayers::TOP_COPPER;
@@ -1122,7 +1170,7 @@ static int get_target_layer_for_padstack_type(Padstack::Type type)
         return BoardLayers::BOTTOM_COPPER;
     }
     else {
-        return 10000;
+        return LayerRange(BoardLayers::BOTTOM_COPPER, BoardLayers::TOP_COPPER);
     }
 }
 
@@ -1189,10 +1237,10 @@ void Canvas::render(const Package &pkg, bool interactive, bool smashed, bool omi
             transform_save();
             transform.accumulate(pad.placement);
             auto bb = pad.padstack.get_bbox();
-            selectables.append(pad.uuid, ObjectType::PAD, {0, 0}, bb.first, bb.second);
+            const auto layer = get_layer_for_padstack_type(pad.padstack.type);
+            selectables.append(pad.uuid, ObjectType::PAD, {0, 0}, bb.first, bb.second, 0, layer);
             transform_restore();
-            int target_layer = get_target_layer_for_padstack_type(pad.padstack.type);
-            targets.emplace_back(pad.uuid, ObjectType::PAD, pad.placement.shift, 0, target_layer);
+            targets.emplace_back(pad.uuid, ObjectType::PAD, pad.placement.shift, 0, layer);
         }
         for (const auto &it : pkg.warnings) {
             render(it);
@@ -1206,43 +1254,6 @@ void Canvas::render(const Package &pkg, bool interactive, bool smashed, bool omi
     }
 }
 
-void Canvas::render(const Buffer &buf)
-{
-    for (const auto &it : buf.junctions) {
-        render(it.second);
-    }
-    for (const auto &it : buf.pins) {
-        render(it.second);
-    }
-    for (const auto &it : buf.holes) {
-        render(it.second);
-    }
-    for (const auto &it : buf.lines) {
-        render(it.second);
-    }
-    for (const auto &it : buf.texts) {
-        render(it.second);
-    }
-    for (const auto &it : buf.arcs) {
-        render(it.second);
-    }
-    for (const auto &it : buf.pads) {
-        render(it.second);
-    }
-    for (const auto &it : buf.symbols) {
-        render(it.second);
-    }
-    for (const auto &it : buf.net_lines) {
-        render(it.second);
-    }
-    for (const auto &it : buf.power_symbols) {
-        render(it.second);
-    }
-    for (const auto &it : buf.net_labels) {
-        render(it.second);
-    }
-}
-
 void Canvas::render(const BoardPackage &pkg, bool interactive)
 {
     transform_save();
@@ -1253,13 +1264,13 @@ void Canvas::render(const BoardPackage &pkg, bool interactive)
     }
     if (interactive) {
         selectables.append(pkg.uuid, ObjectType::BOARD_PACKAGE, {0, 0}, bb.first, bb.second, 0,
-                           pkg.flip ? BoardLayers::BOTTOM_PACKAGE : BoardLayers::TOP_PACKAGE);
+                           pkg.flip ? BoardLayers::BOTTOM_COPPER : BoardLayers::TOP_COPPER);
         targets.emplace_back(pkg.uuid, ObjectType::BOARD_PACKAGE, pkg.placement.shift);
 
         for (const auto &[pad_uuid, pad] : pkg.package.pads) {
-            int target_layer = get_target_layer_for_padstack_type(pad.padstack.type);
+            const auto layer = get_layer_for_padstack_type(pad.padstack.type);
             targets.emplace_back(UUIDPath<2>(pkg.uuid, pad.uuid), ObjectType::PAD,
-                                 transform.transform(pad.placement.shift), 0, target_layer);
+                                 transform.transform(pad.placement.shift), 0, layer);
         }
     }
     if (interactive)
@@ -1284,7 +1295,7 @@ void Canvas::render(const Via &via, bool interactive)
     }
     auto bb = via.padstack.get_bbox();
     if (interactive)
-        selectables.append(via.uuid, ObjectType::VIA, {0, 0}, bb.first, bb.second);
+        selectables.append(via.uuid, ObjectType::VIA, {0, 0}, bb.first, bb.second, 0, via.junction->layer);
     img_net(via.junction->net);
     img_patch_type(PatchType::VIA);
     if (interactive)
@@ -1298,8 +1309,17 @@ void Canvas::render(const Via &via, bool interactive)
     if (show_text_in_vias && interactive && via.junction->net && via.junction->net->name.size()) {
         auto size = (bb.second.x - bb.first.x) * 1.2;
         set_lod_size(size);
-        Placement p(via.junction->position);
-        draw_bitmap_text_box(p, size, size, via.junction->net->name, ColorP::TEXT_OVERLAY, 10000, TextBoxMode::FULL);
+        Placement p;
+        p.set_angle_rad(get_view_angle());
+        if (get_flip_view())
+            p.invert_angle();
+        p.accumulate(Placement(via.junction->position));
+        if (get_flip_view()) {
+            p.shift.x *= -1;
+        }
+        p.set_angle(0);
+        const auto ol = get_overlay_layer({BoardLayers::BOTTOM_COPPER, BoardLayers::TOP_COPPER}, true);
+        draw_bitmap_text_box(p, size, size, via.junction->net->name, ColorP::TEXT_OVERLAY, ol, TextBoxMode::FULL);
         set_lod_size(-1);
     }
 
@@ -1317,7 +1337,8 @@ void Canvas::render(const BoardHole &hole, bool interactive)
     transform.accumulate(hole.placement);
     auto bb = hole.padstack.get_bbox();
     if (interactive)
-        selectables.append(hole.uuid, ObjectType::BOARD_HOLE, {0, 0}, bb.first, bb.second);
+        selectables.append(hole.uuid, ObjectType::BOARD_HOLE, {0, 0}, bb.first, bb.second, 0,
+                           LayerRange(BoardLayers::TOP_COPPER, BoardLayers::BOTTOM_COPPER));
     img_net(hole.net);
     if (hole.padstack.type == Padstack::Type::HOLE)
         img_patch_type(PatchType::HOLE_PTH);
@@ -1335,6 +1356,9 @@ void Canvas::render(const BoardHole &hole, bool interactive)
 
 void Canvas::render(const class Dimension &dim)
 {
+    if (img_mode)
+        return;
+
     Coordd p0 = dim.p0;
     Coordd p1 = dim.p1;
 
@@ -1459,6 +1483,9 @@ void Canvas::render(const Board &brd, bool interactive, PanelMode mode, OutlineM
     for (const auto &it : brd.arcs) {
         render(it.second, interactive);
     }
+    for (const auto &it : brd.decals) {
+        render(it.second);
+    }
     if (mode == PanelMode::INCLUDE) {
         for (const auto &it : brd.board_panels) {
             render(it.second);
@@ -1472,27 +1499,6 @@ void Canvas::render(const Board &brd, bool interactive, PanelMode mode, OutlineM
         for (const auto &it : brd.connection_lines) {
             render(it.second);
         }
-
-        for (const auto &path : brd.obstacles) {
-            for (auto it = path.cbegin(); it < path.cend(); it++) {
-                if (it != path.cbegin()) {
-                    auto b = it - 1;
-                    draw_line(Coordf(b->X, b->Y), Coordf(it->X, it->Y), ColorP::AIRWIRE, 10000, false, 0);
-                }
-            }
-        }
-
-        unsigned int i = 0;
-        for (auto it = brd.track_path.cbegin(); it < brd.track_path.cend(); it++) {
-            if (it != brd.track_path.cbegin()) {
-                auto b = it - 1;
-                draw_line(Coordf(b->X, b->Y), Coordf(it->X, it->Y), ColorP::AIRWIRE, 10000, false, 0);
-            }
-            if (i % 2 == 0) {
-                draw_line(Coordf(it->X, it->Y), Coordf(it->X, it->Y), ColorP::AIRWIRE, 10000, false, .1_mm);
-            }
-            i++;
-        }
         for (const auto &it : brd.warnings) {
             render(it);
         }
@@ -1551,6 +1557,29 @@ void Canvas::render(const Frame &fr, bool on_sheet)
     draw_line(Coordf(0, fr.height), Coordf(), c);
 }
 
+void Canvas::render(const Decal &dec, bool interactive)
+{
+    if (interactive) {
+        for (const auto &it : dec.junctions) {
+            auto &junc = it.second;
+            selectables.append(junc.uuid, ObjectType::JUNCTION, junc.position, 0, 10000, true);
+            targets.emplace_back(junc.uuid, ObjectType::JUNCTION, transform.transform(junc.position));
+        }
+    }
+    for (const auto &it : dec.lines) {
+        render(it.second, interactive);
+    }
+    for (const auto &it : dec.arcs) {
+        render(it.second, interactive);
+    }
+    for (const auto &it : dec.polygons) {
+        render(it.second, interactive);
+    }
+    for (const auto &it : dec.texts) {
+        render(it.second, interactive);
+    }
+}
+
 void Canvas::render(const Picture &pic)
 {
     if (!pic.data && !img_mode) {
@@ -1576,4 +1605,17 @@ void Canvas::render(const Picture &pic)
                               pic.placement.get_angle_rad());
 }
 
+void Canvas::render(const BoardDecal &decal)
+{
+    transform_save();
+    transform.accumulate(decal.placement);
+    auto bb = decal.get_decal().get_bbox();
+    if (decal.get_flip()) {
+        transform.invert_angle();
+    }
+    selectables.append(decal.uuid, ObjectType::BOARD_DECAL, {0, 0}, bb.first, bb.second, 0, decal.get_layers());
+    render(decal.get_decal(), false);
+    transform_restore();
+}
+
 } // namespace horizon
