@@ -4,14 +4,14 @@
 namespace horizon {
 class SelectablesRenderer {
 public:
-    SelectablesRenderer(class CanvasGL *ca, class Selectables *sel);
+    SelectablesRenderer(const class CanvasGL &ca, const class Selectables &sel);
     void realize();
     void render();
     void push();
 
 private:
-    CanvasGL *ca;
-    Selectables *sel;
+    const CanvasGL &ca;
+    const Selectables &sel;
 
     GLuint program;
     GLuint vao;
@@ -25,5 +25,6 @@ private:
     GLuint color_inner_loc;
     GLuint color_outer_loc;
     GLuint color_prelight_loc;
+    GLuint min_size_loc;
 };
 } // namespace horizon
