@@ -107,6 +107,16 @@ void TriangleRenderer::realize()
                                                      "triangle-circle-fragment.glsl",
                                                      "/org/horizon-eda/horizon/canvas/shaders/"
                                                      "triangle-circle-geometry.glsl");
+    program_arc0 = gl_create_program_from_resource("/org/horizon-eda/horizon/canvas/shaders/triangle-vertex.glsl",
+                                                   "/org/horizon-eda/horizon/canvas/shaders/"
+                                                   "triangle-arc0-fragment.glsl",
+                                                   "/org/horizon-eda/horizon/canvas/shaders/"
+                                                   "triangle-arc0-geometry.glsl");
+    program_arc = gl_create_program_from_resource("/org/horizon-eda/horizon/canvas/shaders/triangle-vertex.glsl",
+                                                  "/org/horizon-eda/horizon/canvas/shaders/"
+                                                  "triangle-arc-fragment.glsl",
+                                                  "/org/horizon-eda/horizon/canvas/shaders/"
+                                                  "triangle-arc-geometry.glsl");
     GL_CHECK_ERROR;
     glGenBuffers(1, &ubo);
     glBindBuffer(GL_UNIFORM_BUFFER, ubo);
@@ -123,6 +133,8 @@ void TriangleRenderer::realize()
     glUniformBlockBinding(program_line, block_index, binding_point_index);
     glUniformBlockBinding(program_glyph, block_index, binding_point_index);
     glUniformBlockBinding(program_circle, block_index, binding_point_index);
+    glUniformBlockBinding(program_arc, block_index, binding_point_index);
+    glUniformBlockBinding(program_arc0, block_index, binding_point_index);
     GL_CHECK_ERROR;
     vao = create_vao(program_line0, vbo, ebo);
     GL_CHECK_ERROR;
@@ -271,6 +283,14 @@ void TriangleRenderer::render_layer(int layer, HighlightMode highlight_mode, boo
             case Type::CIRCLE:
                 glUseProgram(program_circle);
                 break;
+
+            case Type::ARC0:
+                glUseProgram(program_arc0);
+                break;
+
+            case Type::ARC:
+                glUseProgram(program_arc);
+                break;
             }
             switch (highlight_mode) {
             case HighlightMode::ONLY: // only highlighted, skip not highlighted
@@ -313,16 +333,6 @@ void TriangleRenderer::render_layer(int layer, HighlightMode highlight_mode, boo
     stencil++;
 }
 
-void TriangleRenderer::render_layer_with_overlay(int layer, HighlightMode highlight_mode)
-{
-    render_layer(layer, highlight_mode);
-    for (auto ignore_flip : {false, true}) {
-        if (ca.overlay_layers.count({layer, ignore_flip}))
-            render_layer(ca.overlay_layers.at({layer, ignore_flip}), highlight_mode, ignore_flip);
-    }
-}
-
-
 void TriangleRenderer::render()
 {
     glBindVertexArray(vao);
@@ -352,23 +362,39 @@ void TriangleRenderer::render()
 
     const auto &modes = ca.highlight_on_top ? modes_on_top : modes_normal;
 
+    std::vector<std::pair<int, std::set<std::pair<int, bool>>>> normal_layers;
+    normal_layers.reserve(layers.size());
+    for (const auto layer : layers) {
+        const auto &ld = ca.get_layer_display(layer);
+        if (layer != ca.work_layer && layer < 10000 && ld.visible && !ca.layer_is_annotation(layer))
+            normal_layers.push_back({layer, {}});
+    }
+    normal_layers.push_back({ca.work_layer, {}});
+
+    for (const auto &[k, overlay_layer] : ca.overlay_layers) {
+        const auto layer = k.first;
+        const auto ignore_flip = k.second;
+        auto f = std::find_if(normal_layers.rbegin(), normal_layers.rend(),
+                              [layer](const auto &x) { return layer.overlaps(x.first); });
+        if (f != normal_layers.rend()) {
+            f->second.emplace(overlay_layer, ignore_flip);
+        }
+    }
+
     render_annotations(false); // annotation bottom
     for (const auto &highlight_modes : modes) {
-        for (auto layer : layers) {
-            const auto &ld = ca.get_layer_display(layer);
-            if (layer != ca.work_layer && layer < 10000 && ld.visible && !ca.layer_is_annotation(layer)) {
-                for (const auto highlight_mode : highlight_modes) {
-                    if (ca.layer_mode == CanvasGL::LayerMode::WORK_ONLY) {
-                        if (highlight_mode == HighlightMode::SKIP)
-                            continue;
-                    }
-                    render_layer_with_overlay(layer, highlight_mode);
+        for (const auto &[layer, overlays] : normal_layers) {
+            for (const auto highlight_mode : highlight_modes) {
+                if (layer != ca.work_layer && ca.layer_mode == CanvasGL::LayerMode::WORK_ONLY
+                    && highlight_mode == HighlightMode::SKIP)
+                    continue;
+
+                render_layer(layer, highlight_mode);
+                for (const auto &[overlay, ignore_flip] : overlays) {
+                    render_layer(overlay, highlight_mode, ignore_flip);
                 }
             }
         }
-        for (const auto highlight_mode : highlight_modes) {
-            render_layer_with_overlay(ca.work_layer, highlight_mode);
-        }
         for (auto layer : layers) {
             const auto &ld = ca.get_layer_display(layer);
             if (layer >= 10000 && layer < Canvas::first_overlay_layer && ld.visible && !ca.layer_is_annotation(layer)) {
@@ -424,6 +450,15 @@ void TriangleRenderer::push()
                 if (tri_info.flags & TriangleInfo::FLAG_GLYPH) {
                     ty = Type::GLYPH;
                 }
+                else if ((tri_info.flags & TriangleInfo::FLAG_ARC) && tri.y2 == 0) {
+                    ty = Type::ARC0;
+                }
+                else if (tri_info.flags & TriangleInfo::FLAG_ARC) {
+                    ty = Type::ARC;
+                }
+                else if (tri_info.flags & TriangleInfo::FLAG_BUTT) {
+                    ty = Type::LINE_BUTT;
+                }
                 else if (!isnan(tri.y2)) {
                     ty = Type::TRIANGLE;
                 }
@@ -433,9 +468,7 @@ void TriangleRenderer::push()
                 else if (isnan(tri.y1) && isnan(tri.x2) && isnan(tri.y2)) {
                     ty = Type::CIRCLE;
                 }
-                else if (isnan(tri.y2) && (tri_info.flags & TriangleInfo::FLAG_BUTT)) {
-                    ty = Type::LINE_BUTT;
-                }
+
                 else if (isnan(tri.y2)) {
                     ty = Type::LINE;
                 }
