@@ -17,7 +17,7 @@ public:
 
 private:
     const CanvasGL &ca;
-    enum class Type { TRIANGLE, LINE, LINE0, LINE_BUTT, GLYPH, CIRCLE };
+    enum class Type { TRIANGLE, LINE, LINE0, LINE_BUTT, GLYPH, CIRCLE, ARC, ARC0 };
     const std::map<int, vector_pair<Triangle, TriangleInfo>> &triangles;
     std::map<int, std::map<std::pair<Type, bool>, std::pair<size_t, size_t>>> layer_offsets;
     size_t n_tris = 0;
@@ -28,6 +28,8 @@ private:
     GLuint program_triangle;
     GLuint program_circle;
     GLuint program_glyph;
+    GLuint program_arc;
+    GLuint program_arc0;
     GLuint vao;
     GLuint vbo;
     GLuint ubo;
@@ -36,7 +38,6 @@ private:
 
     enum class HighlightMode { SKIP, ONLY };
     void render_layer(int layer, HighlightMode highlight_mode, bool ignore_flip = false);
-    void render_layer_with_overlay(int layer, HighlightMode highlight_mode);
     void render_annotations(bool top);
     std::array<float, 4> apply_highlight(const class Color &color, HighlightMode mode, int layer) const;
     int stencil = 0;
