@@ -211,7 +211,7 @@ void Canvas3DBase::render(RenderBackground mode)
     float m = get_magic_number() / height * cam_distance;
     float d = cam_dist_max * 2;
     if (projection == Projection::PERSP) {
-        projmat = glm::perspective(glm::radians(cam_fov), width / height, cam_dist_min / 2, cam_dist_max * 2);
+        projmat = glm::perspective(glm::radians(cam_fov), (float)width / height, cam_dist_min / 2, cam_dist_max * 2);
     }
     else {
         projmat = glm::ortho(-width * m, width * m, -height * m, height * m, -d, d);
@@ -339,10 +339,13 @@ void Canvas3DBase::load_3d_model(const std::string &filename, const std::string
         size_t vertex_offset = face_vertex_buffer.size();
         size_t first_index = face_index_buffer.size();
         for (const auto &face : faces) {
-            for (const auto &v : face.vertices) {
-                face_vertex_buffer.emplace_back(v.x, v.y, v.z, face.color.r * 255, face.color.g * 255,
+            for (size_t i = 0; i < face.vertices.size(); i++) {
+                const auto &v = face.vertices.at(i);
+                const auto &n = face.normals.at(i);
+                face_vertex_buffer.emplace_back(v.x, v.y, v.z, n.x, n.y, n.z, face.color.r * 255, face.color.g * 255,
                                                 face.color.b * 255);
             }
+
             for (const auto &tri : face.triangle_indices) {
                 size_t a, b, c;
                 std::tie(a, b, c) = tri;
