@@ -28,6 +28,7 @@ public:
     bool show_silkscreen = true;
     bool show_substrate = true;
     bool show_models = true;
+    bool show_dnp_models = false;
     bool show_solder_paste = true;
     bool use_layer_colors = false;
     Color solder_mask_color = {0, .5, 0};
@@ -47,13 +48,16 @@ public:
 
     class FaceVertex {
     public:
-        FaceVertex(float ix, float iy, float iz, uint8_t ir, uint8_t ig, uint8_t ib)
-            : x(ix), y(iy), z(iz), r(ir), g(ig), b(ib), _pad(0)
+        FaceVertex(float ix, float iy, float iz, float inx, float iny, float inz, uint8_t ir, uint8_t ig, uint8_t ib)
+            : x(ix), y(iy), z(iz), nx(inx), ny(iny), nz(inz), r(ir), g(ig), b(ib), _pad(0)
         {
         }
         float x;
         float y;
         float z;
+        float nx;
+        float ny;
+        float nz;
 
         uint8_t r;
         uint8_t g;
@@ -85,8 +89,8 @@ public:
 protected:
     Appearance appearance;
 
-    float width = 100;
-    float height = 100;
+    int width = 100;
+    int height = 100;
 
     CoverRenderer cover_renderer;
     WallRenderer wall_renderer;
@@ -110,7 +114,7 @@ protected:
 
     void load_3d_model(const std::string &filename, const std::string &filename_abs);
 
-    std::map<std::string, std::string> get_model_filenames(class Pool &pool);
+    std::map<std::string, std::string> get_model_filenames(class IPool &pool);
 
     std::mutex models_loading_mutex;
 
@@ -132,17 +136,26 @@ private:
     glm::vec3 cam_normal;
 
     float package_height_max = 0;
-    std::vector<FaceVertex> face_vertex_buffer;              // vertices of all models, sequentially
-    std::vector<unsigned int> face_index_buffer;             // indexes face_vertex_buffer to form triangles
-    std::map<std::string, std::pair<size_t, size_t>> models; // key: filename value: first: offset in face_index_buffer
-                                                             // second: no of indexes
+    std::vector<FaceVertex> face_vertex_buffer;  // vertices of all models, sequentially
+    std::vector<unsigned int> face_index_buffer; // indexes face_vertex_buffer to form triangles
+
+    class ModelInfo {
+    public:
+        ModelInfo(size_t o, size_t n) : face_index_offset(o), count(n)
+        {
+        }
+        const size_t face_index_offset; // offset in face_index_buffer
+        const size_t count;             // number of items in face_index_buffer
+        bool pushed = false;
+    };
+    std::map<std::string, ModelInfo> models; // key: filename
 
     std::vector<ModelTransform> package_transforms; // position and rotation of
                                                     // all board packages,
                                                     // grouped by package
-    std::map<std::string, std::pair<size_t, size_t>>
-            package_transform_idxs; // key: model filename: value: first: offset
-                                    // in package_transforms second: no of items
+    std::map<std::pair<std::string, bool>, std::pair<size_t, size_t>>
+            package_transform_idxs; // key: first: model filename second: nopopulate
+                                    // value: first: offset in package_transforms second: no of items
 
     float get_magic_number() const;
 };
