@@ -1,13 +1,13 @@
 #include "wall.hpp"
 #include "canvas/gl_util.hpp"
-#include "canvas3d.hpp"
+#include "canvas3d_base.hpp"
 #include <cmath>
 #include <glm/glm.hpp>
 #include <glm/gtc/matrix_transform.hpp>
 #include <glm/gtc/type_ptr.hpp>
 
 namespace horizon {
-WallRenderer::WallRenderer(Canvas3D *c) : ca(c)
+WallRenderer::WallRenderer(Canvas3DBase &c) : ca(c)
 {
 }
 
@@ -24,7 +24,7 @@ static GLuint create_vao(GLuint program, GLuint &vbo_out)
     glGenBuffers(1, &buffer);
     glBindBuffer(GL_ARRAY_BUFFER, buffer);
 
-    Canvas3D::Layer3D::Vertex vertices[] = {
+    CanvasMesh::Layer3D::Vertex vertices[] = {
             //   Position
             {-5, -5}, {5, -5}, {-5, 5},
 
@@ -34,7 +34,7 @@ static GLuint create_vao(GLuint program, GLuint &vbo_out)
 
     /* enable and set the position attribute */
     glEnableVertexAttribArray(position_index);
-    glVertexAttribPointer(position_index, 2, GL_FLOAT, GL_FALSE, sizeof(Canvas3D::Layer3D::Vertex), 0);
+    glVertexAttribPointer(position_index, 2, GL_FLOAT, GL_FALSE, sizeof(CanvasMesh::Layer3D::Vertex), 0);
 
     /* enable and set the color attribute */
     /* reset the state; we will re-enable the VAO when needed */
@@ -67,16 +67,16 @@ void WallRenderer::push()
 {
     glBindBuffer(GL_ARRAY_BUFFER, vbo);
     n_vertices = 0;
-    for (const auto &it : ca->layers) {
+    for (const auto &it : ca.ca.get_layers()) {
         n_vertices += it.second.walls.size();
     }
-    glBufferData(GL_ARRAY_BUFFER, sizeof(Canvas3D::Layer3D::Vertex) * n_vertices, nullptr, GL_STREAM_DRAW);
+    glBufferData(GL_ARRAY_BUFFER, sizeof(CanvasMesh::Layer3D::Vertex) * n_vertices, nullptr, GL_STREAM_DRAW);
     GL_CHECK_ERROR
     size_t ofs = 0;
     layer_offsets.clear();
-    for (const auto &it : ca->layers) {
-        glBufferSubData(GL_ARRAY_BUFFER, ofs * sizeof(Canvas3D::Layer3D::Vertex),
-                        it.second.walls.size() * sizeof(Canvas3D::Layer3D::Vertex), it.second.walls.data());
+    for (const auto &it : ca.ca.get_layers()) {
+        glBufferSubData(GL_ARRAY_BUFFER, ofs * sizeof(CanvasMesh::Layer3D::Vertex),
+                        it.second.walls.size() * sizeof(CanvasMesh::Layer3D::Vertex), it.second.walls.data());
         layer_offsets[it.first] = ofs;
         ofs += it.second.walls.size();
     }
@@ -85,13 +85,13 @@ void WallRenderer::push()
 
 void WallRenderer::render(int layer)
 {
-    if (ca->layers[layer].alpha != 1)
+    if (ca.ca.get_layer(layer).alpha != 1)
         return;
-    auto co = ca->get_layer_color(layer);
-    glUniform4f(layer_color_loc, co.r, co.g, co.b, ca->layers[layer].alpha);
-    glUniform1f(layer_offset_loc, ca->get_layer_offset(layer));
-    glUniform1f(layer_thickness_loc, ca->get_layer_thickness(layer));
-    glDrawArrays(GL_LINE_STRIP_ADJACENCY, layer_offsets[layer], ca->layers[layer].walls.size());
+    auto co = ca.get_layer_color(layer);
+    glUniform4f(layer_color_loc, co.r, co.g, co.b, ca.ca.get_layer(layer).alpha);
+    glUniform1f(layer_offset_loc, ca.get_layer_offset(layer));
+    glUniform1f(layer_thickness_loc, ca.get_layer_thickness(layer));
+    glDrawArrays(GL_LINE_STRIP_ADJACENCY, layer_offsets[layer], ca.ca.get_layer(layer).walls.size());
 }
 
 void WallRenderer::render()
@@ -99,12 +99,12 @@ void WallRenderer::render()
     glUseProgram(program);
     glBindVertexArray(vao);
 
-    glUniformMatrix4fv(view_loc, 1, GL_FALSE, glm::value_ptr(ca->viewmat));
-    glUniformMatrix4fv(proj_loc, 1, GL_FALSE, glm::value_ptr(ca->projmat));
-    glUniform3fv(cam_normal_loc, 1, glm::value_ptr(ca->cam_normal));
+    glUniformMatrix4fv(view_loc, 1, GL_FALSE, glm::value_ptr(ca.viewmat));
+    glUniformMatrix4fv(proj_loc, 1, GL_FALSE, glm::value_ptr(ca.projmat));
+    glUniform3fv(cam_normal_loc, 1, glm::value_ptr(ca.cam_normal));
 
     for (const auto &it : layer_offsets) {
-        if (ca->layer_is_visible(it.first))
+        if (ca.layer_is_visible(it.first))
             render(it.first);
     }
 }
