@@ -80,6 +80,8 @@ public:
     T x;
     T y;
 
+    using type = T;
+
     // WTF, but works
     // template<typename U = T>
     // Coord(double ix, double iy, typename std::enable_if<std::is_same<U,
@@ -166,6 +168,13 @@ public:
         return Coord<float>(r * cos(phi), r * sin(phi));
     }
 
+    Coord<float> rotate(float a) const
+    {
+        const float x2 = x * cos(a) - y * sin(a);
+        const float y2 = x * sin(a) + y * cos(a);
+        return {x2, y2};
+    }
+
     /**
      * @param a other coordinate
      * @returns dot product of \p a and this
@@ -175,6 +184,11 @@ public:
         return x * a.x + y * a.y;
     }
 
+    T cross(const Coord<T> &other) const
+    {
+        return (x * other.y) - (y * other.x);
+    }
+
     /**
      * @returns squared magnitude of this
      */
