@@ -2,6 +2,8 @@
 #include "lut.hpp"
 #include "nlohmann/json.hpp"
 #include "util/util.hpp"
+#include "util/bbox_accumulator.hpp"
+#include "util/polygon_arc_removal_proxy.hpp"
 
 namespace horizon {
 
@@ -143,6 +145,29 @@ std::pair<unsigned int, unsigned int> Polygon::get_vertices_for_edge(unsigned in
     return {edge, (edge + 1) % vertices.size()};
 }
 
+const Polygon::Vertex &Polygon::get_vertex(int edge) const
+{
+    while (edge < 0)
+        edge += vertices.size();
+    return vertices.at(edge % vertices.size());
+}
+
+Polygon::Vertex &Polygon::get_vertex(int edge)
+{
+    return const_cast<Polygon::Vertex &>(const_cast<const Polygon *>(this)->get_vertex(edge));
+}
+
+std::pair<Coordi, Coordi> Polygon::get_bbox() const
+{
+    PolygonArcRemovalProxy proxy(*this, 8);
+    const auto &poly = proxy.get();
+    BBoxAccumulator<Coordi::type> acc;
+    for (const auto &v : poly.vertices) {
+        acc.accumulate(v.position);
+    }
+    return acc.get();
+}
+
 json Polygon::serialize() const
 {
     json j;
