@@ -28,7 +28,7 @@ Text::Text(const UUID &uu, const json &j)
     : uuid(uu), origin(origin_lut.lookup(j.at("origin"))),
       font(font_lut.lookup(j.value("font", ""), TextData::Font::SIMPLEX)), placement(j.at("placement")),
       text(j.at("text").get<std::string>()), size(j.value("size", 2500000)), width(j.value("width", 0)),
-      layer(j.value("layer", 0)), from_smash(j.value("from_smash", false)), temp(false)
+      layer(j.value("layer", 0)), from_smash(j.value("from_smash", false))
 {
 }
 
