@@ -1,49 +1,49 @@
 #include "core_board.hpp"
 #include "board/board_layers.hpp"
 #include "core_properties.hpp"
-#include "pool/part.hpp"
 #include "util/util.hpp"
-#include <algorithm>
 #include "nlohmann/json.hpp"
 #include <giomm/file.h>
 #include <glibmm/fileutils.h>
+#include "pool/pool_cached.hpp"
+#include "pool/part.hpp"
 
 namespace horizon {
 CoreBoard::CoreBoard(const std::string &board_filename, const std::string &block_filename, const std::string &via_dir,
-                     const std::string &pictures_dir, Pool &pool)
-    : via_padstack_provider(via_dir, pool), block(Block::new_from_file(block_filename, pool)),
-      brd(Board::new_from_file(board_filename, block, pool, via_padstack_provider)), rules(brd.rules),
-      fab_output_settings(brd.fab_output_settings), pdf_export_settings(brd.pdf_export_settings),
-      step_export_settings(brd.step_export_settings), pnp_export_settings(brd.pnp_export_settings), colors(brd.colors),
-      m_board_filename(board_filename), m_block_filename(block_filename), m_pictures_dir(pictures_dir)
+                     const std::string &pictures_dir, IPool &pool)
+    : Core(pool), via_padstack_provider(via_dir, pool), block(Block::new_from_file(block_filename, pool)),
+      brd(Board::new_from_file(board_filename, *block, pool, via_padstack_provider)), rules(brd->rules),
+      fab_output_settings(brd->fab_output_settings), pdf_export_settings(brd->pdf_export_settings),
+      step_export_settings(brd->step_export_settings), pnp_export_settings(brd->pnp_export_settings),
+      colors(brd->colors), m_board_filename(board_filename), m_block_filename(block_filename),
+      m_pictures_dir(pictures_dir)
 {
-    m_pool = &pool;
-    brd.load_pictures(pictures_dir);
+    brd->load_pictures(pictures_dir);
     rebuild();
 }
 
 void CoreBoard::reload_netlist()
 {
-    block = Block::new_from_file(m_block_filename, *m_pool);
-    brd.block = &block;
-    brd.update_refs();
-    for (auto it = brd.packages.begin(); it != brd.packages.end();) {
+    block = Block::new_from_file(m_block_filename, m_pool);
+    brd->block = &*block;
+    brd->update_refs();
+    for (auto it = brd->packages.begin(); it != brd->packages.end();) {
         if (it->second.component == nullptr || it->second.component->part == nullptr) {
             for (auto &it_txt : it->second.texts) {
-                brd.texts.erase(it_txt->uuid);
+                brd->texts.erase(it_txt->uuid);
             }
-            brd.packages.erase(it++);
+            brd->packages.erase(it++);
         }
         else {
             it++;
         }
     }
-    brd.update_refs();
-    for (auto it = brd.tracks.begin(); it != brd.tracks.end();) {
+    brd->update_refs();
+    for (auto it = brd->tracks.begin(); it != brd->tracks.end();) {
         bool del = false;
         for (auto &it_ft : {it->second.from, it->second.to}) {
             if (it_ft.package.uuid) {
-                if (brd.packages.count(it_ft.package.uuid) == 0) {
+                if (brd->packages.count(it_ft.package.uuid) == 0) {
                     del = true;
                 }
                 else {
@@ -55,15 +55,15 @@ void CoreBoard::reload_netlist()
         }
 
         if (del) {
-            brd.tracks.erase(it++);
+            brd->tracks.erase(it++);
         }
         else {
             it++;
         }
     }
-    brd.update_refs();
-    rules.cleanup(&block);
-
+    brd->update_refs();
+    rules.cleanup(&*block);
+    brd->expand_flags = Board::EXPAND_PROPAGATE_NETS | Board::EXPAND_ALL_AIRWIRES | Board::EXPAND_PACKAGES;
     rebuild();
 }
 
@@ -73,7 +73,7 @@ bool CoreBoard::get_property(ObjectType type, const UUID &uu, ObjectProperty::ID
         return true;
     switch (type) {
     case ObjectType::BOARD_PACKAGE: {
-        auto pkg = &brd.packages.at(uu);
+        auto pkg = &brd->packages.at(uu);
         switch (property) {
         case ObjectProperty::ID::FLIPPED:
             dynamic_cast<PropertyValueBool &>(value).value = pkg->flip;
@@ -125,7 +125,7 @@ bool CoreBoard::get_property(ObjectType type, const UUID &uu, ObjectProperty::ID
     } break;
 
     case ObjectType::BOARD_PANEL: {
-        auto &panel = brd.board_panels.at(uu);
+        auto &panel = brd->board_panels.at(uu);
         switch (property) {
         case ObjectProperty::ID::OMIT_OUTLINE:
             dynamic_cast<PropertyValueBool &>(value).value = panel.omit_outline;
@@ -148,7 +148,7 @@ bool CoreBoard::get_property(ObjectType type, const UUID &uu, ObjectProperty::ID
     } break;
 
     case ObjectType::TRACK: {
-        auto track = &brd.tracks.at(uu);
+        auto track = &brd->tracks.at(uu);
         switch (property) {
         case ObjectProperty::ID::WIDTH_FROM_RULES:
             dynamic_cast<PropertyValueBool &>(value).value = track->width_from_rules;
@@ -180,7 +180,7 @@ bool CoreBoard::get_property(ObjectType type, const UUID &uu, ObjectProperty::ID
     } break;
 
     case ObjectType::VIA: {
-        auto via = &brd.vias.at(uu);
+        auto via = &brd->vias.at(uu);
         switch (property) {
         case ObjectProperty::ID::FROM_RULES:
             dynamic_cast<PropertyValueBool &>(value).value = via->from_rules;
@@ -210,7 +210,7 @@ bool CoreBoard::get_property(ObjectType type, const UUID &uu, ObjectProperty::ID
     } break;
 
     case ObjectType::PLANE: {
-        auto plane = &brd.planes.at(uu);
+        auto plane = &brd->planes.at(uu);
         switch (property) {
         case ObjectProperty::ID::FROM_RULES:
             dynamic_cast<PropertyValueBool &>(value).value = plane->from_rules;
@@ -234,7 +234,7 @@ bool CoreBoard::get_property(ObjectType type, const UUID &uu, ObjectProperty::ID
     } break;
 
     case ObjectType::BOARD_HOLE: {
-        auto hole = &brd.holes.at(uu);
+        auto hole = &brd->holes.at(uu);
         switch (property) {
         case ObjectProperty::ID::NAME:
             dynamic_cast<PropertyValueString &>(value).value = hole->pool_padstack->name;
@@ -255,7 +255,7 @@ bool CoreBoard::get_property(ObjectType type, const UUID &uu, ObjectProperty::ID
             return true;
 
         case ObjectProperty::ID::PAD_TYPE: {
-            const auto ps = brd.holes.at(uu).pool_padstack;
+            const auto ps = brd->holes.at(uu).pool_padstack;
             std::string pad_type;
             switch (ps->type) {
             case Padstack::Type::MECHANICAL:
@@ -276,6 +276,32 @@ bool CoreBoard::get_property(ObjectType type, const UUID &uu, ObjectProperty::ID
         }
     } break;
 
+    case ObjectType::BOARD_DECAL: {
+        const auto &decal = brd->decals.at(uu);
+        switch (property) {
+        case ObjectProperty::ID::NAME:
+            dynamic_cast<PropertyValueString &>(value).value = decal.get_decal().name;
+            return true;
+
+        case ObjectProperty::ID::POSITION_X:
+        case ObjectProperty::ID::POSITION_Y:
+        case ObjectProperty::ID::ANGLE:
+            get_placement(decal.placement, value, property);
+            return true;
+
+        case ObjectProperty::ID::FLIPPED:
+            dynamic_cast<PropertyValueBool &>(value).value = decal.get_flip();
+            return true;
+
+        case ObjectProperty::ID::SCALE:
+            dynamic_cast<PropertyValueDouble &>(value).value = decal.get_scale();
+            return true;
+
+        default:
+            return false;
+        }
+    } break;
+
     default:
         return false;
     }
@@ -287,10 +313,17 @@ bool CoreBoard::set_property(ObjectType type, const UUID &uu, ObjectProperty::ID
         return true;
     switch (type) {
     case ObjectType::BOARD_PACKAGE: {
-        auto pkg = &brd.packages.at(uu);
+        auto pkg = &brd->packages.at(uu);
         switch (property) {
         case ObjectProperty::ID::FLIPPED:
             pkg->flip = dynamic_cast<const PropertyValueBool &>(value).value;
+            pkg->update(*brd);
+            brd->update_refs();
+            brd->expand_flags |= Board::EXPAND_AIRWIRES;
+            {
+                const auto n = pkg->get_nets();
+                brd->airwires_expand.insert(n.begin(), n.end());
+            }
             break;
 
         case ObjectProperty::ID::FIXED:
@@ -302,9 +335,16 @@ bool CoreBoard::set_property(ObjectType type, const UUID &uu, ObjectProperty::ID
             if (!alt_uuid) {
                 pkg->alternate_package = nullptr;
             }
-            else if (m_pool->get_alternate_packages(pkg->pool_package->uuid).count(alt_uuid)
+            else if (m_pool.get_alternate_packages(pkg->pool_package->uuid).count(alt_uuid)
                      != 0) { // see if really an alt package for pkg
-                pkg->alternate_package = m_pool->get_package(alt_uuid);
+                pkg->alternate_package = m_pool.get_package(alt_uuid);
+            }
+            pkg->update(*brd);
+            brd->update_refs();
+            brd->expand_flags |= Board::EXPAND_AIRWIRES;
+            {
+                const auto n = pkg->get_nets();
+                brd->airwires_expand.insert(n.begin(), n.end());
             }
         } break;
 
@@ -319,6 +359,11 @@ bool CoreBoard::set_property(ObjectType type, const UUID &uu, ObjectProperty::ID
             for (auto &text : pkg->texts) {
                 text->placement.shift += delta;
             }
+            brd->expand_flags |= Board::EXPAND_AIRWIRES;
+            {
+                const auto n = pkg->get_nets();
+                brd->airwires_expand.insert(n.begin(), n.end());
+            }
         } break;
 
         case ObjectProperty::ID::OMIT_SILKSCREEN:
@@ -335,7 +380,7 @@ bool CoreBoard::set_property(ObjectType type, const UUID &uu, ObjectProperty::ID
     } break;
 
     case ObjectType::BOARD_PANEL: {
-        auto &panel = brd.board_panels.at(uu);
+        auto &panel = brd->board_panels.at(uu);
         switch (property) {
 
         case ObjectProperty::ID::OMIT_OUTLINE:
@@ -354,7 +399,7 @@ bool CoreBoard::set_property(ObjectType type, const UUID &uu, ObjectProperty::ID
     } break;
 
     case ObjectType::TRACK: {
-        auto track = &brd.tracks.at(uu);
+        auto track = &brd->tracks.at(uu);
         switch (property) {
         case ObjectProperty::ID::WIDTH_FROM_RULES:
             track->width_from_rules = dynamic_cast<const PropertyValueBool &>(value).value;
@@ -380,7 +425,7 @@ bool CoreBoard::set_property(ObjectType type, const UUID &uu, ObjectProperty::ID
     } break;
 
     case ObjectType::VIA: {
-        auto via = &brd.vias.at(uu);
+        auto via = &brd->vias.at(uu);
         switch (property) {
         case ObjectProperty::ID::FROM_RULES:
             via->from_rules = dynamic_cast<const PropertyValueBool &>(value).value;
@@ -396,7 +441,7 @@ bool CoreBoard::set_property(ObjectType type, const UUID &uu, ObjectProperty::ID
     } break;
 
     case ObjectType::PLANE: {
-        auto plane = &brd.planes.at(uu);
+        auto plane = &brd->planes.at(uu);
         switch (property) {
         case ObjectProperty::ID::FROM_RULES:
             plane->from_rules = dynamic_cast<const PropertyValueBool &>(value).value;
@@ -418,7 +463,7 @@ bool CoreBoard::set_property(ObjectType type, const UUID &uu, ObjectProperty::ID
     } break;
 
     case ObjectType::BOARD_HOLE: {
-        auto hole = &brd.holes.at(uu);
+        auto hole = &brd->holes.at(uu);
         switch (property) {
         case ObjectProperty::ID::POSITION_X:
         case ObjectProperty::ID::POSITION_Y:
@@ -431,6 +476,28 @@ bool CoreBoard::set_property(ObjectType type, const UUID &uu, ObjectProperty::ID
         }
     } break;
 
+    case ObjectType::BOARD_DECAL: {
+        auto &decal = brd->decals.at(uu);
+        switch (property) {
+        case ObjectProperty::ID::POSITION_X:
+        case ObjectProperty::ID::POSITION_Y:
+        case ObjectProperty::ID::ANGLE:
+            set_placement(decal.placement, value, property);
+            break;
+
+        case ObjectProperty::ID::FLIPPED:
+            decal.set_flip(dynamic_cast<const PropertyValueBool &>(value).value, *brd);
+            break;
+
+        case ObjectProperty::ID::SCALE:
+            decal.set_scale(dynamic_cast<const PropertyValueDouble &>(value).value);
+            break;
+
+        default:
+            return false;
+        }
+    } break;
+
     default:
         return false;
     }
@@ -447,14 +514,14 @@ bool CoreBoard::get_property_meta(ObjectType type, const UUID &uu, ObjectPropert
         return true;
     switch (type) {
     case ObjectType::BOARD_PACKAGE: {
-        auto pkg = &brd.packages.at(uu);
+        auto pkg = &brd->packages.at(uu);
         switch (property) {
         case ObjectProperty::ID::ALTERNATE_PACKAGE: {
             PropertyMetaNetClasses &m = dynamic_cast<PropertyMetaNetClasses &>(meta);
             m.net_classes.clear();
             m.net_classes.emplace(UUID(), pkg->pool_package->name + " (default)");
-            for (const auto &it : m_pool->get_alternate_packages(pkg->pool_package->uuid)) {
-                m.net_classes.emplace(it, m_pool->get_package(it)->name);
+            for (const auto &it : m_pool.get_alternate_packages(pkg->pool_package->uuid)) {
+                m.net_classes.emplace(it, m_pool.get_package(it)->name);
             }
             return true;
         }
@@ -472,7 +539,7 @@ bool CoreBoard::get_property_meta(ObjectType type, const UUID &uu, ObjectPropert
     } break;
 
     case ObjectType::TRACK: {
-        auto track = &brd.tracks.at(uu);
+        auto track = &brd->tracks.at(uu);
         switch (property) {
         case ObjectProperty::ID::WIDTH:
             meta.is_settable = !track->width_from_rules;
@@ -488,7 +555,7 @@ bool CoreBoard::get_property_meta(ObjectType type, const UUID &uu, ObjectPropert
     } break;
 
     case ObjectType::PLANE: {
-        auto plane = &brd.planes.at(uu);
+        auto plane = &brd->planes.at(uu);
         switch (property) {
         case ObjectProperty::ID::WIDTH:
             meta.is_settable = !plane->from_rules;
@@ -507,31 +574,31 @@ bool CoreBoard::get_property_meta(ObjectType type, const UUID &uu, ObjectPropert
 void CoreBoard::rebuild(bool from_undo)
 {
     clock_t begin = clock();
-    brd.expand();
+    brd->expand_some();
     Core::rebuild(from_undo);
     clock_t end = clock();
     double elapsed_secs = double(end - begin) / CLOCKS_PER_SEC;
     std::cout << "rebuild took " << elapsed_secs << std::endl;
 }
 
-LayerProvider *CoreBoard::get_layer_provider()
+LayerProvider &CoreBoard::get_layer_provider()
 {
-    return &brd;
+    return *brd;
 }
 
-const Board *CoreBoard::get_canvas_data()
+const Board &CoreBoard::get_canvas_data()
 {
-    return &brd;
+    return *brd;
 }
 
 Board *CoreBoard::get_board()
 {
-    return &brd;
+    return &*brd;
 }
 
 const Board *CoreBoard::get_board() const
 {
-    return &brd;
+    return &*brd;
 }
 
 Block *CoreBoard::get_block()
@@ -546,12 +613,7 @@ Rules *CoreBoard::get_rules()
 
 void CoreBoard::update_rules()
 {
-    brd.rules = rules;
-}
-
-ViaPadstackProvider *CoreBoard::get_via_padstack_provider()
-{
-    return &via_padstack_provider;
+    brd->rules = rules;
 }
 
 CoreBoard::HistoryItem::HistoryItem(const Block &b, const Board &r) : block(b), brd(shallow_copy, r)
@@ -560,21 +622,29 @@ CoreBoard::HistoryItem::HistoryItem(const Block &b, const Board &r) : block(b),
 
 void CoreBoard::history_push()
 {
-    history.push_back(std::make_unique<CoreBoard::HistoryItem>(block, brd));
+    history.push_back(std::make_unique<CoreBoard::HistoryItem>(*block, *brd));
 }
 
 void CoreBoard::history_load(unsigned int i)
 {
-    auto x = dynamic_cast<CoreBoard::HistoryItem *>(history.at(history_current).get());
-    std::map<UUID, unsigned int> plane_revs;
-    for (const auto &it : brd.planes) {
-        plane_revs[it.first] = it.second.revision;
-    }
-    brd.~Board(); // reconstruct board from json
-    new (&brd) Board(x->brd);
-    block = x->block;
-    brd.update_refs();
-    brd.expand();
+    const auto &x = dynamic_cast<CoreBoard::HistoryItem &>(*history.at(history_current));
+    brd.emplace(shallow_copy, x.brd);
+    block.emplace(x.block);
+    brd->block = &*block;
+    brd->update_refs();
+    brd->expand_flags = Board::EXPAND_PACKAGES | Board::EXPAND_VIAS;
+    brd->expand_some();
+}
+
+void CoreBoard::reload_pool()
+{
+    const auto brd_j = brd->serialize();
+    const auto block_j = block->serialize();
+    m_pool.clear();
+    block.emplace(block->uuid, block_j, m_pool);
+    brd.emplace(brd->uuid, brd_j, *block, m_pool, via_padstack_provider);
+    history_clear();
+    rebuild();
 }
 
 json CoreBoard::get_meta()
@@ -584,7 +654,7 @@ json CoreBoard::get_meta()
 
 std::pair<Coordi, Coordi> CoreBoard::get_bbox()
 {
-    return brd.get_bbox();
+    return brd->get_bbox();
 }
 
 const std::string &CoreBoard::get_filename() const
@@ -594,15 +664,15 @@ const std::string &CoreBoard::get_filename() const
 
 void CoreBoard::save(const std::string &suffix)
 {
-    brd.rules = rules;
-    brd.fab_output_settings = fab_output_settings;
-    brd.pdf_export_settings = pdf_export_settings;
-    brd.step_export_settings = step_export_settings;
-    brd.pnp_export_settings = pnp_export_settings;
-    brd.colors = colors;
-    auto j = brd.serialize();
+    brd->rules = rules;
+    brd->fab_output_settings = fab_output_settings;
+    brd->pdf_export_settings = pdf_export_settings;
+    brd->step_export_settings = step_export_settings;
+    brd->pnp_export_settings = pnp_export_settings;
+    brd->colors = colors;
+    auto j = brd->serialize();
     save_json_to_file(m_board_filename + suffix, j);
-    brd.save_pictures(m_pictures_dir);
+    brd->save_pictures(m_pictures_dir);
 }
 
 void CoreBoard::delete_autosave()
