@@ -212,9 +212,8 @@ bool CorePackage::get_property_meta(ObjectType type, const UUID &uu, ObjectPrope
 
 void CorePackage::rebuild(bool from_undo)
 {
-    auto r = package.apply_parameter_set({});
-    if (r.first) {
-        Logger::get().log_critical("Parameter program failed", Logger::Domain::CORE, r.second);
+    if (auto r = package.apply_parameter_set({})) {
+        Logger::get().log_critical("Parameter program failed", Logger::Domain::CORE, r.value());
     }
     package.expand();
     package.update_warnings();
@@ -228,13 +227,13 @@ void CorePackage::history_push()
 
 void CorePackage::history_load(unsigned int i)
 {
-    auto x = dynamic_cast<CorePackage::HistoryItem *>(history.at(history_current).get());
-    package = x->package;
+    const auto &x = dynamic_cast<CorePackage::HistoryItem &>(*history.at(history_current));
+    package = x.package;
 }
 
-const Package *CorePackage::get_canvas_data()
+const Package &CorePackage::get_canvas_data()
 {
-    return &package;
+    return package;
 }
 
 void CorePackage::reload_pool()
