@@ -1,20 +1,15 @@
 #pragma once
-#include "common/layer.hpp"
 #include "core.hpp"
 #include "pool/package.hpp"
-#include "pool/pool.hpp"
-#include <deque>
-#include <iostream>
-#include <memory>
 #include "document/idocument_package.hpp"
 
 namespace horizon {
 class CorePackage : public Core, public virtual IDocumentPackage {
 public:
-    CorePackage(const std::string &filename, Pool &pool);
+    CorePackage(const std::string &filename, IPool &pool);
     bool has_object_type(ObjectType ty) const override;
 
-    Package *get_package() override;
+    Package &get_package() override;
 
     /*Polygon *insert_polygon(const UUID &uu);
     Polygon *get_polygon(const UUID &uu=true);
@@ -23,7 +18,7 @@ public:
     Hole *get_hole(const UUID &uu=true);
     void delete_hole(const UUID &uu);*/
 
-    class LayerProvider *get_layer_provider() override;
+    class LayerProvider &get_layer_provider() override;
 
     bool set_property(ObjectType type, const UUID &uu, ObjectProperty::ID property,
                       const class PropertyValue &value) override;
@@ -37,7 +32,7 @@ public:
 
     void rebuild(bool from_undo = false) override;
 
-    const Package *get_canvas_data();
+    const Package &get_canvas_data();
     std::pair<Coordi, Coordi> get_bbox() override;
     json get_meta() override;
 
@@ -50,6 +45,11 @@ public:
         return ObjectType::PACKAGE;
     }
 
+    const FileVersion &get_version() const override
+    {
+        return package.version;
+    }
+
 private:
     std::map<UUID, Junction> *get_junction_map() override;
     std::map<UUID, Line> *get_line_map() override;
