@@ -1,20 +1,17 @@
 #include "core_padstack.hpp"
 #include "core_properties.hpp"
-#include <algorithm>
-#include <fstream>
 #include "nlohmann/json.hpp"
 #include "util/util.hpp"
 #include <giomm/file.h>
 #include <glibmm/fileutils.h>
 
 namespace horizon {
-CorePadstack::CorePadstack(const std::string &filename, Pool &pool)
-    : padstack(Padstack::new_from_file(filename)), m_filename(filename),
+CorePadstack::CorePadstack(const std::string &filename, IPool &pool)
+    : Core(pool), padstack(Padstack::new_from_file(filename)), m_filename(filename),
       parameter_program_code(padstack.parameter_program.get_code()), parameter_set(padstack.parameter_set),
       parameters_required(padstack.parameters_required)
 {
     rebuild();
-    m_pool = &pool;
 }
 
 bool CorePadstack::has_object_type(ObjectType ty) const
@@ -201,9 +198,9 @@ std::string CorePadstack::get_display_name(ObjectType type, const UUID &uu)
     }
 }
 
-LayerProvider *CorePadstack::get_layer_provider()
+LayerProvider &CorePadstack::get_layer_provider()
 {
-    return &padstack;
+    return padstack;
 }
 
 std::map<UUID, Polygon> *CorePadstack::get_polygon_map()
@@ -227,19 +224,19 @@ void CorePadstack::history_push()
 
 void CorePadstack::history_load(unsigned int i)
 {
-    auto x = dynamic_cast<CorePadstack::HistoryItem *>(history.at(history_current).get());
-    padstack = x->padstack;
+    const auto &x = dynamic_cast<CorePadstack::HistoryItem &>(*history.at(history_current));
+    padstack = x.padstack;
     s_signal_rebuilt.emit();
 }
 
-const Padstack *CorePadstack::get_canvas_data()
+const Padstack &CorePadstack::get_canvas_data()
 {
-    return &padstack;
+    return padstack;
 }
 
-Padstack *CorePadstack::get_padstack()
+Padstack &CorePadstack::get_padstack()
 {
-    return &padstack;
+    return padstack;
 }
 
 std::pair<Coordi, Coordi> CorePadstack::get_bbox()
