@@ -6,41 +6,42 @@
 #include "nlohmann/json.hpp"
 #include <giomm/file.h>
 #include <glibmm/fileutils.h>
+#include "pool/ipool.hpp"
 
 namespace horizon {
 CoreSchematic::CoreSchematic(const std::string &schematic_filename, const std::string &block_filename,
                              const std::string &pictures_dir, IPool &pool)
     : Core(pool), block(Block::new_from_file(block_filename, pool)),
-      project_meta_loaded_from_block(block.project_meta.size()),
-      sch(Schematic::new_from_file(schematic_filename, block, pool)), rules(sch.rules),
-      bom_export_settings(block.bom_export_settings), pdf_export_settings(sch.pdf_export_settings),
+      project_meta_loaded_from_block(block->project_meta.size()),
+      sch(Schematic::new_from_file(schematic_filename, *block, pool)), rules(sch->rules),
+      bom_export_settings(block->bom_export_settings), pdf_export_settings(sch->pdf_export_settings),
       m_schematic_filename(schematic_filename), m_block_filename(block_filename), m_pictures_dir(pictures_dir)
 {
-    auto x = std::find_if(sch.sheets.cbegin(), sch.sheets.cend(), [](const auto &a) { return a.second.index == 1; });
-    assert(x != sch.sheets.cend());
+    auto x = std::find_if(sch->sheets.cbegin(), sch->sheets.cend(), [](const auto &a) { return a.second.index == 1; });
+    assert(x != sch->sheets.cend());
     sheet_uuid = x->first;
-    sch.load_pictures(m_pictures_dir);
+    sch->load_pictures(m_pictures_dir);
     rebuild();
 }
 
 Junction *CoreSchematic::get_junction(const UUID &uu)
 {
-    auto &sheet = sch.sheets.at(sheet_uuid);
+    auto &sheet = sch->sheets.at(sheet_uuid);
     return &sheet.junctions.at(uu);
 }
 SchematicSymbol *CoreSchematic::get_schematic_symbol(const UUID &uu)
 {
-    auto &sheet = sch.sheets.at(sheet_uuid);
+    auto &sheet = sch->sheets.at(sheet_uuid);
     return &sheet.symbols.at(uu);
 }
 Text *CoreSchematic::get_text(const UUID &uu)
 {
-    auto &sheet = sch.sheets.at(sheet_uuid);
+    auto &sheet = sch->sheets.at(sheet_uuid);
     return &sheet.texts.at(uu);
 }
 Schematic *CoreSchematic::get_schematic()
 {
-    return &sch;
+    return &*sch;
 }
 
 Block *CoreSchematic::get_block()
@@ -55,57 +56,57 @@ LayerProvider &CoreSchematic::get_layer_provider()
 
 Sheet *CoreSchematic::get_sheet()
 {
-    return &sch.sheets.at(sheet_uuid);
+    return &sch->sheets.at(sheet_uuid);
 }
 
 const Sheet *CoreSchematic::get_sheet() const
 {
-    return &sch.sheets.at(sheet_uuid);
+    return &sch->sheets.at(sheet_uuid);
 }
 
 Line *CoreSchematic::get_line(const UUID &uu)
 {
-    auto &sheet = sch.sheets.at(sheet_uuid);
+    auto &sheet = sch->sheets.at(sheet_uuid);
     return &sheet.lines.at(uu);
 }
 Arc *CoreSchematic::get_arc(const UUID &uu)
 {
-    auto &sheet = sch.sheets.at(sheet_uuid);
+    auto &sheet = sch->sheets.at(sheet_uuid);
     return &sheet.arcs.at(uu);
 }
 
 Junction *CoreSchematic::insert_junction(const UUID &uu)
 {
-    auto &sheet = sch.sheets.at(sheet_uuid);
+    auto &sheet = sch->sheets.at(sheet_uuid);
     auto x = sheet.junctions.emplace(std::make_pair(uu, uu));
     return &(x.first->second);
 }
 
 LineNet *CoreSchematic::insert_line_net(const UUID &uu)
 {
-    auto &sheet = sch.sheets.at(sheet_uuid);
+    auto &sheet = sch->sheets.at(sheet_uuid);
     auto x = sheet.net_lines.emplace(std::make_pair(uu, uu));
     return &(x.first->second);
 }
 
 void CoreSchematic::delete_junction(const UUID &uu)
 {
-    auto &sheet = sch.sheets.at(sheet_uuid);
+    auto &sheet = sch->sheets.at(sheet_uuid);
     sheet.junctions.erase(uu);
 }
 void CoreSchematic::delete_line_net(const UUID &uu)
 {
-    auto &sheet = sch.sheets.at(sheet_uuid);
+    auto &sheet = sch->sheets.at(sheet_uuid);
     sheet.net_lines.erase(uu);
 }
 void CoreSchematic::delete_schematic_symbol(const UUID &uu)
 {
-    auto &sheet = sch.sheets.at(sheet_uuid);
+    auto &sheet = sch->sheets.at(sheet_uuid);
     sheet.symbols.erase(uu);
 }
 SchematicSymbol *CoreSchematic::insert_schematic_symbol(const UUID &uu, const Symbol *sym)
 {
-    auto &sheet = sch.sheets.at(sheet_uuid);
+    auto &sheet = sch->sheets.at(sheet_uuid);
     auto x = sheet.symbols.emplace(std::make_pair(uu, SchematicSymbol{uu, sym}));
     return &(x.first->second);
     return nullptr;
@@ -113,31 +114,31 @@ SchematicSymbol *CoreSchematic::insert_schematic_symbol(const UUID &uu, const Sy
 
 Line *CoreSchematic::insert_line(const UUID &uu)
 {
-    auto &sheet = sch.sheets.at(sheet_uuid);
+    auto &sheet = sch->sheets.at(sheet_uuid);
     auto x = sheet.lines.emplace(std::make_pair(uu, uu));
     return &(x.first->second);
 }
 void CoreSchematic::delete_line(const UUID &uu)
 {
-    auto &sheet = sch.sheets.at(sheet_uuid);
+    auto &sheet = sch->sheets.at(sheet_uuid);
     sheet.lines.erase(uu);
 }
 
 Arc *CoreSchematic::insert_arc(const UUID &uu)
 {
-    auto &sheet = sch.sheets.at(sheet_uuid);
+    auto &sheet = sch->sheets.at(sheet_uuid);
     auto x = sheet.arcs.emplace(std::make_pair(uu, uu));
     return &(x.first->second);
 }
 void CoreSchematic::delete_arc(const UUID &uu)
 {
-    auto &sheet = sch.sheets.at(sheet_uuid);
+    auto &sheet = sch->sheets.at(sheet_uuid);
     sheet.arcs.erase(uu);
 }
 
 std::vector<LineNet *> CoreSchematic::get_net_lines()
 {
-    auto &sheet = sch.sheets.at(sheet_uuid);
+    auto &sheet = sch->sheets.at(sheet_uuid);
     std::vector<LineNet *> r;
     for (auto &it : sheet.net_lines) {
         r.push_back(&it.second);
@@ -146,7 +147,7 @@ std::vector<LineNet *> CoreSchematic::get_net_lines()
 }
 std::vector<NetLabel *> CoreSchematic::get_net_labels()
 {
-    auto &sheet = sch.sheets.at(sheet_uuid);
+    auto &sheet = sch->sheets.at(sheet_uuid);
     std::vector<NetLabel *> r;
     for (auto &it : sheet.net_labels) {
         r.push_back(&it.second);
@@ -156,7 +157,7 @@ std::vector<NetLabel *> CoreSchematic::get_net_labels()
 
 std::vector<Line *> CoreSchematic::get_lines()
 {
-    auto &sheet = sch.sheets.at(sheet_uuid);
+    auto &sheet = sch->sheets.at(sheet_uuid);
     std::vector<Line *> r;
     for (auto &it : sheet.lines) {
         r.push_back(&it.second);
@@ -166,7 +167,7 @@ std::vector<Line *> CoreSchematic::get_lines()
 
 std::vector<Arc *> CoreSchematic::get_arcs()
 {
-    auto &sheet = sch.sheets.at(sheet_uuid);
+    auto &sheet = sch->sheets.at(sheet_uuid);
     std::vector<Arc *> r;
     for (auto &it : sheet.arcs) {
         r.push_back(&it.second);
@@ -176,29 +177,29 @@ std::vector<Arc *> CoreSchematic::get_arcs()
 
 void CoreSchematic::delete_text(const UUID &uu)
 {
-    auto &sheet = sch.sheets.at(sheet_uuid);
+    auto &sheet = sch->sheets.at(sheet_uuid);
     sheet.texts.erase(uu);
 }
 Text *CoreSchematic::insert_text(const UUID &uu)
 {
-    auto &sheet = sch.sheets.at(sheet_uuid);
+    auto &sheet = sch->sheets.at(sheet_uuid);
     auto x = sheet.texts.emplace(std::make_pair(uu, uu));
     return &(x.first->second);
 }
 
 Picture *CoreSchematic::get_picture(const UUID &uu)
 {
-    auto &sheet = sch.sheets.at(sheet_uuid);
+    auto &sheet = sch->sheets.at(sheet_uuid);
     return &sheet.pictures.at(uu);
 }
 void CoreSchematic::delete_picture(const UUID &uu)
 {
-    auto &sheet = sch.sheets.at(sheet_uuid);
+    auto &sheet = sch->sheets.at(sheet_uuid);
     sheet.pictures.erase(uu);
 }
 Picture *CoreSchematic::insert_picture(const UUID &uu)
 {
-    auto &sheet = sch.sheets.at(sheet_uuid);
+    auto &sheet = sch->sheets.at(sheet_uuid);
     auto x = sheet.pictures.emplace(std::make_pair(uu, uu));
     return &(x.first->second);
 }
@@ -234,10 +235,10 @@ bool CoreSchematic::get_property(ObjectType type, const UUID &uu, ObjectProperty
 {
     if (Core::get_property(type, uu, property, value))
         return true;
-    auto &sheet = sch.sheets.at(sheet_uuid);
+    auto &sheet = sch->sheets.at(sheet_uuid);
     switch (type) {
     case ObjectType::NET: {
-        auto net = &block.nets.at(uu);
+        auto net = &block->nets.at(uu);
         switch (property) {
         case ObjectProperty::ID::NAME:
             dynamic_cast<PropertyValueString &>(value).value = net->name;
@@ -292,28 +293,28 @@ bool CoreSchematic::get_property(ObjectType type, const UUID &uu, ObjectProperty
     } break;
 
     case ObjectType::COMPONENT: {
-        auto comp = &block.components.at(uu);
+        auto comp = &block->components.at(uu);
         switch (property) {
         case ObjectProperty::ID::REFDES:
             dynamic_cast<PropertyValueString &>(value).value = comp->refdes;
             return true;
 
         case ObjectProperty::ID::VALUE:
-            if (block.components.at(uu).part)
+            if (block->components.at(uu).part)
                 dynamic_cast<PropertyValueString &>(value).value = comp->part->get_value();
             else
                 dynamic_cast<PropertyValueString &>(value).value = comp->value;
             return true;
 
         case ObjectProperty::ID::MPN:
-            if (block.components.at(uu).part)
+            if (block->components.at(uu).part)
                 dynamic_cast<PropertyValueString &>(value).value = comp->part->get_MPN();
             else
                 dynamic_cast<PropertyValueString &>(value).value = "<no part>";
             return true;
 
         case ObjectProperty::ID::NOPOPULATE:
-            if (block.components.at(uu).part)
+            if (block->components.at(uu).part)
                 dynamic_cast<PropertyValueBool &>(value).value = comp->nopopulate;
             else
                 dynamic_cast<PropertyValueBool &>(value).value = false;
@@ -362,10 +363,10 @@ bool CoreSchematic::set_property(ObjectType type, const UUID &uu, ObjectProperty
 {
     if (Core::set_property(type, uu, property, value))
         return true;
-    auto &sheet = sch.sheets.at(sheet_uuid);
+    auto &sheet = sch->sheets.at(sheet_uuid);
     switch (type) {
     case ObjectType::COMPONENT: {
-        auto comp = &block.components.at(uu);
+        auto comp = &block->components.at(uu);
         switch (property) {
         case ObjectProperty::ID::REFDES:
             comp->refdes = dynamic_cast<const PropertyValueString &>(value).value;
@@ -387,20 +388,20 @@ bool CoreSchematic::set_property(ObjectType type, const UUID &uu, ObjectProperty
     } break;
 
     case ObjectType::NET: {
-        auto net = &block.nets.at(uu);
+        auto net = &block->nets.at(uu);
         switch (property) {
         case ObjectProperty::ID::NAME:
             net->name = dynamic_cast<const PropertyValueString &>(value).value;
             break;
 
         case ObjectProperty::ID::NET_CLASS: {
-            net->net_class = &block.net_classes.at(dynamic_cast<const PropertyValueUUID &>(value).value);
+            net->net_class = &block->net_classes.at(dynamic_cast<const PropertyValueUUID &>(value).value);
         } break;
 
         case ObjectProperty::ID::IS_POWER:
-            if (block.nets.at(uu).is_power_forced)
+            if (block->nets.at(uu).is_power_forced)
                 return false;
-            block.nets.at(uu).is_power = dynamic_cast<const PropertyValueBool &>(value).value;
+            block->nets.at(uu).is_power = dynamic_cast<const PropertyValueBool &>(value).value;
             break;
 
         default:
@@ -464,18 +465,18 @@ bool CoreSchematic::get_property_meta(ObjectType type, const UUID &uu, ObjectPro
 {
     if (Core::get_property_meta(type, uu, property, meta))
         return true;
-    auto &sheet = sch.sheets.at(sheet_uuid);
+    auto &sheet = sch->sheets.at(sheet_uuid);
     switch (type) {
     case ObjectType::NET:
         switch (property) {
         case ObjectProperty::ID::IS_POWER:
-            meta.is_settable = !block.nets.at(uu).is_power_forced;
+            meta.is_settable = !block->nets.at(uu).is_power_forced;
             return true;
 
         case ObjectProperty::ID::NET_CLASS: {
             PropertyMetaNetClasses &m = dynamic_cast<PropertyMetaNetClasses &>(meta);
             m.net_classes.clear();
-            for (const auto &it : block.net_classes) {
+            for (const auto &it : block->net_classes) {
                 m.net_classes.emplace(it.first, it.second.name);
             }
             return true;
@@ -489,7 +490,7 @@ bool CoreSchematic::get_property_meta(ObjectType type, const UUID &uu, ObjectPro
     case ObjectType::COMPONENT:
         switch (property) {
         case ObjectProperty::ID::VALUE:
-            meta.is_settable = block.components.at(uu).part == nullptr;
+            meta.is_settable = block->components.at(uu).part == nullptr;
             return true;
 
         default:
@@ -521,10 +522,10 @@ std::string CoreSchematic::get_display_name(ObjectType type, const UUID &uu)
 
 std::string CoreSchematic::get_display_name(ObjectType type, const UUID &uu, const UUID &sh)
 {
-    auto &sheet = sch.sheets.at(sh);
+    auto &sheet = sch->sheets.at(sh);
     switch (type) {
     case ObjectType::NET:
-        return block.nets.at(uu).name;
+        return block->nets.at(uu).name;
 
     case ObjectType::LINE_NET: {
         const auto &li = sheet.net_lines.at(uu);
@@ -545,7 +546,7 @@ std::string CoreSchematic::get_display_name(ObjectType type, const UUID &uu, con
         return sheet.symbols.at(uu).component->refdes + sheet.symbols.at(uu).gate->suffix;
 
     case ObjectType::COMPONENT:
-        return block.components.at(uu).refdes;
+        return block->components.at(uu).refdes;
 
     case ObjectType::POWER_SYMBOL:
         return sheet.power_symbols.at(uu).net->name;
@@ -564,30 +565,30 @@ std::string CoreSchematic::get_display_name(ObjectType type, const UUID &uu, con
 void CoreSchematic::add_sheet()
 {
     auto uu = UUID::random();
-    auto sheet_max = std::max_element(sch.sheets.begin(), sch.sheets.end(),
+    auto sheet_max = std::max_element(sch->sheets.begin(), sch->sheets.end(),
                                       [](const auto &p1, const auto &p2) { return p1.second.index < p2.second.index; });
-    auto *sheet = &sch.sheets.emplace(uu, uu).first->second;
+    auto *sheet = &sch->sheets.emplace(uu, uu).first->second;
     sheet->index = sheet_max->second.index + 1;
     sheet->name = "sheet " + std::to_string(sheet->index);
-    sheet->pool_frame = sch.sheets.at(sheet_uuid).pool_frame;
+    sheet->pool_frame = sch->sheets.at(sheet_uuid).pool_frame;
     rebuild();
 }
 
 void CoreSchematic::delete_sheet(const UUID &uu)
 {
-    if (sch.sheets.size() <= 1)
+    if (sch->sheets.size() <= 1)
         return;
-    if (sch.sheets.at(uu).symbols.size() > 0) // only delete empty sheets
+    if (sch->sheets.at(uu).symbols.size() > 0) // only delete empty sheets
         return;
-    auto deleted_index = sch.sheets.at(uu).index;
-    sch.sheets.erase(uu);
-    for (auto &it : sch.sheets) {
+    auto deleted_index = sch->sheets.at(uu).index;
+    sch->sheets.erase(uu);
+    for (auto &it : sch->sheets) {
         if (it.second.index > deleted_index) {
             it.second.index--;
         }
     }
     if (sheet_uuid == uu) { // deleted current sheet
-        auto x = std::find_if(sch.sheets.begin(), sch.sheets.end(), [](auto e) { return e.second.index == 1; });
+        auto x = std::find_if(sch->sheets.begin(), sch->sheets.end(), [](auto e) { return e.second.index == 1; });
         sheet_uuid = x->first;
     }
     rebuild();
@@ -597,7 +598,7 @@ void CoreSchematic::set_sheet(const UUID &uu)
 {
     if (tool_is_active())
         return;
-    if (sch.sheets.count(uu) == 0)
+    if (sch->sheets.count(uu) == 0)
         return;
     sheet_uuid = uu;
 }
@@ -605,21 +606,21 @@ void CoreSchematic::set_sheet(const UUID &uu)
 void CoreSchematic::rebuild(bool from_undo)
 {
     clock_t begin = clock();
-    sch.expand();
+    sch->expand();
     Core::rebuild(from_undo);
     clock_t end = clock();
     double elapsed_secs = double(end - begin) / CLOCKS_PER_SEC;
     std::cout << "rebuild took " << elapsed_secs << std::endl;
 }
 
-const Sheet *CoreSchematic::get_canvas_data()
+const Sheet &CoreSchematic::get_canvas_data()
 {
-    return &sch.sheets.at(sheet_uuid);
+    return sch->sheets.at(sheet_uuid);
 }
 
 void CoreSchematic::history_push()
 {
-    history.push_back(std::make_unique<CoreSchematic::HistoryItem>(block, sch));
+    history.push_back(std::make_unique<CoreSchematic::HistoryItem>(*block, *sch));
     auto x = dynamic_cast<CoreSchematic::HistoryItem *>(history.back().get());
     x->sch.block = &x->block;
     x->sch.update_refs();
@@ -627,15 +628,25 @@ void CoreSchematic::history_push()
 
 void CoreSchematic::history_load(unsigned int i)
 {
-    auto x = dynamic_cast<CoreSchematic::HistoryItem *>(history.at(history_current).get());
-    sch.~Schematic();
-    new (&sch) Schematic(x->sch);
-    block = x->block;
-    sch.block = &block;
-    sch.update_refs();
+    const auto &x = dynamic_cast<CoreSchematic::HistoryItem &>(*history.at(history_current));
+    sch.emplace(x.sch);
+    block.emplace(x.block);
+    sch->block = &*block;
+    sch->update_refs();
     s_signal_rebuilt.emit();
 }
 
+void CoreSchematic::reload_pool()
+{
+    const auto sch_j = sch->serialize();
+    const auto block_j = block->serialize();
+    m_pool.clear();
+    block.emplace(block->uuid, block_j, m_pool);
+    sch.emplace(sch->uuid, sch_j, *block, m_pool);
+    history_clear();
+    rebuild();
+}
+
 std::pair<Coordi, Coordi> CoreSchematic::get_bbox()
 {
     return get_sheet()->frame.get_bbox();
@@ -648,12 +659,12 @@ const std::string &CoreSchematic::get_filename() const
 
 void CoreSchematic::save(const std::string &suffix)
 {
-    sch.rules = rules;
-    block.bom_export_settings = bom_export_settings;
-    sch.pdf_export_settings = pdf_export_settings;
-    save_json_to_file(m_schematic_filename + suffix, sch.serialize());
-    save_json_to_file(m_block_filename + suffix, block.serialize());
-    sch.save_pictures(m_pictures_dir);
+    sch->rules = rules;
+    block->bom_export_settings = bom_export_settings;
+    sch->pdf_export_settings = pdf_export_settings;
+    save_json_to_file(m_schematic_filename + suffix, sch->serialize());
+    save_json_to_file(m_block_filename + suffix, block->serialize());
+    sch->save_pictures(m_pictures_dir);
 }
 
 
