@@ -4,6 +4,7 @@
 #include "schematic/schematic.hpp"
 #include "document/idocument_schematic.hpp"
 #include <memory>
+#include <optional>
 
 namespace horizon {
 class CoreSchematic : public Core, public virtual IDocumentSchematic {
@@ -76,7 +77,7 @@ public:
     void delete_sheet(const UUID &uu);
 
     void set_sheet(const UUID &uu);
-    const Sheet *get_canvas_data();
+    const Sheet &get_canvas_data();
     std::pair<Coordi, Coordi> get_bbox() override;
 
     const std::string &get_filename() const override;
@@ -93,13 +94,15 @@ public:
 
     const FileVersion &get_version() const override
     {
-        return sch.version;
+        return sch->version;
     }
 
+    void reload_pool() override;
+
 private:
-    Block block;
+    std::optional<Block> block;
     const bool project_meta_loaded_from_block;
-    Schematic sch;
+    std::optional<Schematic> sch;
 
     SchematicRules rules;
 
