@@ -263,8 +263,8 @@ void CoreSymbol::history_push()
 
 void CoreSymbol::history_load(unsigned int i)
 {
-    auto x = dynamic_cast<CoreSymbol::HistoryItem *>(history.at(history_current).get());
-    sym = x->sym;
+    const auto &x = dynamic_cast<CoreSymbol::HistoryItem &>(*history.at(history_current));
+    sym = x.sym;
     sym.expand(pin_display_mode);
     s_signal_rebuilt.emit();
 }
@@ -274,9 +274,9 @@ LayerProvider &CoreSymbol::get_layer_provider()
     return sym;
 }
 
-const Symbol *CoreSymbol::get_canvas_data()
+const Symbol &CoreSymbol::get_canvas_data()
 {
-    return &sym;
+    return sym;
 }
 
 std::pair<Coordi, Coordi> CoreSymbol::get_bbox()
