@@ -145,5 +145,11 @@ enum class ToolID {
     ROUND_OFF_VERTEX,
     SWAP_GATES,
     PLACE_PICTURE,
+    ADD_TEXT,
+    PLACE_DECAL,
+    DRAW_PLANE,
+    DRAW_KEEPOUT,
+    DRAG_POLYGON_EDGE,
+    MEASURE,
 };
 } // namespace horizon
