@@ -6,6 +6,7 @@
 #include <iostream>
 #include <sstream>
 #include "core/tool_id.hpp"
+#include "pool/pool.hpp"
 
 namespace horizon {
 
@@ -47,7 +48,7 @@ ToolResponse ToolAddPart::begin(const ToolArgs &args)
             }
         }
         imp->part_placed(part_uuid);
-        auto part = doc.c->get_pool()->get_part(part_uuid);
+        auto part = doc.c->get_pool().get_part(part_uuid);
 
         auto uu = UUID::random();
         comp = &sch->block->components.emplace(uu, uu).first->second;
@@ -58,7 +59,7 @@ ToolResponse ToolAddPart::begin(const ToolArgs &args)
         if (auto r = imp->dialogs.select_entity(doc.r->get_pool())) {
             auto uu = UUID::random();
             comp = &sch->block->components.emplace(uu, uu).first->second;
-            comp->entity = doc.c->get_pool()->get_entity(*r);
+            comp->entity = doc.c->get_pool().get_entity(*r);
         }
         else {
             return ToolResponse::end();
@@ -133,6 +134,7 @@ ToolResponse ToolAddPart::update(const ToolArgs &args)
                 }
                 sym_current->placement = old_symbol->placement;
                 sym_current->placement.shift = args.coords;
+                sym_current->symbol.apply_placement(sym_current->placement);
 
                 selection.clear();
                 selection.emplace(sym_current->uuid, ObjectType::SCHEMATIC_SYMBOL);
@@ -146,6 +148,7 @@ ToolResponse ToolAddPart::update(const ToolArgs &args)
                     sym_current = sym;
                     current_gate++;
                     sym_current->placement.shift = args.coords;
+                    sym_current->symbol.apply_placement(sym_current->placement);
                     selection.clear();
                     selection.emplace(sym_current->uuid, ObjectType::SCHEMATIC_SYMBOL);
                     return ToolResponse();
