@@ -1,13 +1,11 @@
 #pragma once
-#include "block/component.hpp"
 #include "core/tool.hpp"
-#include <forward_list>
 
 namespace horizon {
 
 class ToolAssignPart : public ToolBase {
 public:
-    ToolAssignPart(IDocument *c, ToolID tid);
+    using ToolBase::ToolBase;
     ToolResponse begin(const ToolArgs &args) override;
     ToolResponse update(const ToolArgs &args) override;
     bool can_begin() override;
@@ -18,6 +16,6 @@ public:
 
 private:
     const class Entity *get_entity();
-    Component *comp;
+    class Component *comp;
 };
 } // namespace horizon
