@@ -7,10 +7,6 @@
 
 namespace horizon {
 
-ToolCopyPlacement::ToolCopyPlacement(IDocument *c, ToolID tid) : ToolBase(c, tid)
-{
-}
-
 bool ToolCopyPlacement::can_begin()
 {
     if (!doc.b)
@@ -37,6 +33,7 @@ ToolResponse ToolCopyPlacement::update(const ToolArgs &args)
                 const auto &ref_pkg = brd->packages.at(pkg_uuid);
                 const auto &ref_group = ref_pkg.component->group;
                 const auto &ref_tag = ref_pkg.component->tag;
+                std::set<UUID> nets;
 
                 std::set<BoardPackage *> target_pkgs;
                 for (const auto &it : selection) {
@@ -71,6 +68,11 @@ ToolResponse ToolCopyPlacement::update(const ToolArgs &args)
                     return ToolResponse::revert();
                 }
 
+                for (const auto &pkg : target_pkgs) {
+                    const auto n = pkg->get_nets();
+                    nets.insert(n.begin(), n.end());
+                }
+
                 for (auto it : target_pkgs) {
                     BoardPackage *this_ref_pkg = nullptr;
                     for (auto &it_ref : brd->packages) {
@@ -116,7 +118,7 @@ ToolResponse ToolCopyPlacement::update(const ToolArgs &args)
                         }
                     }
                 }
-
+                doc.b->get_board()->update_airwires(false, nets);
                 return ToolResponse::commit();
             }
             else {
