@@ -16,10 +16,6 @@
 
 namespace horizon {
 
-ToolDelete::ToolDelete(IDocument *c, ToolID tid) : ToolBase(c, tid)
-{
-}
-
 bool ToolDelete::can_begin()
 {
     return selection.size() > 0;
@@ -68,12 +64,6 @@ ToolResponse ToolDelete::begin(const ToolArgs &args)
                 }
             }
         }
-        else if (it.type == ObjectType::NET_LABEL) {
-            Junction *ju = doc.c->get_sheet()->net_labels.at(it.uuid).junction;
-            if (ju->connection_count == 0) {
-                delete_extra.emplace(ju->uuid, ObjectType::JUNCTION);
-            }
-        }
         else if (it.type == ObjectType::SCHEMATIC_SYMBOL) {
             auto sym = doc.c->get_schematic_symbol(it.uuid);
             doc.c->get_schematic()->disconnect_symbol(doc.c->get_sheet(), sym);
@@ -101,6 +91,7 @@ ToolResponse ToolDelete::begin(const ToolArgs &args)
         }
     }
     delete_extra.insert(args.selection.begin(), args.selection.end());
+    const auto nets = nets_from_selection(delete_extra);
     for (const auto &it : delete_extra) {
         if (it.type == ObjectType::LINE_NET) { // need to erase net lines before symbols
             LineNet *line = &doc.c->get_sheet()->net_lines.at(it.uuid);
@@ -111,7 +102,7 @@ ToolResponse ToolDelete::begin(const ToolArgs &args)
                                                         // junctions
             auto *power_sym = &doc.c->get_sheet()->power_symbols.at(it.uuid);
             auto sheet = doc.c->get_sheet();
-            Junction *j = power_sym->junction;
+            SchematicJunction *j = power_sym->junction;
             sheet->power_symbols.erase(power_sym->uuid);
 
             // now, we've got a net segment with one less power symbol
@@ -127,20 +118,21 @@ ToolResponse ToolDelete::begin(const ToolArgs &args)
         }
         else if (it.type == ObjectType::BUS_RIPPER) { // need to erase bus
                                                       // rippers junctions
-            auto *ripper = &doc.c->get_sheet()->bus_rippers.at(it.uuid);
-            auto sheet = doc.c->get_sheet();
-            if (ripper->connection_count == 0) {
+            auto &sheet = *doc.c->get_sheet();
+            auto &ripper = sheet.bus_rippers.at(it.uuid);
+
+            if (ripper.connections.size() == 0) {
                 // just delete it
-                sheet->bus_rippers.erase(ripper->uuid);
+                sheet.bus_rippers.erase(ripper.uuid);
             }
             else {
-                Junction *j = sheet->replace_bus_ripper(ripper);
-                sheet->bus_rippers.erase(ripper->uuid);
-                sheet->propagate_net_segments();
-                auto ns = sheet->analyze_net_segments();
-                auto &nsinfo = ns.at(j->net_segment);
+                auto &j = sheet.replace_bus_ripper(ripper);
+                sheet.bus_rippers.erase(ripper.uuid);
+                sheet.propagate_net_segments();
+                auto ns = sheet.analyze_net_segments();
+                auto &nsinfo = ns.at(j.net_segment);
                 if (!nsinfo.has_label) {
-                    auto pins = sheet->get_pins_connected_to_net_segment(j->net_segment);
+                    auto pins = sheet.get_pins_connected_to_net_segment(j.net_segment);
                     doc.c->get_schematic()->block->extract_pins(pins);
                 }
             }
@@ -171,7 +163,7 @@ ToolResponse ToolDelete::begin(const ToolArgs &args)
             bool multi = false;
             for (const auto &it_ft : {track.from, track.to}) {
                 if (it_ft.is_junc()) {
-                    const Junction *ju = it_ft.junc;
+                    const BoardJunction *ju = it_ft.junc;
                     for (const auto &it_track : doc.b->get_board()->tracks) {
                         if (it_track.second.uuid != track.uuid
                             && (it_track.second.from.junc == ju || it_track.second.to.junc == ju)) {
@@ -246,7 +238,7 @@ ToolResponse ToolDelete::begin(const ToolArgs &args)
             doc.r->delete_hole(it.uuid);
             break;
         case ObjectType::PAD:
-            doc.k->get_package()->pads.erase(it.uuid);
+            doc.k->get_package().pads.erase(it.uuid);
             break;
         case ObjectType::BOARD_HOLE:
             doc.b->get_board()->holes.erase(it.uuid);
@@ -263,6 +255,9 @@ ToolResponse ToolDelete::begin(const ToolArgs &args)
         case ObjectType::BOARD_PANEL:
             doc.b->get_board()->board_panels.erase(it.uuid);
             break;
+        case ObjectType::BOARD_DECAL:
+            doc.b->get_board()->decals.erase(it.uuid);
+            break;
         case ObjectType::PICTURE:
             doc.r->delete_picture(it.uuid);
             break;
@@ -301,7 +296,7 @@ ToolResponse ToolDelete::begin(const ToolArgs &args)
             doc.b->get_board()->vias.erase(it.uuid);
             break;
         case ObjectType::SHAPE:
-            doc.a->get_padstack()->shapes.erase(it.uuid);
+            doc.a->get_padstack().shapes.erase(it.uuid);
             break;
         case ObjectType::TEXT:
             doc.r->delete_text(it.uuid);
@@ -336,10 +331,19 @@ ToolResponse ToolDelete::begin(const ToolArgs &args)
         if (!it->is_valid()) {
             doc.r->delete_polygon(it->uuid);
         }
+        else if (doc.b) {
+            if (auto plane = dynamic_cast<Plane *>(it->usage.ptr)) {
+                if (plane->fragments.size())
+                    doc.b->get_board()->update_plane(plane);
+            }
+        }
     }
     if (doc.b) {
         auto brd = doc.b->get_board();
-        brd->expand_flags = static_cast<Board::ExpandFlags>(Board::EXPAND_AIRWIRES | Board::EXPAND_PROPAGATE_NETS);
+        if (nets.size()) {
+            brd->airwires_expand = nets;
+            brd->expand_flags = Board::EXPAND_AIRWIRES | Board::EXPAND_PROPAGATE_NETS;
+        }
     }
 
     return ToolResponse::commit();
