@@ -8,10 +8,6 @@
 
 namespace horizon {
 
-ToolDrawConnectionLine::ToolDrawConnectionLine(IDocument *c, ToolID tid) : ToolBase(c, tid)
-{
-}
-
 bool ToolDrawConnectionLine::can_begin()
 {
     return doc.b;
@@ -19,7 +15,8 @@ bool ToolDrawConnectionLine::can_begin()
 
 ToolResponse ToolDrawConnectionLine::begin(const ToolArgs &args)
 {
-    temp_junc = doc.r->insert_junction(UUID::random());
+    const auto uu = UUID::random();
+    temp_junc = &doc.b->get_board()->junctions.emplace(uu, uu).first->second;
     imp->set_snap_filter({{ObjectType::JUNCTION, temp_junc->uuid}});
     temp_junc->position = args.coords;
     temp_line = nullptr;
