@@ -5,7 +5,7 @@ namespace horizon {
 
 class ToolDrawConnectionLine : public ToolBase {
 public:
-    ToolDrawConnectionLine(IDocument *c, ToolID tid);
+    using ToolBase::ToolBase;
     ToolResponse begin(const ToolArgs &args) override;
     ToolResponse update(const ToolArgs &args) override;
     bool can_begin() override;
@@ -20,7 +20,7 @@ public:
     }
 
 private:
-    class Junction *temp_junc = 0;
+    class BoardJunction *temp_junc = 0;
     class ConnectionLine *temp_line = 0;
     class ConnectionLine *temp_line_last = 0;
     class ConnectionLine *temp_line_last2 = 0;
