@@ -5,7 +5,7 @@
 namespace horizon {
 class ToolDrawDimension : public ToolBase, public ToolHelperRestrict {
 public:
-    ToolDrawDimension(IDocument *c, ToolID tid);
+    using ToolBase::ToolBase;
     ToolResponse begin(const ToolArgs &args) override;
     ToolResponse update(const ToolArgs &args) override;
     bool can_begin() override;
@@ -13,15 +13,36 @@ public:
     {
         using I = InToolActionID;
         return {
-                I::LMB, I::CANCEL, I::RMB, I::RESTRICT, I::DIMENSION_MODE, I::ENTER_DATUM,
+                I::LMB, I::CANCEL, I::RMB, I::RESTRICT, I::DIMENSION_MODE, I::ENTER_DATUM, I::ENTER_SIZE,
         };
     }
 
+    class Settings : public ToolSettings {
+    public:
+        json serialize() const override;
+        void load_from_json(const json &j) override;
+        uint64_t label_size = 1.5_mm;
+    };
+
+    const ToolSettings *get_settings_const() const override
+    {
+        return &settings;
+    }
+
+    void apply_settings() override;
+
+protected:
+    ToolSettings *get_settings() override
+    {
+        return &settings;
+    }
+
 private:
     class Dimension *temp = nullptr;
     void update_tip();
 
     enum class State { P0, P1, LABEL };
     State state = State::P0;
+    Settings settings;
 };
 } // namespace horizon
