@@ -7,7 +7,7 @@ namespace horizon {
 
 class ToolDrawLine : public ToolHelperLineWidthSetting, public ToolHelperRestrict {
 public:
-    ToolDrawLine(IDocument *c, ToolID tid);
+    using ToolHelperLineWidthSetting::ToolHelperLineWidthSetting;
     ToolResponse begin(const ToolArgs &args) override;
     ToolResponse update(const ToolArgs &args) override;
     bool can_begin() override;
