@@ -1,16 +1,12 @@
 #include "tool_draw_polygon.hpp"
-#include "document/idocument_padstack.hpp"
-#include "pool/padstack.hpp"
+#include "document/idocument.hpp"
 #include "imp/imp_interface.hpp"
+#include "util/util.hpp"
 #include <iostream>
 #include <sstream>
 
 namespace horizon {
 
-ToolDrawPolygon::ToolDrawPolygon(IDocument *c, ToolID tid) : ToolBase(c, tid)
-{
-}
-
 bool ToolDrawPolygon::can_begin()
 {
     return doc.r->has_object_type(ObjectType::POLYGON);
@@ -22,14 +18,28 @@ ToolResponse ToolDrawPolygon::begin(const ToolArgs &args)
 
     temp = doc.r->insert_polygon(UUID::random());
     temp->layer = args.work_layer;
-    vertex = temp->append_vertex();
-    vertex->position = args.coords;
-    set_snap_filter();
+    append_vertex(args.coords);
 
     update_tip();
     return ToolResponse();
 }
 
+void ToolDrawPolygon::append_vertex(const Coordi &c)
+{
+    vertex = temp->append_vertex();
+    if (temp->vertices.size() >= 2)
+        last_vertex = &temp->vertices.at(temp->vertices.size() - 2);
+    else
+        last_vertex = nullptr;
+    set_snap_filter();
+    cycle_restrict_mode_xy();
+    if (last_vertex)
+        vertex->position = get_coord_restrict(last_vertex->position, c);
+    else
+        vertex->position = c;
+    selection = {{temp->uuid, ObjectType::POLYGON_VERTEX, static_cast<unsigned int>(temp->vertices.size() - 1)}};
+}
+
 void ToolDrawPolygon::set_snap_filter()
 {
     if (arc_mode == ArcMode::CURRENT)
@@ -70,7 +80,8 @@ void ToolDrawPolygon::update_tip()
 void ToolDrawPolygon::update_vertex(const Coordi &c)
 {
     if (arc_mode == ArcMode::CURRENT && last_vertex) {
-        last_vertex->arc_center = c;
+        const auto p = project_onto_perp_bisector(last_vertex->position, vertex->position, c);
+        last_vertex->arc_center = Coordi(p.x, p.y);
     }
     else {
         if (last_vertex == nullptr) {
@@ -93,24 +104,24 @@ ToolResponse ToolDrawPolygon::update(const ToolArgs &args)
         case InToolActionID::LMB:
             if (arc_mode == ArcMode::CURRENT) {
                 arc_mode = ArcMode::OFF;
-                last_vertex = vertex;
-                vertex = temp->append_vertex();
-                set_snap_filter();
-                cycle_restrict_mode_xy();
-                vertex->position = get_coord_restrict(last_vertex->position, args.coords);
+                append_vertex(args.coords);
             }
             else if (arc_mode == ArcMode::NEXT) {
                 arc_mode = ArcMode::CURRENT;
+                selection = {{temp->uuid, ObjectType::POLYGON_ARC_CENTER,
+                              static_cast<unsigned int>(temp->vertices.size() - 2)}};
                 last_vertex->type = Polygon::Vertex::Type::ARC;
                 last_vertex->arc_center = args.coords;
                 set_snap_filter();
             }
             else {
-                last_vertex = vertex;
-                vertex = temp->append_vertex();
-                set_snap_filter();
-                cycle_restrict_mode_xy();
-                vertex->position = get_coord_restrict(last_vertex->position, args.coords);
+                if (temp->vertices.size() > 3 && temp->vertices.front().position == vertex->position) {
+                    // closed cycle
+                    temp->vertices.pop_back();
+                    return commit();
+                }
+
+                append_vertex(args.coords);
             }
             break;
 
@@ -119,9 +130,9 @@ ToolResponse ToolDrawPolygon::update(const ToolArgs &args)
             temp->vertices.pop_back();
             vertex = nullptr;
             if (!temp->is_valid()) {
-                doc.r->delete_polygon(temp->uuid);
+                return ToolResponse::revert();
             }
-            return ToolResponse::commit();
+            return commit();
             break;
 
         case InToolActionID::TOGGLE_ARC:
@@ -155,4 +166,10 @@ ToolResponse ToolDrawPolygon::update(const ToolArgs &args)
     update_tip();
     return ToolResponse();
 }
+
+ToolResponse ToolDrawPolygon::commit()
+{
+    return ToolResponse::commit();
+}
+
 } // namespace horizon
