@@ -7,7 +7,7 @@ namespace horizon {
 
 class ToolDrawPolygon : public ToolBase, public ToolHelperRestrict {
 public:
-    ToolDrawPolygon(IDocument *c, ToolID tid);
+    using ToolBase::ToolBase;
     ToolResponse begin(const ToolArgs &args) override;
     ToolResponse update(const ToolArgs &args) override;
     bool can_begin() override;
@@ -19,8 +19,11 @@ public:
         };
     }
 
-private:
+protected:
     Polygon *temp = nullptr;
+    virtual ToolResponse commit();
+
+private:
     Polygon::Vertex *vertex = nullptr;
     Polygon::Vertex *last_vertex = nullptr;
     enum class ArcMode { OFF, NEXT, CURRENT };
@@ -28,5 +31,6 @@ private:
     void update_tip();
     void update_vertex(const Coordi &c);
     void set_snap_filter();
+    void append_vertex(const Coordi &c);
 };
 } // namespace horizon
