@@ -6,10 +6,6 @@
 
 namespace horizon {
 
-ToolEditBoardHole::ToolEditBoardHole(IDocument *c, ToolID tid) : ToolBase(c, tid)
-{
-}
-
 bool ToolEditBoardHole::can_begin()
 {
     return get_holes().size() > 0;
@@ -29,7 +25,7 @@ std::set<BoardHole *> ToolEditBoardHole::get_holes()
 ToolResponse ToolEditBoardHole::begin(const ToolArgs &args)
 {
     auto holes = get_holes();
-    auto r = imp->dialogs.edit_board_hole(holes, doc.r->get_pool(), doc.b->get_block());
+    auto r = imp->dialogs.edit_board_hole(holes, doc.r->get_pool(), *doc.b->get_block());
     if (r) {
         return ToolResponse::commit();
     }
