@@ -5,6 +5,8 @@
 #include "document/idocument_padstack.hpp"
 #include "pool/padstack.hpp"
 #include "document/idocument_schematic.hpp"
+#include "document/idocument_board.hpp"
+#include "board/board.hpp"
 #include "schematic/schematic.hpp"
 #include "imp/imp_interface.hpp"
 #include "util/accumulator.hpp"
@@ -13,10 +15,6 @@
 
 namespace horizon {
 
-ToolEnterDatum::ToolEnterDatum(IDocument *c, ToolID tid) : ToolBase(c, tid)
-{
-}
-
 template <typename T> T sgn(T x)
 {
     if (x < 0)
@@ -283,7 +281,7 @@ ToolResponse ToolEnterDatum::begin(const ToolArgs &args)
         Pad *pad = nullptr;
         for (const auto &it : args.selection) {
             if (it.type == ObjectType::PAD) {
-                pad = &doc.k->get_package()->pads.at(it.uuid);
+                pad = &doc.k->get_package().pads.at(it.uuid);
                 break;
             }
         }
@@ -292,7 +290,7 @@ ToolResponse ToolEnterDatum::begin(const ToolArgs &args)
         if (auto r = imp->dialogs.ask_datum_string("Enter pad name", pad->name)) {
             for (const auto &it : args.selection) {
                 if (it.type == ObjectType::PAD) {
-                    doc.k->get_package()->pads.at(it.uuid).name = *r;
+                    doc.k->get_package().pads.at(it.uuid).name = *r;
                 }
             }
         }
@@ -439,6 +437,9 @@ ToolResponse ToolEnterDatum::begin(const ToolArgs &args)
         return ToolResponse::end();
     }
 
+    if (doc.b) {
+        doc.b->get_board()->update_airwires(false, nets_from_selection(selection));
+    }
 
     return ToolResponse::commit();
 }
