@@ -1,12 +1,12 @@
 #pragma once
 #include "core/tool.hpp"
-#include <forward_list>
+#include "tool_helper_collect_nets.hpp"
 
 namespace horizon {
 
-class ToolEnterDatum : public ToolBase {
+class ToolEnterDatum : public virtual ToolBase, public ToolHelperCollectNets {
 public:
-    ToolEnterDatum(IDocument *c, ToolID tid);
+    using ToolBase::ToolBase;
     ToolResponse begin(const ToolArgs &args) override;
     ToolResponse update(const ToolArgs &args) override;
     bool can_begin() override;
