@@ -1,13 +1,12 @@
 #pragma once
 #include "core/tool.hpp"
-#include "pool/package.hpp"
-#include <set>
+#include "clipper/clipper.hpp"
 
 namespace horizon {
 
 class ToolGenerateSilkscreen : public ToolBase {
 public:
-    ToolGenerateSilkscreen(IDocument *c, ToolID tid);
+    using ToolBase::ToolBase;
     ToolResponse begin(const ToolArgs &args) override;
     ToolResponse update(const ToolArgs &args) override;
     bool can_begin() override;
@@ -15,10 +14,6 @@ public:
     {
         return false;
     }
-    bool handles_esc() override
-    {
-        return true;
-    }
 
     class Settings : public ToolSettings {
     public:
@@ -35,6 +30,15 @@ public:
         return &settings;
     }
 
+    std::set<InToolActionID> get_actions() const override
+    {
+        using I = InToolActionID;
+        return {
+                I::LMB,
+                I::CANCEL,
+        };
+    }
+
 protected:
     ToolSettings *get_settings() override
     {
@@ -49,7 +53,7 @@ private:
 
     class GenerateSilkscreenWindow *win = nullptr;
     Settings settings;
-    const Polygon *pp;
+    const class Polygon *pp;
     bool package_visible;
     ClipperLib::Path path_pkg;
     ClipperLib::Paths pads;
