@@ -4,9 +4,7 @@
 namespace horizon {
 class ToolHelperMerge : public virtual ToolBase {
 public:
-    ToolHelperMerge(class IDocument *c, ToolID tid) : ToolBase(c, tid)
-    {
-    }
+    using ToolBase::ToolBase;
 
 protected:
     bool merge_bus_net(class Net *net, class Bus *bus, class Net *net_other, class Bus *bus_other);
