@@ -6,7 +6,7 @@ namespace horizon {
 
 class ToolImportDXF : public ToolHelperMove {
 public:
-    ToolImportDXF(IDocument *c, ToolID tid);
+    using ToolHelperMove::ToolHelperMove;
     ToolResponse begin(const ToolArgs &args) override;
     ToolResponse update(const ToolArgs &args) override;
     bool can_begin() override;
