@@ -6,9 +6,6 @@
 #include <iostream>
 
 namespace horizon {
-ToolMapPackage::ToolMapPackage(IDocument *c, ToolID tid) : ToolBase(c, tid), ToolHelperMove(c, tid)
-{
-}
 
 bool ToolMapPackage::can_begin()
 {
@@ -100,14 +97,15 @@ void ToolMapPackage::place_package(Component *comp, const Coordi &c)
     pkg->placement.shift = c;
     pkg->flip = flipped;
     pkg->placement.set_angle(angle);
-    brd->packages_expand = {uu};
-    brd->expand_flags = static_cast<Board::ExpandFlags>(Board::EXPAND_PACKAGES | Board::EXPAND_AIRWIRES);
-    brd->expand(true);
+    pkg->update(*brd);
+
     nets.clear();
     for (const auto &it : pkg->package.pads) {
         if (it.second.net)
             nets.insert(it.second.net->uuid);
     }
+    all_nets.insert(nets.begin(), nets.end());
+    brd->update_airwires(true, nets);
     selection.clear();
     selection.emplace(uu, ObjectType::BOARD_PACKAGE);
     update_tooltip();
@@ -142,6 +140,7 @@ ToolResponse ToolMapPackage::update(const ToolArgs &args)
                 component_index++;
             }
             if (component_index == components.size()) {
+                doc.b->get_board()->update_airwires(false, all_nets);
                 return ToolResponse::commit();
             }
             Component *comp = components.at(component_index).first;
@@ -153,6 +152,7 @@ ToolResponse ToolMapPackage::update(const ToolArgs &args)
             if (pkg) {
                 doc.b->get_board()->packages.erase(pkg->uuid);
             }
+            doc.b->get_board()->update_airwires(false, all_nets);
             return ToolResponse::commit();
 
         case InToolActionID::EDIT:
