@@ -5,7 +5,7 @@
 namespace horizon {
 class ToolMapPackage : public ToolHelperMove {
 public:
-    ToolMapPackage(IDocument *c, ToolID tid);
+    using ToolHelperMove::ToolHelperMove;
     ToolResponse begin(const ToolArgs &args) override;
     ToolResponse update(const ToolArgs &args) override;
     bool can_begin() override;
@@ -22,6 +22,7 @@ private:
     unsigned int component_index = 0;
     class BoardPackage *pkg = nullptr;
     std::set<UUID> nets;
+    std::set<UUID> all_nets;
     void place_package(Component *comp, const Coordi &c);
     void update_tooltip();
     bool flipped = false;
