@@ -10,7 +10,7 @@
 #include "imp/imp_interface.hpp"
 #include "pool/entity.hpp"
 #include "util/util.hpp"
-#include "core/buffer.hpp"
+#include "core/clipboard/clipboard.hpp"
 #include <iostream>
 #include <gtkmm.h>
 #include "core/tool_id.hpp"
@@ -358,8 +358,7 @@ ToolResponse ToolPaste::begin_paste(const json &j, const Coordi &cursor_pos_canv
                               .first->second;
             if (auto ps = doc.b->get_via_padstack_provider().get_padstack(x->vpp_padstack.uuid)) {
                 x->vpp_padstack = ps;
-                x->padstack = *ps;
-                x->padstack.apply_parameter_set(x->parameter_set);
+                x->expand(*brd);
             }
             if (brd->block->nets.count(x->net_set.uuid)) {
                 x->net_set = &brd->block->nets.at(x->net_set.uuid);
@@ -429,7 +428,7 @@ ToolResponse ToolPaste::begin_paste(const json &j, const Coordi &cursor_pos_canv
             auto brd = doc.b->get_board();
             auto &x = brd->decals
                               .emplace(std::piecewise_construct, std::forward_as_tuple(u),
-                                       std::forward_as_tuple(u, it.value(), doc.r->get_pool()))
+                                       std::forward_as_tuple(u, it.value(), doc.r->get_pool(), *brd))
                               .first->second;
             apply_shift(x.placement.shift, cursor_pos_canvas);
             selection.emplace(u, ObjectType::BOARD_DECAL);
@@ -467,9 +466,8 @@ ToolResponse ToolPaste::begin(const ToolArgs &args)
     }
 
     if (tool_id == ToolID::DUPLICATE) {
-        Buffer buffer(doc);
-        buffer.load(args.selection);
-        paste_data = buffer.serialize();
+        auto clip = ClipboardBase::create(*doc.r);
+        paste_data = clip->process(args.selection);
         paste_data["cursor_pos"] = args.coords.as_array();
         return begin_paste(paste_data, args.coords);
     }
