@@ -9,7 +9,7 @@
 namespace horizon {
 
 ToolPlaceBusRipper::ToolPlaceBusRipper(IDocument *c, ToolID tid)
-    : ToolBase(c, tid), ToolPlaceJunction(c, tid), ToolHelperMove(c, tid)
+    : ToolBase(c, tid), ToolPlaceJunctionSchematic(c, tid), ToolHelperMove(c, tid)
 {
 }
 
@@ -20,7 +20,7 @@ bool ToolPlaceBusRipper::can_begin()
 
 bool ToolPlaceBusRipper::begin_attached()
 {
-    if (auto r = imp->dialogs.select_bus(doc.c->get_schematic()->block)) {
+    if (auto r = imp->dialogs.select_bus(*doc.c->get_schematic()->block)) {
         imp->tool_bar_set_actions({
                 {InToolActionID::LMB},
                 {InToolActionID::RMB},
@@ -82,7 +82,7 @@ bool ToolPlaceBusRipper::update_attached(const ToolArgs &args)
         switch (args.action) {
         case InToolActionID::LMB:
             if (args.target.type == ObjectType::JUNCTION) {
-                Junction *j = doc.r->get_junction(args.target.path.at(0));
+                SchematicJunction *j = &doc.c->get_sheet()->junctions.at(args.target.path.at(0));
                 if (j->bus != bus) {
                     imp->tool_bar_flash("junction connected to wrong bus");
                     return true;
@@ -112,7 +112,7 @@ bool ToolPlaceBusRipper::update_attached(const ToolArgs &args)
             return true;
 
         case InToolActionID::EDIT:
-            if (auto r = imp->dialogs.select_bus_member(doc.c->get_schematic()->block, bus->uuid)) {
+            if (auto r = imp->dialogs.select_bus_member(*doc.c->get_schematic()->block, bus->uuid)) {
                 Bus::Member *bus_member = &bus->members.at(*r);
 
                 auto p = std::find(bus_members.begin(), bus_members.end(), bus_member);
