@@ -1,14 +1,14 @@
 #pragma once
 #include "core/tool.hpp"
-#include "schematic/power_symbol.hpp"
-#include "tool_place_junction.hpp"
+#include "tool_place_junction_schematic.hpp"
 #include <forward_list>
 
 namespace horizon {
 
-class ToolPlacePowerSymbol : public ToolPlaceJunction {
+class ToolPlacePowerSymbol : public ToolPlaceJunctionSchematic {
 public:
-    ToolPlacePowerSymbol(IDocument *c, ToolID tid);
+    using ToolPlaceJunctionSchematic::ToolPlaceJunctionSchematic;
+
     bool can_begin() override;
     std::set<InToolActionID> get_actions() const override
     {
@@ -24,7 +24,7 @@ protected:
     bool begin_attached() override;
     bool update_attached(const ToolArgs &args) override;
     bool check_line(LineNet *li) override;
-    PowerSymbol *sym = nullptr;
+    class PowerSymbol *sym = nullptr;
     std::forward_list<PowerSymbol *> symbols_placed;
     Net *net = nullptr;
 
