@@ -7,10 +7,6 @@
 
 namespace horizon {
 
-ToolPlaceVia::ToolPlaceVia(IDocument *c, ToolID tid) : ToolBase(c, tid), ToolPlaceJunction(c, tid)
-{
-}
-
 bool ToolPlaceVia::can_begin()
 {
     return doc.b;
@@ -19,8 +15,9 @@ bool ToolPlaceVia::can_begin()
 bool ToolPlaceVia::begin_attached()
 {
     rules = dynamic_cast<BoardRules *>(doc.b->get_rules());
-    if (auto r = imp->dialogs.select_net(doc.b->get_block(), false)) {
+    if (auto r = imp->dialogs.select_net(*doc.b->get_block(), false)) {
         net = doc.b->get_block()->get_net(*r);
+        nets.insert(net->uuid);
         auto ps_uu = rules->get_via_padstack_uuid(net);
         if (!ps_uu) {
             Logger::log_warning("Didn't find a via for net " + net->name, Logger::Domain::TOOL,
@@ -40,10 +37,16 @@ bool ToolPlaceVia::begin_attached()
     }
 }
 
+void ToolPlaceVia::insert_junction()
+{
+    const auto uu = UUID::random();
+    temp = &doc.b->get_board()->junctions.emplace(uu, uu).first->second;
+}
+
 void ToolPlaceVia::create_attached()
 {
     auto uu = UUID::random();
-    auto ps = doc.b->get_via_padstack_provider()->get_padstack(rules->get_via_padstack_uuid(net));
+    auto ps = doc.b->get_via_padstack_provider().get_padstack(rules->get_via_padstack_uuid(net));
     if (!ps) {
         throw std::runtime_error("padstack not found");
     }
@@ -53,6 +56,7 @@ void ToolPlaceVia::create_attached()
     via->junction = temp;
     via->from_rules = true;
     via->net_set = net;
+    via->junction->net = net;
     via->parameter_set = rules->get_via_parameter_set(net);
     via->expand(*doc.b->get_board());
 }
@@ -69,13 +73,19 @@ void ToolPlaceVia::update_tip()
     imp->tool_bar_set_tip(net->name);
 }
 
+void ToolPlaceVia::finish()
+{
+    doc.b->get_board()->airwires_expand = nets;
+    doc.b->get_board()->expand_flags = Board::EXPAND_PROPAGATE_NETS | Board::EXPAND_AIRWIRES;
+}
+
 bool ToolPlaceVia::update_attached(const ToolArgs &args)
 {
     if (args.type == ToolEventType::ACTION) {
         switch (args.action) {
         case InToolActionID::LMB:
             if (args.target.type == ObjectType::JUNCTION) {
-                Junction *j = doc.r->get_junction(args.target.path.at(0));
+                auto j = &doc.b->get_board()->junctions.at(args.target.path.at(0));
                 via->junction = j;
                 create_attached();
                 return true;
@@ -84,8 +94,9 @@ bool ToolPlaceVia::update_attached(const ToolArgs &args)
 
         case InToolActionID::EDIT:
             if (via) {
-                if (auto r = imp->dialogs.select_net(doc.b->get_block(), false)) {
+                if (auto r = imp->dialogs.select_net(*doc.b->get_block(), false)) {
                     net = doc.b->get_block()->get_net(*r);
+                    nets.insert(net->uuid);
                     via->net_set = net;
                     via->parameter_set = rules->get_via_parameter_set(net);
                     via->expand(*doc.b->get_board());
