@@ -2,12 +2,13 @@
 #include "core/tool.hpp"
 #include "canvas/selectables.hpp"
 #include "util/placement.hpp"
+#include "tool_helper_collect_nets.hpp"
 
 namespace horizon {
 
-class ToolRotateArbitrary : public ToolBase {
+class ToolRotateArbitrary : public virtual ToolBase, public ToolHelperCollectNets {
 public:
-    ToolRotateArbitrary(IDocument *c, ToolID tid);
+    using ToolBase::ToolBase;
     ToolResponse begin(const ToolArgs &args) override;
     ToolResponse update(const ToolArgs &args) override;
     bool can_begin() override;
@@ -38,6 +39,9 @@ private:
     enum class State { ORIGIN, ROTATE, REF, SCALE };
     State state = State::ORIGIN;
     std::map<SelectableRef, Placement> placements;
+    std::map<UUID, double> decal_scales;
     class CanvasAnnotation *annotation = nullptr;
+    std::set<UUID> nets;
+    void update_airwires(bool fast);
 };
 } // namespace horizon
