@@ -1,13 +1,12 @@
 #pragma once
 #include "common/polygon.hpp"
-#include "core/tool.hpp"
-#include <forward_list>
+#include "tool_helper_plane.hpp"
 
 namespace horizon {
 
-class ToolRoundOffVertex : public ToolBase {
+class ToolRoundOffVertex : public virtual ToolBase, public ToolHelperPlane {
 public:
-    ToolRoundOffVertex(IDocument *c, ToolID tid);
+    using ToolBase::ToolBase;
     ToolResponse begin(const ToolArgs &args) override;
     ToolResponse update(const ToolArgs &args) override;
     bool can_begin() override;
