@@ -40,10 +40,6 @@ public:
     ToolRouteTrackInteractive *tool = nullptr;
 };
 
-ToolRouteTrackInteractive::ToolRouteTrackInteractive(IDocument *c, ToolID tid) : ToolBase(c, tid)
-{
-}
-
 const std::map<ToolRouteTrackInteractive::Settings::Mode, std::string> ToolRouteTrackInteractive::Settings::mode_names =
         {{ToolRouteTrackInteractive::Settings::Mode::BEND, "45 degree"},
          {ToolRouteTrackInteractive::Settings::Mode::STRAIGHT, "Straight"},
@@ -670,8 +666,6 @@ ToolResponse ToolRouteTrackInteractive::update(const ToolArgs &args)
                 if (router->FixRoute(wrapper->m_endSnapPoint, wrapper->m_endItem)) {
                     router->StopRouting();
                     imp->canvas_update();
-                    board->expand_flags =
-                            static_cast<Board::ExpandFlags>(Board::EXPAND_PROPAGATE_NETS | Board::EXPAND_AIRWIRES);
                     return ToolResponse::commit();
                 }
             }
@@ -692,8 +686,6 @@ ToolResponse ToolRouteTrackInteractive::update(const ToolArgs &args)
             case InToolActionID::LMB:
                 if (router->FixRoute(VECTOR2I(args.coords.x, args.coords.y), NULL)) {
                     router->StopRouting();
-                    board->expand_flags =
-                            static_cast<Board::ExpandFlags>(Board::EXPAND_PROPAGATE_NETS | Board::EXPAND_AIRWIRES);
                     return ToolResponse::commit();
                 }
                 break;
@@ -792,8 +784,6 @@ ToolResponse ToolRouteTrackInteractive::update(const ToolArgs &args)
 
                 case InToolActionID::RMB:
                 case InToolActionID::CANCEL:
-                    board->expand_flags =
-                            static_cast<Board::ExpandFlags>(Board::EXPAND_PROPAGATE_NETS | Board::EXPAND_AIRWIRES);
                     return ToolResponse::commit();
 
                 default:;
@@ -855,8 +845,6 @@ ToolResponse ToolRouteTrackInteractive::update(const ToolArgs &args)
 
                 case InToolActionID::CANCEL:
                     router->StopRouting();
-                    board->expand_flags =
-                            static_cast<Board::ExpandFlags>(Board::EXPAND_PROPAGATE_NETS | Board::EXPAND_AIRWIRES);
                     return ToolResponse::commit();
 
                 case InToolActionID::POSTURE:
