@@ -19,7 +19,7 @@
 #include "annotate.hpp"
 #include "pool/part.hpp"
 #include "edit_shape.hpp"
-#include "edit_pad_parameter_set.hpp"
+#include "pad_parameter_set_window.hpp"
 #include "schematic_properties.hpp"
 #include "edit_via.hpp"
 #include "edit_plane.hpp"
@@ -35,6 +35,8 @@
 #include "select_included_board.hpp"
 #include "manage_included_boards.hpp"
 #include "enter_datum_window.hpp"
+#include "enter_datum_angle_window.hpp"
+#include "enter_datum_scale_window.hpp"
 #include "router_settings_window.hpp"
 #include <glibmm.h>
 #include "pool/ipool.hpp"
@@ -251,12 +253,6 @@ bool Dialogs::annotate(Schematic &s)
     return dia.run() == Gtk::RESPONSE_OK;
 }
 
-bool Dialogs::edit_pad_parameter_set(std::set<class Pad *> &pads, IPool &pool, class Package &pkg)
-{
-    PadParameterSetDialog dia(parent, pads, pool, pkg);
-    return dia.run() == Gtk::RESPONSE_OK;
-}
-
 bool Dialogs::edit_board_hole(std::set<class BoardHole *> &holes, IPool &pool, Block &block)
 {
     BoardHoleDialog dia(parent, holes, pool, block);
@@ -523,11 +519,9 @@ class GenerateSilkscreenWindow *Dialogs::show_generate_silkscreen_window(class T
 
 EnterDatumWindow *Dialogs::show_enter_datum_window(const std::string &label, int64_t def)
 {
-    if (window_nonmodal) {
-        if (auto win = dynamic_cast<EnterDatumWindow *>(window_nonmodal)) {
-            win->present();
-            return win;
-        }
+    if (auto win = dynamic_cast<EnterDatumWindow *>(window_nonmodal)) {
+        win->present();
+        return win;
     }
     auto win = new EnterDatumWindow(parent, interface, label, def);
     window_nonmodal = win;
@@ -536,13 +530,37 @@ EnterDatumWindow *Dialogs::show_enter_datum_window(const std::string &label, int
     return win;
 }
 
+EnterDatumAngleWindow *Dialogs::show_enter_datum_angle_window(const std::string &label, uint16_t def)
+{
+    if (auto win = dynamic_cast<EnterDatumAngleWindow *>(window_nonmodal)) {
+        win->present();
+        return win;
+    }
+    auto win = new EnterDatumAngleWindow(parent, interface, label, def);
+    window_nonmodal = win;
+    win->signal_hide().connect([this] { close_nonmodal(); });
+    win->present();
+    return win;
+}
+
+EnterDatumScaleWindow *Dialogs::show_enter_datum_scale_window(const std::string &label, double def)
+{
+    if (auto win = dynamic_cast<EnterDatumScaleWindow *>(window_nonmodal)) {
+        win->present();
+        return win;
+    }
+    auto win = new EnterDatumScaleWindow(parent, interface, label, def);
+    window_nonmodal = win;
+    win->signal_hide().connect([this] { close_nonmodal(); });
+    win->present();
+    return win;
+}
+
 RouterSettingsWindow *Dialogs::show_router_settings_window(ToolSettings &settings)
 {
-    if (window_nonmodal) {
-        if (auto win = dynamic_cast<RouterSettingsWindow *>(window_nonmodal)) {
-            win->present();
-            return win;
-        }
+    if (auto win = dynamic_cast<RouterSettingsWindow *>(window_nonmodal)) {
+        win->present();
+        return win;
     }
     auto win = new RouterSettingsWindow(parent, interface, settings);
     window_nonmodal = win;
@@ -551,6 +569,20 @@ RouterSettingsWindow *Dialogs::show_router_settings_window(ToolSettings &setting
     return win;
 }
 
+PadParameterSetWindow *Dialogs::show_pad_parameter_set_window(std::set<class Pad *> &pads, class IPool &pool,
+                                                              class Package &pkg)
+{
+    if (auto win = dynamic_cast<PadParameterSetWindow *>(window_nonmodal)) {
+        win->present();
+        return win;
+    }
+    auto win = new PadParameterSetWindow(parent, interface, pads, pool, pkg);
+    window_nonmodal = win;
+    win->signal_hide().connect([this] { close_nonmodal(); });
+    win->present();
+    return win;
+}
+
 void Dialogs::close_nonmodal()
 {
     delete window_nonmodal;
