@@ -16,7 +16,7 @@ public:
 private:
     class IPool &pool;
     class Block &block;
-    class MyParameterSetEditor *editor = nullptr;
+    class ParameterSetEditor *editor = nullptr;
     class PoolBrowserButton *padstack_button = nullptr;
     class NetButton *net_button = nullptr;
 };
