@@ -1,9 +1,10 @@
 #include "schematic_properties.hpp"
 #include "schematic/schematic.hpp"
 #include "widgets/pool_browser_button.hpp"
+#include "widgets/pool_browser.hpp"
 #include "widgets/title_block_values_editor.hpp"
 #include "widgets/project_meta_editor.hpp"
-#include "pool/pool.hpp"
+#include "pool/ipool.hpp"
 #include <iostream>
 #include <deque>
 #include <algorithm>
@@ -12,11 +13,11 @@ namespace horizon {
 
 class SheetEditor : public Gtk::Box {
 public:
-    SheetEditor(Sheet *s, Schematic *c, Pool *pool);
+    SheetEditor(Sheet &s, Schematic &c, IPool &pool);
 
 private:
     Gtk::Grid *grid = nullptr;
-    Sheet *sheet;
+    Sheet &sheet;
     int top = 0;
     void append_widget(const std::string &label, Gtk::Widget *w);
 };
@@ -34,7 +35,7 @@ void SheetEditor::append_widget(const std::string &label, Gtk::Widget *w)
     top++;
 }
 
-SheetEditor::SheetEditor(Sheet *s, Schematic *c, Pool *pool) : Gtk::Box(Gtk::ORIENTATION_VERTICAL, 0), sheet(s)
+SheetEditor::SheetEditor(Sheet &s, Schematic &c, IPool &pool) : Gtk::Box(Gtk::ORIENTATION_VERTICAL, 0), sheet(s)
 {
     grid = Gtk::manage(new Gtk::Grid);
     grid->set_column_spacing(10);
@@ -45,10 +46,10 @@ SheetEditor::SheetEditor(Sheet *s, Schematic *c, Pool *pool) : Gtk::Box(Gtk::ORI
     grid->set_margin_start(20);
 
     auto title_entry = Gtk::manage(new Gtk::Entry());
-    title_entry->set_text(s->name);
+    title_entry->set_text(s.name);
     title_entry->signal_changed().connect([this, title_entry] {
         auto ti = title_entry->get_text();
-        sheet->name = ti;
+        sheet.name = ti;
         auto stack = dynamic_cast<Gtk::Stack *>(get_ancestor(GTK_TYPE_STACK));
         stack->child_property_title(*this) = "Sheet " + ti;
     });
@@ -56,10 +57,15 @@ SheetEditor::SheetEditor(Sheet *s, Schematic *c, Pool *pool) : Gtk::Box(Gtk::ORI
     append_widget("Title", title_entry);
 
     auto frame_button = Gtk::manage(new PoolBrowserButton(ObjectType::FRAME, pool));
-    if (sheet->pool_frame)
-        frame_button->property_selected_uuid() = sheet->pool_frame->uuid;
-    frame_button->property_selected_uuid().signal_changed().connect([this, frame_button, pool] {
-        sheet->pool_frame = pool->get_frame(frame_button->property_selected_uuid());
+    frame_button->get_browser().set_show_none(true);
+    if (sheet.pool_frame)
+        frame_button->property_selected_uuid() = sheet.pool_frame->uuid;
+    frame_button->property_selected_uuid().signal_changed().connect([this, frame_button, &pool] {
+        UUID uu = frame_button->property_selected_uuid();
+        if (uu)
+            sheet.pool_frame = pool.get_frame(uu);
+        else
+            sheet.pool_frame = nullptr;
     });
     append_widget("Frame", frame_button);
 
@@ -67,12 +73,12 @@ SheetEditor::SheetEditor(Sheet *s, Schematic *c, Pool *pool) : Gtk::Box(Gtk::ORI
     grid->show();
 
 
-    auto ed = Gtk::manage(new TitleBlockValuesEditor(sheet->title_block_values));
+    auto ed = Gtk::manage(new TitleBlockValuesEditor(sheet.title_block_values));
     pack_start(*ed, true, true, 0);
     ed->show();
 }
 
-SchematicPropertiesDialog::SchematicPropertiesDialog(Gtk::Window *parent, Schematic *c, Pool *pool)
+SchematicPropertiesDialog::SchematicPropertiesDialog(Gtk::Window *parent, Schematic &c, IPool &pool)
     : Gtk::Dialog("Schematic properties", *parent,
                   Gtk::DialogFlags::DIALOG_MODAL | Gtk::DialogFlags::DIALOG_USE_HEADER_BAR),
       sch(c)
@@ -94,19 +100,19 @@ SchematicPropertiesDialog::SchematicPropertiesDialog(Gtk::Window *parent, Schema
     box->pack_start(*stack, true, true, 0);
 
     {
-        auto ed = Gtk::manage(new ProjectMetaEditor(sch->block->project_meta));
+        auto ed = Gtk::manage(new ProjectMetaEditor(sch.block->project_meta));
         ed->property_margin() = 20;
         ed->show();
         stack->add(*ed, "global", "Global");
     }
 
     std::vector<Sheet *> sheets;
-    for (auto &it : sch->sheets) {
+    for (auto &it : sch.sheets) {
         sheets.push_back(&it.second);
     }
     std::sort(sheets.begin(), sheets.end(), [](auto a, auto b) { return a->index < b->index; });
     for (auto &it : sheets) {
-        auto ed = Gtk::manage(new SheetEditor(it, sch, pool));
+        auto ed = Gtk::manage(new SheetEditor(*it, sch, pool));
         stack->add(*ed, (std::string)it->uuid, "Sheet " + it->name);
     }
 
