@@ -48,12 +48,14 @@ public:
 
     virtual class Block *get_block() = 0;
     virtual class Rules *get_rules() = 0;
-    virtual class Pool *get_pool() = 0;
-    virtual class LayerProvider *get_layer_provider() = 0;
+    virtual class IPool &get_pool() = 0;
+    virtual class LayerProvider &get_layer_provider() = 0;
 
     virtual std::string get_display_name(ObjectType type, const UUID &uu) = 0;
     virtual std::string get_display_name(ObjectType type, const UUID &uu, const UUID &sheet) = 0;
 
+    virtual const class FileVersion &get_version() const = 0;
+
     virtual ~IDocument()
     {
     }
