@@ -7,20 +7,20 @@
 #include "board/board_layers.hpp"
 
 namespace horizon {
-GerberExporter::GerberExporter(const Board *b, const FabOutputSettings *s) : brd(b), settings(s)
+GerberExporter::GerberExporter(const Board &b, const FabOutputSettings &s) : brd(b), settings(s)
 {
 
-    for (const auto &it : settings->layers) {
-        if (brd->get_layers().count(it.first) && it.second.enabled)
+    for (const auto &it : settings.layers) {
+        if (brd.get_layers().count(it.first) && it.second.enabled)
             writers.emplace(it.first,
-                            Glib::build_filename(settings->output_directory, settings->prefix + it.second.filename));
+                            Glib::build_filename(settings.output_directory, settings.prefix + it.second.filename));
     }
 
     drill_writer_pth = std::make_unique<ExcellonWriter>(
-            Glib::build_filename(settings->output_directory, settings->prefix + settings->drill_pth_filename));
-    if (settings->drill_mode == FabOutputSettings::DrillMode::INDIVIDUAL) {
+            Glib::build_filename(settings.output_directory, settings.prefix + settings.drill_pth_filename));
+    if (settings.drill_mode == FabOutputSettings::DrillMode::INDIVIDUAL) {
         drill_writer_npth = std::make_unique<ExcellonWriter>(
-                Glib::build_filename(settings->output_directory, settings->prefix + settings->drill_npth_filename));
+                Glib::build_filename(settings.output_directory, settings.prefix + settings.drill_npth_filename));
     }
     else {
         drill_writer_npth = nullptr;
@@ -29,9 +29,9 @@ GerberExporter::GerberExporter(const Board *b, const FabOutputSettings *s) : brd
 
 void GerberExporter::generate()
 {
-    CanvasGerber ca(this);
-    ca.outline_width = settings->outline_width;
-    ca.update(*brd);
+    CanvasGerber ca(*this);
+    ca.outline_width = settings.outline_width;
+    ca.update(brd);
 
     for (auto &it : writers) {
         it.second.write_format();
@@ -41,7 +41,7 @@ void GerberExporter::generate()
         it.second.write_arcs();
         it.second.write_pads();
         it.second.close();
-        log << "Wrote layer " << brd->get_layers().at(it.first).name << " to gerber file " << it.second.get_filename()
+        log << "Wrote layer " << brd.get_layers().at(it.first).name << " to gerber file " << it.second.get_filename()
             << std::endl;
     }
     for (auto it : {drill_writer_npth.get(), drill_writer_pth.get()}) {
@@ -54,14 +54,14 @@ void GerberExporter::generate()
         }
     }
 
-    if (settings->zip_output) {
+    if (settings.zip_output) {
         generate_zip();
     }
 }
 
 void GerberExporter::generate_zip()
 {
-    std::string zip_file = Glib::build_filename(settings->output_directory, settings->prefix + ".zip");
+    std::string zip_file = Glib::build_filename(settings.output_directory, settings.prefix + ".zip");
     libzip::archive zip(zip_file, ZIP_CREATE);
 
     for (int64_t i = 0; i < zip.num_entries(); i++) {
@@ -98,7 +98,7 @@ GerberWriter *GerberExporter::get_writer_for_layer(int l)
 
 ExcellonWriter *GerberExporter::get_drill_writer(bool pth)
 {
-    if (settings->drill_mode == FabOutputSettings::DrillMode::MERGED) {
+    if (settings.drill_mode == FabOutputSettings::DrillMode::MERGED) {
         return drill_writer_pth.get();
     }
     else {
