@@ -24,15 +24,15 @@ const std::map<ActionToolID, ActionCatalogItem> action_catalog = {
 
         {{ActionID::FLIP_VIEW, ToolID::NONE},
          {"Flip view", ActionGroup::VIEW, ActionCatalogItem::AVAILABLE_IN_PACKAGE_AND_BOARD,
-          ActionCatalogItem::FLAGS_DEFAULT}},
+          ActionCatalogItem::FLAGS_IN_TOOL}},
 
         {{ActionID::VIEW_TOP, ToolID::NONE},
          {"View top", ActionGroup::VIEW, ActionCatalogItem::AVAILABLE_IN_PACKAGE_AND_BOARD,
-          ActionCatalogItem::FLAGS_DEFAULT}},
+          ActionCatalogItem::FLAGS_IN_TOOL}},
 
         {{ActionID::VIEW_BOTTOM, ToolID::NONE},
          {"View bottom", ActionGroup::VIEW, ActionCatalogItem::AVAILABLE_IN_PACKAGE_AND_BOARD,
-          ActionCatalogItem::FLAGS_DEFAULT}},
+          ActionCatalogItem::FLAGS_IN_TOOL}},
 
         {{ActionID::LAYER_DOWN, ToolID::NONE},
          {"Layer down", ActionGroup::LAYER, ActionCatalogItem::AVAILABLE_LAYERED, ActionCatalogItem::FLAGS_IN_TOOL}},
@@ -147,7 +147,8 @@ const std::map<ActionToolID, ActionCatalogItem> action_catalog = {
 
         {{ActionID::RULES_RUN_CHECKS, ToolID::NONE},
          {"Run checks", ActionGroup::RULES,
-          ActionCatalogItem::AVAILABLE_IN_SCHEMATIC_AND_BOARD | ActionCatalogItem::AVAILABLE_IN_PACKAGE,
+          ActionCatalogItem::AVAILABLE_IN_SCHEMATIC_AND_BOARD | ActionCatalogItem::AVAILABLE_IN_PACKAGE
+                  | ActionCatalogItem::AVAILABLE_IN_SYMBOL,
           ActionCatalogItem::FLAGS_DEFAULT}},
 
         {{ActionID::SHOW_IN_BROWSER, ToolID::NONE},
@@ -626,7 +627,8 @@ const std::map<ActionToolID, ActionCatalogItem> action_catalog = {
 
         {{ActionID::RELOAD_POOL, ToolID::NONE},
          {"Reload pool", ActionGroup::UNKNOWN,
-          ActionCatalogItem::AVAILABLE_IN_PACKAGE | ActionCatalogItem::AVAILABLE_IN_SYMBOL,
+          ActionCatalogItem::AVAILABLE_IN_PACKAGE | ActionCatalogItem::AVAILABLE_IN_SYMBOL
+                  | ActionCatalogItem::AVAILABLE_IN_SCHEMATIC | ActionCatalogItem::AVAILABLE_IN_BOARD,
           ActionCatalogItem::FLAGS_DEFAULT}},
 
         {{ActionID::EDIT_PADSTACK, ToolID::NONE},
@@ -881,6 +883,36 @@ const std::map<ActionToolID, ActionCatalogItem> action_catalog = {
         {{ActionID::HIGHLIGHT_NET_CLASS, ToolID::NONE},
          {"Highlight net class", ActionGroup::UNKNOWN, ActionCatalogItem::AVAILABLE_IN_SCHEMATIC_AND_BOARD,
           ActionCatalogItem::FLAGS_SPECIFIC}},
+
+        {{ActionID::TOOL, ToolID::DRAW_PLANE},
+         {"Draw plane", ActionGroup::BOARD, ActionCatalogItem::AVAILABLE_IN_BOARD, ActionCatalogItem::FLAGS_DEFAULT}},
+
+        {{ActionID::TOOL, ToolID::DRAW_KEEPOUT},
+         {"Draw keepout", ActionGroup::BOARD, ActionCatalogItem::AVAILABLE_IN_PACKAGE_AND_BOARD,
+          ActionCatalogItem::FLAGS_DEFAULT}},
+
+        {{ActionID::TOOL, ToolID::DRAG_POLYGON_EDGE},
+         {"Drag polygon edge", ActionGroup::GRAPHICS, ActionCatalogItem::AVAILABLE_EVERYWHERE,
+          ActionCatalogItem::FLAGS_DEFAULT}},
+
+        {{ActionID::ROTATE_VIEW_LEFT, ToolID::NONE},
+         {"Rotate view left", ActionGroup::VIEW, ActionCatalogItem::AVAILABLE_IN_PACKAGE_AND_BOARD,
+          ActionCatalogItem::FLAGS_IN_TOOL}},
+
+        {{ActionID::ROTATE_VIEW_RIGHT, ToolID::NONE},
+         {"Rotate view right", ActionGroup::VIEW, ActionCatalogItem::AVAILABLE_IN_PACKAGE_AND_BOARD,
+          ActionCatalogItem::FLAGS_IN_TOOL}},
+
+        {{ActionID::ROTATE_VIEW_RESET, ToolID::NONE},
+         {"Reset view rotation", ActionGroup::VIEW, ActionCatalogItem::AVAILABLE_IN_PACKAGE_AND_BOARD,
+          ActionCatalogItem::FLAGS_IN_TOOL}},
+
+        {{ActionID::ROTATE_VIEW, ToolID::NONE},
+         {"Rotate view", ActionGroup::VIEW, ActionCatalogItem::AVAILABLE_IN_PACKAGE_AND_BOARD,
+          ActionCatalogItem::FLAGS_IN_TOOL}},
+
+        {{ActionID::TOOL, ToolID::MEASURE},
+         {"Measure", ActionGroup::GRAPHICS, ActionCatalogItem::AVAILABLE_LAYERED, ActionCatalogItem::FLAGS_DEFAULT}},
 };
 
 const std::vector<std::pair<ActionGroup, std::string>> action_group_catalog = {
@@ -1002,6 +1034,10 @@ const LutEnumStr<ActionID> action_lut = {
         ACTION_LUT_ITEM(ZOOM_OUT),
         ACTION_LUT_ITEM(CLICK_SELECT),
         ACTION_LUT_ITEM(HIGHLIGHT_NET_CLASS),
+        ACTION_LUT_ITEM(ROTATE_VIEW_LEFT),
+        ACTION_LUT_ITEM(ROTATE_VIEW_RIGHT),
+        ACTION_LUT_ITEM(ROTATE_VIEW_RESET),
+        ACTION_LUT_ITEM(ROTATE_VIEW),
 };
 
 #define TOOL_LUT_ITEM(x)                                                                                               \
@@ -1151,5 +1187,9 @@ const LutEnumStr<ToolID> tool_lut = {
         TOOL_LUT_ITEM(DRAW_LINE_CIRCLE),
         TOOL_LUT_ITEM(ADD_TEXT),
         TOOL_LUT_ITEM(PLACE_DECAL),
+        TOOL_LUT_ITEM(DRAW_PLANE),
+        TOOL_LUT_ITEM(DRAW_KEEPOUT),
+        TOOL_LUT_ITEM(DRAG_POLYGON_EDGE),
+        TOOL_LUT_ITEM(MEASURE),
 };
 } // namespace horizon
