@@ -13,8 +13,9 @@ public:
         AVAILABLE_IN_PACKAGE = (1 << 3),
         AVAILABLE_IN_BOARD = (1 << 4),
         AVAILABLE_IN_FRAME = (1 << 5),
+        AVAILABLE_IN_DECAL = (1 << 6),
         AVAILABLE_EVERYWHERE = 0xff,
-        AVAILABLE_LAYERED = AVAILABLE_IN_PACKAGE | AVAILABLE_IN_PADSTACK | AVAILABLE_IN_BOARD,
+        AVAILABLE_LAYERED = AVAILABLE_IN_PACKAGE | AVAILABLE_IN_PADSTACK | AVAILABLE_IN_BOARD | AVAILABLE_IN_DECAL,
         AVAILABLE_IN_PACKAGE_AND_BOARD = AVAILABLE_IN_PACKAGE | AVAILABLE_IN_BOARD,
         AVAILABLE_IN_SCHEMATIC_AND_BOARD = AVAILABLE_IN_SCHEMATIC | AVAILABLE_IN_BOARD
     };
