@@ -15,10 +15,10 @@ class BOMExportWindow : public Gtk::Window, public Changeable {
     friend class OrderableMPNSelector;
 
 public:
-    BOMExportWindow(BaseObjectType *cobject, const Glib::RefPtr<Gtk::Builder> &x, class Block *block,
-                    class BOMExportSettings *settings, class Pool &pool, const std::string &project_dir);
-    static BOMExportWindow *create(Gtk::Window *p, class Block *block, class BOMExportSettings *settings,
-                                   class Pool &pool, const std::string &project_dir);
+    BOMExportWindow(BaseObjectType *cobject, const Glib::RefPtr<Gtk::Builder> &x, class Block &block,
+                    class BOMExportSettings &settings, class IPool &pool, const std::string &project_dir);
+    static BOMExportWindow *create(Gtk::Window *p, class Block &block, class BOMExportSettings &settings,
+                                   class IPool &pool, const std::string &project_dir);
 
     void set_can_export(bool v);
     void generate();
@@ -27,9 +27,9 @@ public:
     void update();
 
 private:
-    class Block *block;
-    class BOMExportSettings *settings;
-    class Pool &pool;
+    class Block &block;
+    class BOMExportSettings &settings;
+    class IPool &pool;
     PoolParametric pool_parametric;
 
     void update_concrete_parts();
