@@ -30,6 +30,7 @@
 #include "preferences/preferences_util.hpp"
 #include "widgets/action_button.hpp"
 #include "in_tool_action_catalog.hpp"
+#include "util/zmq_helper.hpp"
 
 #ifdef G_OS_WIN32
 #include <winsock2.h>
@@ -79,13 +80,14 @@ ImpBase::ImpBase(const PoolParams &params)
                 [this](Glib::IOCondition cond) {
                     while (sock_broadcast_rx.getsockopt<int>(ZMQ_EVENTS) & ZMQ_POLLIN) {
                         zmq::message_t msg;
-                        sock_broadcast_rx.recv(&msg);
-                        int prefix;
-                        memcpy(&prefix, msg.data(), 4);
-                        char *data = ((char *)msg.data()) + 4;
-                        json j = json::parse(data);
-                        if (prefix == 0 || prefix == getpid()) {
-                            handle_broadcast(j);
+                        if (zmq_helper::recv(sock_broadcast_rx, msg)) {
+                            int prefix;
+                            memcpy(&prefix, msg.data(), 4);
+                            char *data = ((char *)msg.data()) + 4;
+                            json j = json::parse(data);
+                            if (prefix == 0 || prefix == getpid()) {
+                                handle_broadcast(j);
+                            }
                         }
                     }
                     return true;
@@ -125,7 +127,7 @@ json ImpBase::send_json(const json &j)
     auto m = (char *)msg.data();
     m[msg.size() - 1] = 0;
     try {
-        if (sock_project.send(msg) == false) {
+        if (zmq_helper::send(sock_project, msg) == false) {
             sockets_broken = true;
             sockets_connected = false;
             show_sockets_broken_dialog("send timeout");
@@ -141,7 +143,7 @@ json ImpBase::send_json(const json &j)
 
     zmq::message_t rx;
     try {
-        if (sock_project.recv(&rx) == false) {
+        if (zmq_helper::recv(sock_project, rx) == false) {
             sockets_broken = true;
             sockets_connected = false;
             show_sockets_broken_dialog("receive timeout");
@@ -158,7 +160,7 @@ json ImpBase::send_json(const json &j)
     return json::parse(rxdata);
 }
 
-bool ImpBase::handle_close(GdkEventAny *ev)
+bool ImpBase::handle_close(const GdkEventAny *ev)
 {
     bool dontask = false;
     Glib::getenv("HORIZON_NOEXITCONFIRM", dontask);
@@ -278,7 +280,6 @@ void ImpBase::set_flip_view(bool flip)
     canvas->set_flip_view(flip);
     canvas_update_from_pp();
     update_view_hints();
-    apply_arrow_keys();
     g_simple_action_set_state(bottom_view_action->gobj(), g_variant_new_boolean(canvas->get_flip_view()));
 }
 
@@ -288,10 +289,8 @@ void ImpBase::run(int argc, char *argv[])
 
     main_window = MainWindow::create();
     canvas = main_window->canvas;
-    {
-        Documents docs(core);
-        clipboard.reset(new ClipboardManager(docs));
-    }
+    clipboard = ClipboardBase::create(*core);
+    clipboard_handler = std::make_unique<ClipboardHandler>(*clipboard);
 
     canvas->signal_selection_changed().connect(sigc::mem_fun(*this, &ImpBase::handle_selection_changed));
     canvas->signal_cursor_moved().connect(sigc::mem_fun(*this, &ImpBase::handle_cursor_move));
@@ -486,11 +485,13 @@ void ImpBase::run(int argc, char *argv[])
         this->canvas_update_from_pp();
     });
 
-    connect_action(ActionID::COPY,
-                   [this](const auto &a) { clipboard->copy(canvas->get_selection(), canvas->get_cursor_pos()); });
+    connect_action(ActionID::COPY, [this](const auto &a) {
+        clipboard_handler->copy(canvas->get_selection(), canvas->get_cursor_pos());
+    });
 
     connect_action(ActionID::VIEW_ALL, [this](const auto &a) {
         auto bbox = canvas->get_bbox();
+        std::cout << coord_to_string(bbox.first) << " " << coord_to_string(bbox.second) << std::endl;
         canvas->zoom_to_bbox(bbox.first, bbox.second);
     });
 
@@ -532,6 +533,8 @@ void ImpBase::run(int argc, char *argv[])
 
     connect_action(ActionID::FLIP_VIEW, [this](const auto &a) { set_flip_view(!canvas->get_flip_view()); });
 
+    connect_action(ActionID::SELECT_POLYGON, sigc::mem_fun(*this, &ImpBase::handle_select_polygon));
+
     bottom_view_action = main_window->add_action_bool("bottom_view", false);
     bottom_view_action->signal_change_state().connect([this](const Glib::VariantBase &v) {
         auto b = Glib::VariantBase::cast_dynamic<Glib::Variant<bool>>(v).get();
@@ -624,7 +627,7 @@ void ImpBase::run(int argc, char *argv[])
 
         {
             auto button = create_action_button(make_action(ActionID::RULES));
-            button->set_label("Rules...");
+            button->set_label("Rules…");
             main_window->header->pack_start(*button);
             button->show();
         }
@@ -663,17 +666,23 @@ void ImpBase::run(int argc, char *argv[])
 
     add_hamburger_menu();
 
-    view_options_menu = Gio::Menu::create();
-    main_window->view_options_button->set_menu_model(view_options_menu);
+    auto view_options_popover = Gtk::manage(new Gtk::PopoverMenu);
+    main_window->view_options_button->set_popover(*view_options_popover);
     {
         Gdk::Rectangle rect;
         rect.set_width(24);
         main_window->view_options_button->get_popover()->set_pointing_to(rect);
     }
 
-    view_options_menu->append("Distraction free mode", "win.distraction_free");
+    view_options_menu = Gtk::manage(new Gtk::Box(Gtk::ORIENTATION_VERTICAL));
+    view_options_menu->set_border_width(9);
+    view_options_popover->add(*view_options_menu);
+    view_options_menu->show();
+    view_options_popover->child_property_submenu(*view_options_menu) = "main";
+
+    view_options_menu_append_action("Distraction free mode", "win.distraction_free");
     add_tool_action(ActionID::SELECTION_FILTER, "selection_filter");
-    view_options_menu->append("Selection filter", "win.selection_filter");
+    view_options_menu_append_action("Selection filter", "win.selection_filter");
 
     imp_interface = std::make_unique<ImpInterface>(this);
 
@@ -806,8 +815,6 @@ void ImpBase::run(int argc, char *argv[])
     }
     update_view_hints();
 
-    connect_action(ActionID::SELECT_POLYGON, sigc::mem_fun(*this, &ImpBase::handle_select_polygon));
-
     check_version();
 
     {
@@ -870,8 +877,11 @@ ToolID ImpBase::get_tool_for_drag_move(bool ctrl, const std::set<SelectableRef>
 {
     if (ctrl)
         return ToolID::DUPLICATE;
-    else
-        return ToolID::MOVE;
+
+    if (preferences.mouse.drag_polygon_edges && sel.size() == 1 && sel.begin()->type == ObjectType::POLYGON_EDGE)
+        return ToolID::DRAG_POLYGON_EDGE;
+
+    return ToolID::MOVE;
 }
 
 void ImpBase::handle_drag(bool ctrl)
@@ -896,10 +906,10 @@ void ImpBase::handle_drag(bool ctrl)
 
 void ImpBase::apply_preferences()
 {
-    auto canvas_prefs = get_canvas_preferences();
-    canvas->set_appearance(canvas_prefs->appearance);
+    const auto &canvas_prefs = get_canvas_preferences();
+    canvas->set_appearance(canvas_prefs.appearance);
     if (core->tool_is_active()) {
-        canvas->set_cursor_size(canvas_prefs->appearance.cursor_size_tool);
+        canvas->set_cursor_size(canvas_prefs.appearance.cursor_size_tool);
     }
     canvas->show_all_junctions_in_schematic = preferences.schematic.show_all_junctions;
 
@@ -955,8 +965,11 @@ void ImpBase::apply_preferences()
 
 void ImpBase::canvas_update_from_pp()
 {
-    if (core->tool_is_active())
+    if (core->tool_is_active()) {
+        canvas_update();
+        canvas->set_selection(core->get_tool_selection());
         return;
+    }
 
     auto sel = canvas->get_selection();
     canvas_update();
@@ -1056,7 +1069,7 @@ void ImpBase::fix_cursor_pos()
     canvas->update_cursor_pos(x, y);
 }
 
-bool ImpBase::handle_click_release(GdkEventButton *button_event)
+bool ImpBase::handle_click_release(const GdkEventButton *button_event)
 {
     if (core->tool_is_active() && button_event->button != 2 && !(button_event->state & Gdk::SHIFT_MASK)) {
         ToolArgs args;
@@ -1163,8 +1176,13 @@ void ImpBase::create_context_menu(Gtk::Menu *parent, const std::set<SelectableRe
         delete sep;
 }
 
-bool ImpBase::handle_click(GdkEventButton *button_event)
+bool ImpBase::handle_click(const GdkEventButton *button_event)
 {
+    if (button_event->button > 3) {
+        handle_extra_button(button_event);
+        return false;
+    }
+
     if (button_event->button != 2)
         set_search_mode(false);
 
@@ -1224,19 +1242,9 @@ bool ImpBase::handle_click(GdkEventButton *button_event)
                     std::string text = get_complete_display_name(sr);
                     auto la = Gtk::manage(new Gtk::MenuItem(text));
 
-                    la->signal_select().connect([this, sr] {
-                        canvas->set_selection({sr}, false);
-#ifdef G_OS_WIN32 // work around a bug(?) in intel(?) GPU drivers on windows
-                        Glib::signal_idle().connect_once([this] { canvas->queue_draw(); });
-#endif
-                    });
+                    la->signal_select().connect([this, sr] { canvas->set_selection({sr}, false); });
 
-                    la->signal_deselect().connect([this] {
-                        canvas->set_selection({}, false);
-#ifdef G_OS_WIN32 // work around a bug(?) in intel(?) GPU drivers on windows
-                        Glib::signal_idle().connect_once([this] { canvas->queue_draw(); });
-#endif
-                    });
+                    la->signal_deselect().connect([this] { canvas->set_selection({}, false); });
 
                     auto submenu = Gtk::manage(new Gtk::Menu);
 
@@ -1390,10 +1398,10 @@ void ImpBase::handle_tool_change(ToolID id)
         main_window->tool_bar_set_tool_name(action_catalog.at({ActionID::TOOL, id}).name);
         main_window->tool_bar_set_tool_tip("");
         main_window->hud_hide();
-        canvas->set_cursor_size(get_canvas_preferences()->appearance.cursor_size_tool);
+        canvas->set_cursor_size(get_canvas_preferences().appearance.cursor_size_tool);
     }
     else {
-        canvas->set_cursor_size(get_canvas_preferences()->appearance.cursor_size);
+        canvas->set_cursor_size(get_canvas_preferences().appearance.cursor_size);
     }
     main_window->tool_bar_set_visible(id != ToolID::NONE);
     tool_bar_clear_actions();
@@ -1549,9 +1557,6 @@ std::vector<std::string> ImpBase::get_view_hints()
     if (distraction_free)
         r.emplace_back("distraction free mode");
 
-    if (canvas->get_flip_view())
-        r.emplace_back("bottom view");
-
     if (selection_filter_dialog->get_filtered())
         r.emplace_back("selection filtered");
     return r;
@@ -1610,4 +1615,14 @@ void ImpBase::check_version()
     }
 }
 
+void ImpBase::view_options_menu_append_action(const std::string &label, const std::string &action)
+{
+    auto bu = Gtk::manage(new Gtk::ModelButton);
+    bu->set_label(label);
+    bu->get_child()->set_halign(Gtk::ALIGN_START);
+    gtk_actionable_set_action_name(GTK_ACTIONABLE(bu->gobj()), action.c_str());
+    view_options_menu->pack_start(*bu, false, false, 0);
+    bu->show();
+}
+
 } // namespace horizon
