@@ -22,6 +22,7 @@
 #include "core/tool_id.hpp"
 #include "widgets/action_button.hpp"
 #include "parts_window.hpp"
+#include "pool/pool_cached.hpp"
 
 namespace horizon {
 ImpBoard::ImpBoard(const std::string &board_filename, const std::string &block_filename, const std::string &via_dir,
@@ -36,7 +37,7 @@ ImpBoard::ImpBoard(const std::string &board_filename, const std::string &block_f
 
 void ImpBoard::canvas_update()
 {
-    canvas->update(*core_board.get_canvas_data());
+    canvas->update(core_board.get_canvas_data());
     warnings_box->update(core_board.get_board()->warnings);
     apply_net_colors();
     update_highlights();
@@ -93,8 +94,14 @@ void ImpBoard::update_highlights()
         if (it.type == ObjectType::COMPONENT) {
             for (const auto &it_pkg : core_board.get_board()->packages) {
                 if (it_pkg.second.component->uuid == it.uuid) {
-                    ObjectRef ref(ObjectType::BOARD_PACKAGE, it_pkg.first);
-                    canvas->set_flags(ref, TriangleInfo::FLAG_HIGHLIGHT, 0);
+                    {
+                        ObjectRef ref(ObjectType::BOARD_PACKAGE, it_pkg.first);
+                        canvas->set_flags(ref, TriangleInfo::FLAG_HIGHLIGHT, 0);
+                    }
+                    for (const auto text : it_pkg.second.texts) {
+                        ObjectRef ref(ObjectType::TEXT, text->uuid);
+                        canvas->set_flags(ref, TriangleInfo::FLAG_HIGHLIGHT, 0);
+                    }
                 }
             }
         }
@@ -141,11 +148,9 @@ void ImpBoard::apply_net_colors()
 bool ImpBoard::handle_broadcast(const json &j)
 {
     if (!ImpBase::handle_broadcast(j)) {
-        if (core_board.tool_is_active())
-            return true;
         std::string op = j.at("op");
         guint32 timestamp = j.value("time", 0);
-        if (op == "highlight" && cross_probing_enabled) {
+        if (op == "highlight" && cross_probing_enabled && !core->tool_is_active()) {
             highlights.clear();
             const json &o = j["objects"];
             for (auto it = o.cbegin(); it != o.cend(); ++it) {
@@ -156,6 +161,7 @@ bool ImpBoard::handle_broadcast(const json &j)
             update_highlights();
         }
         else if (op == "place") {
+            force_end_tool();
             main_window->present(timestamp);
             std::set<SelectableRef> components;
             const json &o = j["components"];
@@ -169,10 +175,11 @@ bool ImpBoard::handle_broadcast(const json &j)
             tool_begin(ToolID::MAP_PACKAGE, true, components);
         }
         else if (op == "reload-netlist") {
+            force_end_tool();
             main_window->present(timestamp);
             trigger_action(ActionID::RELOAD_NETLIST);
         }
-        else if (op == "reload-netlist-hint") {
+        else if (op == "reload-netlist-hint" && !core->tool_is_active()) {
             reload_netlist_delay_conn = Glib::signal_timeout().connect(
                     [this] {
 #if GTK_CHECK_VERSION(3, 22, 0)
@@ -274,6 +281,7 @@ void ImpBoard::update_action_sensitivity()
     });
 
     set_action_sensitive(make_action(ActionID::HIGHLIGHT_NET), can_select_more);
+    set_action_sensitive(make_action(ActionID::HIGHLIGHT_NET_CLASS), can_select_more);
     set_action_sensitive(make_action(ActionID::SELECT_MORE), can_select_more);
     set_action_sensitive(make_action(ActionID::SELECT_MORE_NO_VIA), can_select_more);
     set_action_sensitive(make_action(ActionID::FILTER_AIRWIRES), can_select_more || n_pkgs);
@@ -424,7 +432,7 @@ void ImpBoard::construct()
     hamburger_menu->append("PDF Export", "win.export_pdf");
     main_window->add_action("export_pdf", [this] { trigger_action(ActionID::PDF_EXPORT_WINDOW); });
 
-    hamburger_menu->append("Stackup...", "win.edit_stackup");
+    hamburger_menu->append("Stackup…", "win.edit_stackup");
     add_tool_action(ToolID::EDIT_STACKUP, "edit_stackup");
 
     hamburger_menu->append("Update all planes", "win.update_all_planes");
@@ -446,9 +454,10 @@ void ImpBoard::construct()
     main_window->add_action("tuning", [this] { trigger_action(ActionID::TUNING); });
 
     add_tool_action(ActionID::AIRWIRE_FILTER_WINDOW, "airwire_filter");
-    view_options_menu->append("Nets…", "win.airwire_filter");
+    view_options_menu_append_action("Nets…", "win.airwire_filter");
 
-    view_options_menu->append("Bottom view", "win.bottom_view");
+    view_options_menu_append_action("Bottom view", "win.bottom_view");
+    add_view_angle_actions();
 
     if (sockets_connected) {
         hamburger_menu->append("Cross probing", "win.cross_probing");
@@ -547,7 +556,7 @@ void ImpBoard::construct()
         la->property_margin() = 10;
     }
 
-    fab_output_window = FabOutputWindow::create(main_window, &core_board, project_dir);
+    fab_output_window = FabOutputWindow::create(main_window, core_board, project_dir);
     core->signal_tool_changed().connect([this](ToolID t) { fab_output_window->set_can_generate(t == ToolID::NONE); });
     core->signal_rebuilt().connect([this] { fab_output_window->reload_layers(); });
     fab_output_window->signal_changed().connect([this] { core_board.set_needs_save(); });
@@ -558,7 +567,7 @@ void ImpBoard::construct()
     });
 
     pdf_export_window =
-            PDFExportWindow::create(main_window, &core_board, *core_board.get_pdf_export_settings(), project_dir);
+            PDFExportWindow::create(main_window, core_board, core_board.get_pdf_export_settings(), project_dir);
     pdf_export_window->signal_changed().connect([this] { core_board.set_needs_save(); });
     core->signal_rebuilt().connect([this] { pdf_export_window->reload_layers(); });
     connect_action(ActionID::PDF_EXPORT_WINDOW, [this](const auto &c) { pdf_export_window->present(); });
@@ -567,12 +576,12 @@ void ImpBoard::construct()
         pdf_export_window->generate();
     });
 
-    view_3d_window = View3DWindow::create(core_board.get_board(), pool.get());
-    view_3d_window->set_solder_mask_color(rgba_from_color(core_board.get_colors()->solder_mask));
-    view_3d_window->set_substrate_color(rgba_from_color(core_board.get_colors()->substrate));
+    view_3d_window = View3DWindow::create(*core_board.get_board(), *pool.get(), View3DWindow::Mode::BOARD);
+    view_3d_window->set_solder_mask_color(rgba_from_color(core_board.get_colors().solder_mask));
+    view_3d_window->set_substrate_color(rgba_from_color(core_board.get_colors().substrate));
     view_3d_window->signal_changed().connect([this] {
-        core_board.get_colors()->solder_mask = color_from_rgba(view_3d_window->get_solder_mask_color());
-        core_board.get_colors()->substrate = color_from_rgba(view_3d_window->get_substrate_color());
+        core_board.get_colors().solder_mask = color_from_rgba(view_3d_window->get_solder_mask_color());
+        core_board.get_colors().substrate = color_from_rgba(view_3d_window->get_substrate_color());
         core_board.set_needs_save();
     });
     view_3d_window->signal_key_press_event().connect([this](GdkEventKey *ev) {
@@ -583,7 +592,7 @@ void ImpBoard::construct()
         return false;
     });
 
-    step_export_window = StepExportWindow::create(main_window, &core_board, project_dir);
+    step_export_window = StepExportWindow::create(main_window, core_board, project_dir);
     step_export_window->signal_changed().connect([this] { core_board.set_needs_save(); });
     connect_action(ActionID::STEP_EXPORT_WINDOW, [this](const auto &c) { step_export_window->present(); });
     connect_action(ActionID::EXPORT_STEP, [this](const auto &c) {
@@ -628,31 +637,27 @@ void ImpBoard::construct()
     connect_action(ActionID::HIGHLIGHT_NET, [this](const auto &a) {
         highlights.clear();
         for (const auto &it : canvas->get_selection()) {
-            auto board = core_board.get_board();
-            switch (it.type) {
-            case ObjectType::TRACK: {
-                auto &track = board->tracks.at(it.uuid);
-                if (track.net) {
-                    highlights.emplace(ObjectType::NET, track.net->uuid);
-                }
-            } break;
-            case ObjectType::VIA: {
-                auto &via = board->vias.at(it.uuid);
-                if (via.junction->net) {
-                    highlights.emplace(ObjectType::NET, via.junction->net->uuid);
-                }
-            } break;
-            case ObjectType::JUNCTION: {
-                auto &ju = board->junctions.at(it.uuid);
-                if (ju.net) {
-                    highlights.emplace(ObjectType::NET, ju.net->uuid);
-                }
-            } break;
-            default:;
+            if (auto uu = net_from_selectable(it)) {
+                highlights.emplace(ObjectType::NET, uu);
             }
         }
         this->update_highlights();
     });
+
+    connect_action(ActionID::HIGHLIGHT_NET_CLASS, [this](const auto &a) {
+        highlights.clear();
+        for (const auto &it : canvas->get_selection()) {
+            if (auto uu = net_from_selectable(it)) {
+                const auto &net_sel = core_board.get_block()->nets.at(uu);
+                for (const auto &[net_uu, net] : core_board.get_block()->nets) {
+                    if (net.net_class == net_sel.net_class)
+                        highlights.emplace(ObjectType::NET, net_uu);
+                }
+            }
+        }
+        this->update_highlights();
+    });
+
     connect_action(ActionID::SELECT_MORE, sigc::mem_fun(*this, &ImpBoard::handle_select_more));
     connect_action(ActionID::SELECT_MORE_NO_VIA, sigc::mem_fun(*this, &ImpBoard::handle_select_more));
 
@@ -728,17 +733,24 @@ void ImpBoard::construct()
 
 
     pnp_export_window = PnPExportWindow::create(main_window, *core_board.get_board(),
-                                                *core_board.get_pnp_export_settings(), project_dir);
+                                                core_board.get_pnp_export_settings(), project_dir);
 
-    connect_action(ActionID::PNP_EXPORT_WINDOW, [this](const auto &c) { pnp_export_window->present(); });
+    connect_action(ActionID::PNP_EXPORT_WINDOW, [this](const auto &c) {
+        pnp_export_window->update();
+        pnp_export_window->present();
+    });
     connect_action(ActionID::EXPORT_PNP, [this](const auto &c) {
+        pnp_export_window->update();
         pnp_export_window->present();
         pnp_export_window->generate();
     });
 
     pnp_export_window->signal_changed().connect([this] { core_board.set_needs_save(); });
     core->signal_tool_changed().connect([this](ToolID t) { pnp_export_window->set_can_export(t == ToolID::NONE); });
-    core->signal_rebuilt().connect([this] { pnp_export_window->update(); });
+    core->signal_rebuilt().connect([this] {
+        if (pnp_export_window->get_visible())
+            pnp_export_window->update();
+    });
 
     airwire_filter_window = AirwireFilterWindow::create(main_window, *core_board.get_board());
     airwire_filter_window->update_nets();
@@ -803,25 +815,48 @@ void ImpBoard::construct()
         auto &b = add_action_button(make_action(ToolID::ROUTE_TRACK_INTERACTIVE));
         b.add_action(make_action(ToolID::ROUTE_DIFFPAIR_INTERACTIVE));
     }
-    {
-        auto &b = add_action_button(make_action(ToolID::DRAW_POLYGON));
-        b.add_action(make_action(ToolID::DRAW_POLYGON_RECTANGLE));
-        b.add_action(make_action(ToolID::DRAW_POLYGON_CIRCLE));
-    }
+    add_action_button_polygon();
     {
         auto &b = add_action_button(make_action(ToolID::PLACE_BOARD_HOLE));
         b.add_action(make_action(ToolID::PLACE_VIA));
     }
-    {
-        auto &b = add_action_button(make_action(ToolID::DRAW_LINE));
-        b.add_action(make_action(ToolID::DRAW_LINE_RECTANGLE));
-        b.add_action(make_action(ToolID::DRAW_ARC));
-    }
+    add_action_button_line();
 
     add_action_button(make_action(ToolID::PLACE_TEXT));
     add_action_button(make_action(ToolID::DRAW_DIMENSION));
 
+    update_monitor();
+
     display_control_notebook->show();
+
+    set_view_angle(0);
+}
+
+UUID ImpBoard::net_from_selectable(const SelectableRef &sr)
+{
+    const auto &board = *core_board.get_board();
+    switch (sr.type) {
+    case ObjectType::TRACK: {
+        auto &track = board.tracks.at(sr.uuid);
+        if (track.net) {
+            return track.net->uuid;
+        }
+    } break;
+    case ObjectType::VIA: {
+        auto &via = board.vias.at(sr.uuid);
+        if (via.junction->net) {
+            return via.junction->net->uuid;
+        }
+    } break;
+    case ObjectType::JUNCTION: {
+        auto &ju = board.junctions.at(sr.uuid);
+        if (ju.net) {
+            return ju.net->uuid;
+        }
+    } break;
+    default:;
+    }
+    return UUID();
 }
 
 void ImpBoard::update_airwires()
@@ -891,7 +926,7 @@ std::string ImpBoard::get_hud_text(std::set<SelectableRef> &sel)
         }
         s += "Layers: ";
         for (auto layer : layers) {
-            s += core->get_layer_provider()->get_layers().at(layer).name + " ";
+            s += core->get_layer_provider().get_layers().at(layer).name + " ";
         }
         s += "\nTotal length: " + dim_to_string(length, false);
         if (sel_count_type(sel, ObjectType::TRACK) == 1) {
@@ -941,7 +976,7 @@ std::string ImpBoard::get_hud_text(std::set<SelectableRef> &sel)
                 s += "\n\n<b>Plane " + plane->net->name + "</b>\n";
                 s += "Priority: " + std::to_string(plane->priority) + "\n";
                 s += "Layer: ";
-                s += core_board.get_layer_provider()->get_layers().at(poly->layer).name + "\n";
+                s += core_board.get_layer_provider().get_layers().at(poly->layer).name + "\n";
             }
         }
     }
@@ -1129,23 +1164,25 @@ std::map<ObjectType, ImpBase::SelectionFilterInfo> ImpBoard::get_selection_filte
     layers_polygon.insert(layers_polygon.end(), inner_layers.begin(), inner_layers.end());
     append_bottom_layers(layers_polygon);
 
-    std::vector<int> layers_package = {BoardLayers::TOP_PACKAGE, BoardLayers::BOTTOM_PACKAGE};
+    std::vector<int> layers_package = {BoardLayers::TOP_COPPER, BoardLayers::BOTTOM_COPPER};
 
     std::vector<int> layers_track = {BoardLayers::TOP_COPPER};
     layers_track.insert(layers_track.end(), inner_layers.begin(), inner_layers.end());
     append_bottom_layers(layers_track);
 
+    using Flag = ImpBase::SelectionFilterInfo::Flag;
     std::map<ObjectType, ImpBase::SelectionFilterInfo> r = {
-            {ObjectType::BOARD_PACKAGE, {layers_package, false}},
-            {ObjectType::TRACK, {layers_track, false}},
-            {ObjectType::VIA, {}},
-            {ObjectType::POLYGON, {layers_polygon, true}},
-            {ObjectType::TEXT, {layers_line, true}},
-            {ObjectType::LINE, {layers_line, true}},
-            {ObjectType::JUNCTION, {}},
-            {ObjectType::ARC, {layers_line, true}},
+            {ObjectType::BOARD_PACKAGE, {layers_package, Flag::DEFAULT}},
+            {ObjectType::TRACK, {layers_track, Flag::DEFAULT}},
+            {ObjectType::VIA, {{}, Flag::WORK_LAYER_ONLY_ENABLED}},
+            {ObjectType::BOARD_DECAL, {}},
+            {ObjectType::POLYGON, {layers_polygon, Flag::HAS_OTHERS}},
+            {ObjectType::TEXT, {layers_line, Flag::HAS_OTHERS}},
+            {ObjectType::LINE, {layers_line, Flag::HAS_OTHERS}},
+            {ObjectType::JUNCTION, {layers_track, Flag::HAS_OTHERS}},
+            {ObjectType::ARC, {layers_line, Flag::HAS_OTHERS}},
             {ObjectType::DIMENSION, {}},
-            {ObjectType::BOARD_HOLE, {}},
+            {ObjectType::BOARD_HOLE, {{}, Flag::WORK_LAYER_ONLY_ENABLED}},
             {ObjectType::CONNECTION_LINE, {}},
             {ObjectType::BOARD_PANEL, {}},
             {ObjectType::PICTURE, {}},
@@ -1179,7 +1216,7 @@ void ImpBoard::get_save_meta(json &j)
 
 std::vector<std::string> ImpBoard::get_view_hints()
 {
-    auto r = ImpBase::get_view_hints();
+    auto r = ImpLayer::get_view_hints();
 
     if (airwire_filter_window->get_filtered())
         r.emplace_back("airwires filtered");
@@ -1215,6 +1252,17 @@ void ImpBoard::update_net_colors()
     }
 }
 
+
+void ImpBoard::update_monitor()
+{
+    ItemSet mon_items = core_board.get_block()->get_pool_items_used();
+    {
+        ItemSet items = core_board.get_board()->get_pool_items_used();
+        mon_items.insert(items.begin(), items.end());
+    }
+    set_monitor_items(mon_items);
+}
+
 ImpBoard::~ImpBoard()
 {
     reload_netlist_delay_conn.disconnect();
