@@ -14,7 +14,7 @@ ImpFrame::ImpFrame(const std::string &frame_filename, const std::string &pool_pa
 
 void ImpFrame::canvas_update()
 {
-    canvas->update(*core_frame.get_canvas_data());
+    canvas->update(core_frame.get_canvas_data());
 }
 
 void ImpFrame::construct()
@@ -35,7 +35,7 @@ void ImpFrame::construct()
 
     core->signal_save().connect([this] { frame.name = name_entry->get_text(); });
 
-    hamburger_menu->append("Frame properties...", "win.edit_frame");
+    hamburger_menu->append("Frame properties…", "win.edit_frame");
     add_tool_action(ToolID::EDIT_FRAME_PROPERTIES, "edit_frame");
 
     add_action_button_line();
