@@ -10,48 +10,24 @@
 
 namespace horizon {
 ImpPadstack::ImpPadstack(const std::string &padstack_filename, const std::string &pool_path)
-    : ImpLayer(pool_path), core_padstack(padstack_filename, *pool)
+    : ImpLayer(pool_path), core_padstack(padstack_filename, *pool), padstack(core_padstack.get_padstack())
 {
     core = &core_padstack;
     core_padstack.signal_tool_changed().connect(sigc::mem_fun(*this, &ImpBase::handle_tool_change));
+    view_angle = 0;
 }
 
 void ImpPadstack::canvas_update()
 {
-    canvas->update(*core_padstack.get_canvas_data());
+    canvas->update(core_padstack.get_canvas_data());
 }
 
-class ImpPadstackParameterSetEditor : public ParameterSetEditor {
+class MyCheckButton : public Gtk::CheckButton, public Changeable {
 public:
-    ImpPadstackParameterSetEditor(ParameterSet *ps, std::set<ParameterID> *ps_reqd)
-        : ParameterSetEditor(ps, false), parameters_required(ps_reqd)
+    MyCheckButton(const std::string &s) : Gtk::CheckButton(s)
     {
+        signal_toggled().connect([this] { s_signal_changed.emit(); });
     }
-
-private:
-    Gtk::Widget *create_extra_widget(ParameterID id) override
-    {
-        auto w = Gtk::manage(new Gtk::CheckButton("Required"));
-        w->set_tooltip_text("Parameter has to be set in pad");
-        w->set_active(parameters_required->count(id));
-        w->signal_toggled().connect([this, id, w] {
-            s_signal_changed.emit();
-            if (w->get_active()) {
-                parameters_required->insert(id);
-            }
-            else {
-                parameters_required->erase(id);
-            }
-        });
-        return w;
-    }
-
-    void erase_cb(ParameterID id) override
-    {
-        parameters_required->erase(id);
-    }
-
-    std::set<ParameterID> *parameters_required;
 };
 
 void ImpPadstack::construct()
@@ -67,21 +43,15 @@ void ImpPadstack::construct()
     header_button->signal_closed().connect(sigc::mem_fun(*this, &ImpPadstack::update_header));
 
     name_entry = header_button->add_entry("Name");
-    name_entry->set_text(core_padstack.get_padstack()->name);
-    name_entry->set_width_chars(core_padstack.get_padstack()->name.size());
+    name_entry->set_text(padstack.name);
+    name_entry->set_width_chars(padstack.name.size());
     name_entry->signal_changed().connect([this] { core_padstack.set_needs_save(); });
     name_entry->signal_activate().connect(sigc::mem_fun(*this, &ImpPadstack::update_header));
 
     auto well_known_name_entry = header_button->add_entry("Well-known name");
-    well_known_name_entry->set_text(core_padstack.get_padstack()->well_known_name);
+    well_known_name_entry->set_text(padstack.well_known_name);
     well_known_name_entry->signal_changed().connect([this, well_known_name_entry] { core_padstack.set_needs_save(); });
 
-    core_padstack.signal_save().connect([this, well_known_name_entry] {
-        core_padstack.get_padstack()->name = name_entry->get_text();
-        core_padstack.get_padstack()->well_known_name = well_known_name_entry->get_text();
-        header_button->set_label(core_padstack.get_padstack()->name);
-    });
-
     auto type_combo = Gtk::manage(new Gtk::ComboBoxText());
     type_combo->append("top", "Top");
     type_combo->append("bottom", "Bottom");
@@ -91,39 +61,62 @@ void ImpPadstack::construct()
     type_combo->append("mechanical", "Mechanical");
     type_combo->show();
     header_button->add_widget("Type", type_combo);
-    type_combo->set_active_id(Padstack::type_lut.lookup_reverse(core_padstack.get_padstack()->type));
+    type_combo->set_active_id(Padstack::type_lut.lookup_reverse(padstack.type));
     type_combo->signal_changed().connect([this] { core_padstack.set_needs_save(); });
 
-    auto editor = new ImpPadstackParameterSetEditor(&core_padstack.parameter_set, &core_padstack.parameters_required);
-    editor->populate();
-    auto parameter_window = new ParameterWindow(main_window, &core_padstack.parameter_program_code,
-                                                &core_padstack.parameter_set, editor);
+    core_padstack.signal_save().connect([this, well_known_name_entry, type_combo] {
+        padstack.name = name_entry->get_text();
+        padstack.well_known_name = well_known_name_entry->get_text();
+        padstack.type = Padstack::type_lut.lookup(type_combo->get_active_id());
+    });
+
+    auto editor = new ParameterSetEditor(&core_padstack.parameter_set, false); //, &core_padstack.parameters_required);
+    editor->signal_create_extra_widget().connect([this](ParameterID id) {
+        auto w = Gtk::manage(new MyCheckButton("Required"));
+        w->set_tooltip_text("Parameter has to be set in pad");
+        w->set_active(core_padstack.parameters_required.count(id));
+        w->signal_toggled().connect([this, id, w] {
+            if (w->get_active()) {
+                core_padstack.parameters_required.insert(id);
+            }
+            else {
+                core_padstack.parameters_required.erase(id);
+            }
+        });
+        return w;
+    });
+
+    editor->signal_remove_extra_widget().connect(
+            [this](ParameterID id) { core_padstack.parameters_required.erase(id); });
+
+    parameter_window = new ParameterWindow(main_window, &core_padstack.parameter_program_code,
+                                           &core_padstack.parameter_set, editor);
     parameter_window->signal_changed().connect([this] { core_padstack.set_needs_save(); });
     parameter_window_add_polygon_expand(parameter_window);
     {
-        auto button = Gtk::manage(new Gtk::Button("Parameters..."));
+        auto button = Gtk::manage(new Gtk::Button("Parameters…"));
         main_window->header->pack_start(*button);
         button->show();
-        button->signal_clicked().connect([parameter_window] { parameter_window->present(); });
+        button->signal_clicked().connect([this] { parameter_window->present(); });
     }
 
 
-    parameter_window->signal_apply().connect([this, parameter_window] {
+    parameter_window->signal_apply().connect([this] {
         if (core->tool_is_active())
             return;
-        auto ps = core_padstack.get_padstack();
-        auto r_compile = ps->parameter_program.set_code(core_padstack.parameter_program_code);
-        if (r_compile.first) {
-            parameter_window->set_error_message("<b>Compile error:</b>" + r_compile.second);
+        auto &ps = padstack;
+
+        if (auto r = ps.parameter_program.set_code(core_padstack.parameter_program_code)) {
+            parameter_window->set_error_message("<b>Compile error:</b>" + r.value());
             return;
         }
         else {
             parameter_window->set_error_message("");
         }
-        ps->parameter_set = core_padstack.parameter_set;
-        auto r = ps->parameter_program.run(ps->parameter_set);
-        if (r.first) {
-            parameter_window->set_error_message("<b>Run error:</b>" + r.second);
+        ps.parameter_set = core_padstack.parameter_set;
+
+        if (auto r = ps.parameter_program.run(ps.parameter_set)) {
+            parameter_window->set_error_message("<b>Run error:</b>" + r.value());
             return;
         }
         else {
@@ -132,24 +125,14 @@ void ImpPadstack::construct()
         core_padstack.rebuild();
         canvas_update();
     });
-    core->signal_tool_changed().connect(
-            [parameter_window](ToolID t) { parameter_window->set_can_apply(t == ToolID::NONE); });
-
-    core_padstack.signal_save().connect([this, type_combo] {
-        core_padstack.get_padstack()->type = Padstack::type_lut.lookup(type_combo->get_active_id());
-    });
+    core->signal_tool_changed().connect([this](ToolID t) { parameter_window->set_can_apply(t == ToolID::NONE); });
 
     add_action_button(make_action(ToolID::PLACE_SHAPE));
     add_action_button(make_action(ToolID::PLACE_SHAPE_RECTANGLE));
     add_action_button(make_action(ToolID::PLACE_SHAPE_OBROUND));
     add_action_button(make_action(ToolID::PLACE_HOLE)).set_margin_top(5);
     add_action_button(make_action(ToolID::PLACE_HOLE_SLOT));
-    {
-        auto &b = add_action_button(make_action(ToolID::DRAW_POLYGON));
-        b.set_margin_top(5);
-        b.add_action(make_action(ToolID::DRAW_POLYGON_RECTANGLE));
-        b.add_action(make_action(ToolID::DRAW_POLYGON_CIRCLE));
-    }
+    add_action_button_polygon().set_margin_top(5);
     update_header();
 }
 
@@ -172,18 +155,21 @@ std::map<ObjectType, ImpBase::SelectionFilterInfo> ImpPadstack::get_selection_fi
     const std::vector<int> my_layers = {BoardLayers::TOP_PASTE,   BoardLayers::TOP_MASK,      BoardLayers::TOP_COPPER,
                                         BoardLayers::IN1_COPPER,  BoardLayers::BOTTOM_COPPER, BoardLayers::BOTTOM_MASK,
                                         BoardLayers::BOTTOM_PASTE};
+    using Flag = ImpBase::SelectionFilterInfo::Flag;
     std::map<ObjectType, ImpBase::SelectionFilterInfo> r = {
-            {ObjectType::SHAPE, {my_layers, false}},
+            {ObjectType::SHAPE, {my_layers, Flag::DEFAULT}},
             {ObjectType::HOLE, {}},
-            {ObjectType::POLYGON, {my_layers, false}},
+            {ObjectType::POLYGON, {my_layers, Flag::DEFAULT}},
     };
     return r;
 }
 
 void ImpPadstack::update_header()
 {
-    header_button->set_label(name_entry->get_text());
-    set_window_title(name_entry->get_text());
+    const auto &name = name_entry->get_text();
+    header_button->set_label(name);
+    set_window_title(name);
+    parameter_window->set_subtitle(name);
 }
 
 
