@@ -31,7 +31,7 @@ ImpSchematic::ImpSchematic(const std::string &schematic_filename, const std::str
 
 void ImpSchematic::canvas_update()
 {
-    canvas->update(*core_schematic.get_canvas_data());
+    canvas->update(core_schematic.get_canvas_data());
     warnings_box->update(core_schematic.get_sheet()->warnings);
     update_highlights();
 }
@@ -274,13 +274,13 @@ void ImpSchematic::construct()
     hamburger_menu->append("Annotate", "win.annotate");
     add_tool_action(ToolID::ANNOTATE, "annotate");
 
-    hamburger_menu->append("Buses...", "win.manage_buses");
+    hamburger_menu->append("Buses…", "win.manage_buses");
     add_tool_action(ToolID::MANAGE_BUSES, "manage_buses");
 
-    hamburger_menu->append("Net classes...", "win.manage_nc");
+    hamburger_menu->append("Net classes…", "win.manage_nc");
     add_tool_action(ToolID::MANAGE_NET_CLASSES, "manage_nc");
 
-    hamburger_menu->append("Power Nets...", "win.manage_pn");
+    hamburger_menu->append("Power Nets…", "win.manage_pn");
     add_tool_action(ToolID::MANAGE_POWER_NETS, "manage_pn");
 
     hamburger_menu->append("Schematic properties", "win.sch_properties");
@@ -476,7 +476,7 @@ void ImpSchematic::construct()
         g_simple_action_set_state(toggle_snap_to_targets_action->gobj(),
                                   g_variant_new_boolean(canvas->snap_to_targets));
     });
-    view_options_menu->append("Snap to targets", "win.snap_to_targets");
+    view_options_menu_append_action("Snap to targets", "win.snap_to_targets");
 
     toggle_snap_to_targets_action = main_window->add_action_bool("snap_to_targets", canvas->snap_to_targets);
     toggle_snap_to_targets_action->signal_change_state().connect([this](const Glib::VariantBase &v) {
@@ -533,6 +533,8 @@ void ImpSchematic::construct()
     add_action_button_line();
     add_action_button(make_action(ToolID::PLACE_TEXT));
 
+    update_monitor();
+
     if (!core_schematic.get_project_meta_loaded_from_block())
         core_schematic.set_needs_save();
 }
@@ -1079,14 +1081,15 @@ ToolID ImpSchematic::get_tool_for_drag_move(bool ctrl, const std::set<Selectable
 void ImpSchematic::expand_selection_for_property_panel(std::set<SelectableRef> &sel_extra,
                                                        const std::set<SelectableRef> &sel)
 {
+    const auto &sheet = *core_schematic.get_sheet();
     for (const auto &it : sel) {
         switch (it.type) {
         case ObjectType::SCHEMATIC_SYMBOL:
             sel_extra.emplace(core_schematic.get_schematic_symbol(it.uuid)->component->uuid, ObjectType::COMPONENT);
             break;
         case ObjectType::JUNCTION:
-            if (core->get_junction(it.uuid)->net) {
-                sel_extra.emplace(core->get_junction(it.uuid)->net->uuid, ObjectType::NET);
+            if (sheet.junctions.at(it.uuid).net) {
+                sel_extra.emplace(sheet.junctions.at(it.uuid).net->uuid, ObjectType::NET);
             }
             break;
         case ObjectType::LINE_NET: {
@@ -1111,4 +1114,15 @@ void ImpSchematic::expand_selection_for_property_panel(std::set<SelectableRef> &
         }
     }
 }
+
+void ImpSchematic::update_monitor()
+{
+    ItemSet mon_items = core_schematic.get_block()->get_pool_items_used();
+    {
+        ItemSet items = core_schematic.get_schematic()->get_pool_items_used();
+        mon_items.insert(items.begin(), items.end());
+    }
+    set_monitor_items(mon_items);
+}
+
 } // namespace horizon
