@@ -3,9 +3,12 @@
 #include "header_button.hpp"
 #include "pool/part.hpp"
 #include "symbol_preview/symbol_preview_window.hpp"
+#include "symbol_preview/symbol_preview_expand_window.hpp"
 #include "widgets/unplaced_box.hpp"
 #include "core/tool_id.hpp"
 #include "widgets/action_button.hpp"
+#include "widgets/help_button.hpp"
+#include "help_texts.hpp"
 
 namespace horizon {
 ImpSymbol::ImpSymbol(const std::string &symbol_filename, const std::string &pool_path)
@@ -17,8 +20,8 @@ ImpSymbol::ImpSymbol(const std::string &symbol_filename, const std::string &pool
 
 void ImpSymbol::canvas_update()
 {
-    canvas->update(*core_symbol.get_canvas_data());
-    symbol_preview_window->update(*core_symbol.get_canvas_data());
+    canvas->update(core_symbol.get_canvas_data());
+    symbol_preview_window->update(core_symbol.get_canvas_data());
     update_bbox_annotation();
 }
 
@@ -30,6 +33,7 @@ void ImpSymbol::update_monitor()
 void ImpSymbol::apply_preferences()
 {
     symbol_preview_window->set_canvas_appearance(preferences.canvas_non_layer.appearance);
+    symbol_preview_expand_window->set_canvas_appearance(preferences.canvas_non_layer.appearance);
     ImpBase::apply_preferences();
 }
 
@@ -59,8 +63,11 @@ void ImpSymbol::construct()
         canvas->set_selection(sel);
     });
 
+    symbol_preview_expand_window = new SymbolPreviewExpandWindow(main_window, core_symbol.get_symbol());
+    core->signal_rebuilt().connect([this] { symbol_preview_expand_window->update(); });
+
     {
-        auto button = Gtk::manage(new Gtk::Button("Preview..."));
+        auto button = Gtk::manage(new Gtk::Button("Preview…"));
         main_window->header->pack_start(*button);
         button->show();
         button->signal_clicked().connect([this] { symbol_preview_window->present(); });
@@ -106,12 +113,38 @@ void ImpSymbol::construct()
         header_button->add_widget("Unit", box);
     }
 
-    can_expand_switch = Gtk::manage(new Gtk::Switch);
-    can_expand_switch->set_active(symbol.can_expand);
-    can_expand_switch->set_halign(Gtk::ALIGN_START);
-    can_expand_switch->property_active().signal_changed().connect([this] { core_symbol.set_needs_save(); });
+    {
+        auto box = Gtk::manage(new Gtk::Box(Gtk::ORIENTATION_HORIZONTAL, 10));
 
-    header_button->add_widget("Can expand", can_expand_switch);
+        can_expand_switch = Gtk::manage(new Gtk::Switch);
+        can_expand_switch->set_active(symbol.can_expand);
+        can_expand_switch->set_halign(Gtk::ALIGN_START);
+        can_expand_switch->set_valign(Gtk::ALIGN_CENTER);
+        can_expand_switch->property_active().signal_changed().connect([this] {
+            core_symbol.set_needs_save();
+            const bool a = can_expand_switch->get_active();
+            expand_preview_button->set_sensitive(a);
+            if (!a)
+                symbol_preview_expand_window->hide();
+        });
+        can_expand_switch->show();
+        box->pack_start(*can_expand_switch, false, false, 0);
+        auto help_button = Gtk::manage(new HelpButton(HelpTexts::SYMBOL_CAN_EXPAND));
+        help_button->show();
+        box->pack_start(*help_button, false, false, 0);
+
+        expand_preview_button = Gtk::manage(new Gtk::Button("Preview"));
+        expand_preview_button->signal_clicked().connect([this] {
+            symbol_preview_expand_window->present();
+            symbol_preview_expand_window->update();
+            symbol_preview_expand_window->zoom_to_fit();
+        });
+        expand_preview_button->show();
+        expand_preview_button->set_sensitive(symbol.can_expand);
+        box->pack_end(*expand_preview_button, false, false, 0);
+
+        header_button->add_widget("Can expand", box);
+    }
 
     {
         auto box = Gtk::manage(new Gtk::Box(Gtk::ORIENTATION_HORIZONTAL));
