@@ -11,7 +11,7 @@
 namespace horizon {
 void RuleEditorDiffpair::populate()
 {
-    rule2 = dynamic_cast<RuleDiffpair *>(rule);
+    rule2 = &dynamic_cast<RuleDiffpair &>(rule);
 
     auto editor = Gtk::manage(new Gtk::Box(Gtk::ORIENTATION_VERTICAL, 20));
     editor->set_margin_start(20);
@@ -36,18 +36,18 @@ void RuleEditorDiffpair::populate()
         grid->attach(*la, 1, 0, 1, 1);
     }
 
-    auto net_class_button = Gtk::manage(new NetClassButton(core->get_block()));
+    auto net_class_button = Gtk::manage(new NetClassButton(*core.get_block()));
     net_class_button->set_net_class(rule2->net_class);
     net_class_button->signal_net_class_changed().connect([this](const UUID &net_class) {
         rule2->net_class = net_class;
         s_signal_updated.emit();
     });
     if (!rule2->net_class)
-        net_class_button->set_net_class(core->get_block()->net_class_default->uuid);
+        net_class_button->set_net_class(core.get_block()->net_class_default->uuid);
     grid->attach(*net_class_button, 0, 1, 1, 1);
 
     auto *layer_combo = Gtk::manage(new Gtk::ComboBoxText());
-    for (const auto &it : core->get_layer_provider()->get_layers()) {
+    for (const auto &it : core.get_layer_provider().get_layers()) {
         if (it.second.copper)
             layer_combo->insert(0, std::to_string(it.first), it.second.name + ": " + std::to_string(it.first));
     }
