@@ -4,11 +4,12 @@
 #include "rule_match_editor.hpp"
 #include "widgets/chooser_buttons.hpp"
 #include "widgets/plane_editor.hpp"
+#include "common/layer_provider.hpp"
 
 namespace horizon {
 void RuleEditorPlane::populate()
 {
-    rule2 = dynamic_cast<RulePlane *>(rule);
+    rule2 = &dynamic_cast<RulePlane &>(rule);
 
     auto editor = Gtk::manage(new Gtk::Box(Gtk::ORIENTATION_VERTICAL, 20));
     editor->set_margin_start(20);
@@ -32,13 +33,13 @@ void RuleEditorPlane::populate()
         grid->attach(*la, 1, 0, 1, 1);
     }
 
-    auto match_editor = Gtk::manage(new RuleMatchEditor(&rule2->match, core));
+    auto match_editor = Gtk::manage(new RuleMatchEditor(rule2->match, core));
     match_editor->set_orientation(Gtk::ORIENTATION_HORIZONTAL);
     match_editor->signal_updated().connect([this] { s_signal_updated.emit(); });
     grid->attach(*match_editor, 0, 1, 1, 1);
 
     auto *layer_combo = Gtk::manage(new Gtk::ComboBoxText());
-    for (const auto &it : core->get_layer_provider()->get_layers()) {
+    for (const auto &it : core.get_layer_provider().get_layers()) {
         if (it.second.copper)
             layer_combo->insert(0, std::to_string(it.first), it.second.name + ": " + std::to_string(it.first));
     }
