@@ -1,12 +1,15 @@
 #include "tool_popover.hpp"
 #include "action_catalog.hpp"
 #include "util/str_util.hpp"
+#include <iostream>
 
 namespace horizon {
 ToolPopover::ToolPopover(Gtk::Widget *parent, ActionCatalogItem::Availability availability) : Gtk::Popover(*parent)
 {
-    auto box = Gtk::manage(new Gtk::Box(Gtk::ORIENTATION_VERTICAL, 3));
+    get_style_context()->add_class("imp-tool-popover");
+    auto box = Gtk::manage(new Gtk::Box(Gtk::ORIENTATION_VERTICAL));
     search_entry = Gtk::manage(new Gtk::SearchEntry());
+    search_entry->set_margin_bottom(5);
     box->pack_start(*search_entry, false, false, 0);
 
     store = Gtk::ListStore::create(list_columns);
@@ -67,7 +70,7 @@ ToolPopover::ToolPopover(Gtk::Widget *parent, ActionCatalogItem::Availability av
     search_entry->signal_activate().connect(sigc::mem_fun(*this, &ToolPopover::emit_tool_activated));
     view->signal_row_activated().connect([this](auto a, auto b) { this->emit_tool_activated(); });
 
-    auto sc = Gtk::manage(new Gtk::ScrolledWindow());
+    sc = Gtk::manage(new Gtk::ScrolledWindow());
     sc->set_policy(Gtk::POLICY_NEVER, Gtk::POLICY_AUTOMATIC);
     sc->set_shadow_type(Gtk::SHADOW_IN);
     sc->set_min_content_height(210);
@@ -103,7 +106,7 @@ ToolPopover::ToolPopover(Gtk::Widget *parent, ActionCatalogItem::Availability av
     sc2->set_policy(Gtk::POLICY_NEVER, Gtk::POLICY_AUTOMATIC);
     sc2->set_shadow_type(Gtk::SHADOW_IN);
     sc2->add(*view_group);
-    sc2->set_margin_end(3);
+    sc2->set_margin_end(5);
 
     revealer = Gtk::manage(new Gtk::Revealer);
     revealer->add(*sc2);
@@ -115,6 +118,38 @@ ToolPopover::ToolPopover(Gtk::Widget *parent, ActionCatalogItem::Availability av
     box2->pack_start(*sc, true, true, 0);
     box->pack_start(*box2, true, true, 0);
 
+    auto evb = Gtk::manage(new Gtk::EventBox);
+    evb->set_size_request(-1, 7);
+    evb->signal_realize().connect([evb] {
+        auto dpy = evb->get_display();
+        evb->get_window()->set_cursor(Gdk::Cursor::create(dpy, "ns-resize"));
+    });
+    evb->signal_button_press_event().connect([this](GdkEventButton *ev) {
+        if (ev->button == 1) {
+            y_start = ev->y_root;
+            sc_height = sc->get_min_content_height();
+            return true;
+        }
+        return false;
+    });
+    evb->signal_button_release_event().connect([this](GdkEventButton *ev) {
+        if (ev->button == 1) {
+            y_start = NAN;
+            return true;
+        }
+        return false;
+    });
+    evb->signal_motion_notify_event().connect([this](GdkEventMotion *ev) {
+        if (!std::isnan(y_start)) {
+            sc->set_min_content_height(sc_height + (ev->y_root - y_start));
+            return true;
+        }
+        return false;
+    });
+    box->set_margin_start(5);
+    box->set_margin_end(5);
+    box->set_margin_top(5);
+    box->pack_start(*evb, false, false, 0);
 
     for (const auto &it : action_catalog) {
         if ((it.second.availability & availability) && !(it.second.flags & ActionCatalogItem::FLAGS_NO_POPOVER)) {
@@ -139,23 +174,11 @@ ToolPopover::ToolPopover(Gtk::Widget *parent, ActionCatalogItem::Availability av
         row[list_columns_group.group] = ActionGroup::ALL;
     }
 
-    static const std::map<ActionGroup, ActionCatalogItem::Availability> group_av = {
-            {ActionGroup::BOARD, ActionCatalogItem::AVAILABLE_IN_BOARD},
-            {ActionGroup::SCHEMATIC, ActionCatalogItem::AVAILABLE_IN_SCHEMATIC},
-            {ActionGroup::SYMBOL, ActionCatalogItem::AVAILABLE_IN_SYMBOL},
-            {ActionGroup::PADSTACK, ActionCatalogItem::AVAILABLE_IN_PADSTACK},
-            {ActionGroup::PACKAGE, ActionCatalogItem::AVAILABLE_IN_PACKAGE},
-            {ActionGroup::LAYER, ActionCatalogItem::AVAILABLE_LAYERED},
-            {ActionGroup::FRAME, ActionCatalogItem::AVAILABLE_IN_FRAME},
-            {ActionGroup::GROUP_TAG, ActionCatalogItem::AVAILABLE_IN_SCHEMATIC},
-    };
-
     for (const auto &it : action_group_catalog) {
-        bool show = false;
-        if (group_av.count(it.first) == 0)
-            show = true;
-        else
-            show = group_av.at(it.first) & availability;
+        bool show = std::any_of(action_catalog.begin(), action_catalog.end(), [availability, it](const auto &x) {
+            return (x.second.group == it.first) && (x.second.availability & availability);
+        });
+
         if (show) {
             Gtk::TreeModel::Row row = *(store_group->append());
             row[list_columns_group.name] = it.second;
@@ -181,7 +204,7 @@ void ToolPopover::emit_tool_activated()
     }
 }
 
-void ToolPopover::set_can_begin(const std::map<std::pair<ActionID, ToolID>, bool> &can_begin)
+void ToolPopover::set_can_begin(const std::map<ActionToolID, bool> &can_begin)
 {
     for (auto &it : store->children()) {
         auto k = std::make_pair(it[list_columns.action_id], it[list_columns.tool_id]);
@@ -194,14 +217,9 @@ void ToolPopover::set_can_begin(const std::map<std::pair<ActionID, ToolID>, bool
     }
 }
 
-void ToolPopover::set_key_sequences(std::pair<ActionID, ToolID> action_id, const std::vector<KeySequence> &seqs)
+void ToolPopover::set_key_sequences(ActionToolID action_id, const std::vector<KeySequence> &seqs)
 {
-    std::stringstream s;
-    std::transform(seqs.begin(), seqs.end(), std::ostream_iterator<std::string>(s, ","),
-                   [](const auto &x) { return key_sequence_to_string(x); });
-    auto str = s.str();
-    if (str.size())
-        str.pop_back();
+    auto str = key_sequences_to_string(seqs);
     for (auto &it : store->children()) {
         if (it[list_columns.tool_id] == action_id.second && it[list_columns.action_id] == action_id.first) {
             it[list_columns.keys] = str;
