@@ -3,15 +3,17 @@
 #include "rules/cache.hpp"
 #include "util/accumulator.hpp"
 #include "util/util.hpp"
+#include "util/str_util.hpp"
+#include "board/board_layers.hpp"
 #include <ctype.h>
 
 namespace horizon {
-RulesCheckResult PackageRules::check_package(const class Package *pkg) const
+RulesCheckResult PackageRules::check_package(const class Package &pkg) const
 {
     RulesCheckResult r;
     r.level = RulesCheckErrorLevel::PASS;
 
-    if (pkg->name.size() == 0) {
+    if (pkg.name.size() == 0) {
         r.errors.emplace_back(RulesCheckErrorLevel::FAIL);
         auto &x = r.errors.back();
         x.comment = "Package has no name";
@@ -21,7 +23,7 @@ RulesCheckResult PackageRules::check_package(const class Package *pkg) const
     int silk_refdes_count = 0;
     int assy_refdes_count = 0;
     const Text *silkscreen_refdes = nullptr;
-    for (const auto &it : pkg->texts) {
+    for (const auto &it : pkg.texts) {
         const auto &txt = it.second;
         if (txt.text == "$RD"
             && (txt.layer == BoardLayers::TOP_SILKSCREEN || txt.layer == BoardLayers::BOTTOM_SILKSCREEN)) {
@@ -63,7 +65,7 @@ RulesCheckResult PackageRules::check_package(const class Package *pkg) const
     int courtyard_top_count = 0;
     int courtyard_bottom_count = 0;
 
-    for (const auto &it : pkg->polygons) {
+    for (const auto &it : pkg.polygons) {
         if (it.second.layer == BoardLayers::TOP_COURTYARD) {
             courtyard_top_count++;
         }
@@ -74,7 +76,7 @@ RulesCheckResult PackageRules::check_package(const class Package *pkg) const
 
     int lines_assy = 0;
     int lines_pkg = 0;
-    for (const auto &it : pkg->lines) {
+    for (const auto &it : pkg.lines) {
         if (it.second.layer == BoardLayers::TOP_ASSEMBLY || it.second.layer == BoardLayers::BOTTOM_ASSEMBLY) {
             lines_assy++;
         }
@@ -95,7 +97,7 @@ RulesCheckResult PackageRules::check_package(const class Package *pkg) const
         x.has_location = false;
     }
 
-    for (const auto &it : pkg->polygons) {
+    for (const auto &it : pkg.polygons) {
         if (it.second.layer == BoardLayers::TOP_COURTYARD || it.second.layer == BoardLayers::BOTTOM_COURTYARD) {
             if (it.second.parameter_class != "courtyard") {
                 r.errors.emplace_back(RulesCheckErrorLevel::FAIL);
@@ -119,7 +121,7 @@ RulesCheckResult PackageRules::check_package(const class Package *pkg) const
     }
 
     std::set<std::string> pad_names;
-    for (const auto &it : pkg->pads) {
+    for (const auto &it : pkg.pads) {
         const auto &name = it.second.name;
         if (pad_names.insert(name).second == false) {
             r.errors.emplace_back(RulesCheckErrorLevel::FAIL);
@@ -149,7 +151,7 @@ RulesCheckResult PackageRules::check_package(const class Package *pkg) const
         }
     }
 
-    for (const auto &it : pkg->polygons) {
+    for (const auto &it : pkg.polygons) {
         if (it.second.layer == BoardLayers::TOP_SILKSCREEN || it.second.layer == BoardLayers::BOTTOM_SILKSCREEN) {
             r.errors.emplace_back(RulesCheckErrorLevel::FAIL);
             auto &x = r.errors.back();
@@ -158,16 +160,99 @@ RulesCheckResult PackageRules::check_package(const class Package *pkg) const
         }
     }
 
+    {
+        std::string param_code = pkg.parameter_program.get_code();
+        trim(param_code);
+        if (!param_code.size())
+            r.errors.emplace_back(RulesCheckErrorLevel::WARN, "Empty parameter program");
+    }
+
+    if (pkg.parameter_set.count(ParameterID::COURTYARD_EXPANSION) == 0) {
+        r.errors.emplace_back(RulesCheckErrorLevel::WARN, "Missing courtyard expansion parameter");
+    }
+
     r.update();
     return r;
 }
 
-RulesCheckResult PackageRules::check(RuleID id, const Package *pkg, RulesCheckCache &cache) const
+
+RulesCheckResult PackageRules::check_clearance(const class Package &pkg) const
+{
+    RulesCheckResult r;
+    r.level = RulesCheckErrorLevel::PASS;
+
+    CanvasPatch ca;
+    ca.update(pkg);
+
+    std::map<int, ClipperLib::ClipperOffset> clippers_offset;
+    std::set<int> layers;
+    for (const auto &[key, paths] : ca.get_patches()) {
+        if (any_of(static_cast<BoardLayers::Layer>(key.layer),
+                   {BoardLayers::TOP_COPPER, BoardLayers::BOTTOM_COPPER, BoardLayers::TOP_PACKAGE,
+                    BoardLayers::BOTTOM_PACKAGE})) {
+            clippers_offset[key.layer].AddPaths(paths, ClipperLib::jtRound, ClipperLib::etClosedPolygon);
+        }
+        layers.insert(key.layer);
+    }
+    std::map<int, ClipperLib::Paths> paths;
+    for (auto &[layer, cl] : clippers_offset) {
+        if (BoardLayers::is_copper(layer)) {
+            cl.Execute(paths[layer], rule_clearance_package.clearance_silkscreen_cu);
+        }
+        else {
+            cl.Execute(paths[layer], rule_clearance_package.clearance_silkscreen_pkg);
+        }
+    }
+
+    static const std::vector<std::pair<int, int>> check_pairs = {
+            {BoardLayers::TOP_COPPER, BoardLayers::TOP_SILKSCREEN},
+            {BoardLayers::BOTTOM_COPPER, BoardLayers::BOTTOM_SILKSCREEN},
+            {BoardLayers::TOP_PACKAGE, BoardLayers::TOP_SILKSCREEN},
+            {BoardLayers::BOTTOM_PACKAGE, BoardLayers::BOTTOM_SILKSCREEN},
+    };
+
+    for (const auto [l_ex, l_silk] : check_pairs) {
+        if (layers.count(l_ex) && layers.count(l_silk)) {
+            ClipperLib::Clipper cl;
+            cl.AddPaths(paths.at(l_ex), ClipperLib::ptClip, true);
+            for (const auto &[key, p_paths] : ca.get_patches()) {
+                if (key.layer == l_silk) {
+                    cl.AddPaths(p_paths, ClipperLib::ptSubject, true);
+                }
+            }
+            ClipperLib::Paths errors;
+            cl.Execute(ClipperLib::ctIntersection, errors, ClipperLib::pftNonZero);
+            if (errors.size()) {
+                r.errors.emplace_back(RulesCheckErrorLevel::FAIL);
+                auto &e = r.errors.back();
+                e.has_location = true;
+                Accumulator<Coordi> acc;
+                for (const auto &ite : errors) {
+                    for (const auto &ite2 : ite) {
+                        acc.accumulate({ite2.X, ite2.Y});
+                    }
+                }
+                e.location = acc.get();
+                e.comment = BoardLayers::get_layer_name(l_ex) + " near " + BoardLayers::get_layer_name(l_silk);
+                e.error_polygons = errors;
+            }
+        }
+    }
+
+    r.update();
+    return r;
+}
+
+
+RulesCheckResult PackageRules::check(RuleID id, const Package &pkg) const
 {
     switch (id) {
     case RuleID::PACKAGE_CHECKS:
         return check_package(pkg);
 
+    case RuleID::CLEARANCE_PACKAGE:
+        return check_clearance(pkg);
+
     default:
         return RulesCheckResult();
     }
