@@ -7,7 +7,7 @@
 #include "pool/symbol.hpp"
 #include "util/gtk_util.hpp"
 #include "util/util.hpp"
-#include "../part_wizard/location_entry.hpp"
+#include "widgets/location_entry.hpp"
 #include "nlohmann/json.hpp"
 
 namespace horizon {
