@@ -8,7 +8,7 @@
 #include "pool/symbol.hpp"
 #include "util/gtk_util.hpp"
 #include "util/util.hpp"
-#include "../part_wizard/location_entry.hpp"
+#include "widgets/location_entry.hpp"
 #include "nlohmann/json.hpp"
 #include "util/pool_completion.hpp"
 
@@ -71,7 +71,7 @@ public:
     {
         if (grid->get_visible()) {
             return DuplicatePartWidget::duplicate_package(pool, pkg.uuid, location_entry->get_filename(),
-                                                          name_entry->get_text());
+                                                          name_entry->get_text(), filenames);
         }
         else {
             return pkg.uuid;
