@@ -9,11 +9,11 @@ public:
     friend class DuplicateUnitWidget;
     friend class DuplicateEntityWidget;
     friend class DuplicatePartWidget;
-    DuplicateWindow(class Pool *p, ObjectType ty, const UUID &uu);
+    DuplicateWindow(class Pool &p, ObjectType ty, const UUID &uu);
     std::vector<std::string> get_filenames() const;
 
 private:
-    class Pool *pool = nullptr;
+    class Pool &pool;
     class DuplicateBase *duplicate_widget = nullptr;
     bool duplicated = false;
     void handle_duplicate();
