@@ -7,8 +7,13 @@
 #include "pool/part.hpp"
 #include "util/util.hpp"
 #include "util/str_util.hpp"
-#include "pool/pool.hpp"
+#include "util/gtk_util.hpp"
+#include "pool/ipool.hpp"
 #include "nlohmann/json.hpp"
+#include "widgets/color_box.hpp"
+#include "checks/check_entity.hpp"
+#include "checks/check_unit.hpp"
+#include "checks/check_part.hpp"
 
 namespace horizon {
 
@@ -27,7 +32,7 @@ public:
         : EditorWindowStore(fn), unit(filename.size() ? Unit::new_from_file(filename) : Unit(UUID::random()))
     {
     }
-    void save_as(const std::string &fn)
+    void save_as(const std::string &fn) override
     {
         save_json_to_file(fn, unit.serialize());
         filename = fn;
@@ -40,17 +45,29 @@ public:
     {
         return unit.uuid;
     }
+    RulesCheckResult run_checks() const override
+    {
+        return check_unit(unit);
+    }
+    const FileVersion &get_version() const override
+    {
+        return unit.version;
+    }
+    ObjectType get_type() const override
+    {
+        return ObjectType::UNIT;
+    }
     Unit unit;
 };
 
 class EntityStore : public EditorWindowStore {
 public:
-    EntityStore(const std::string &fn, class Pool *pool)
+    EntityStore(const std::string &fn, class IPool &pool)
         : EditorWindowStore(fn),
-          entity(filename.size() ? Entity::new_from_file(filename, *pool) : Entity(UUID::random()))
+          entity(filename.size() ? Entity::new_from_file(filename, pool) : Entity(UUID::random()))
     {
     }
-    void save_as(const std::string &fn)
+    void save_as(const std::string &fn) override
     {
         save_json_to_file(fn, entity.serialize());
         filename = fn;
@@ -63,16 +80,28 @@ public:
     {
         return entity.uuid;
     }
+    RulesCheckResult run_checks() const override
+    {
+        return check_entity(entity);
+    }
+    const FileVersion &get_version() const override
+    {
+        return entity.version;
+    }
+    ObjectType get_type() const override
+    {
+        return ObjectType::ENTITY;
+    }
     Entity entity;
 };
 
 class PartStore : public EditorWindowStore {
 public:
-    PartStore(const std::string &fn, class Pool *pool)
-        : EditorWindowStore(fn), part(filename.size() ? Part::new_from_file(filename, *pool) : Part(UUID::random()))
+    PartStore(const std::string &fn, class IPool &pool)
+        : EditorWindowStore(fn), part(filename.size() ? Part::new_from_file(filename, pool) : Part(UUID::random()))
     {
     }
-    void save_as(const std::string &fn)
+    void save_as(const std::string &fn) override
     {
         save_json_to_file(fn, part.serialize());
         filename = fn;
@@ -85,12 +114,24 @@ public:
     {
         return part.uuid;
     }
+    RulesCheckResult run_checks() const override
+    {
+        return check_part(part);
+    }
+    const FileVersion &get_version() const override
+    {
+        return part.version;
+    }
+    ObjectType get_type() const override
+    {
+        return ObjectType::PART;
+    }
     Part part;
 };
 
-EditorWindow::EditorWindow(ObjectType ty, const std::string &filename, Pool *p, class PoolParametric *pp,
+EditorWindow::EditorWindow(ObjectType ty, const std::string &filename, IPool *p, class PoolParametric *pp,
                            bool read_only, bool is_temp)
-    : Gtk::Window(), type(ty), pool(p), pool_parametric(pp),
+    : Gtk::Window(), type(ty), pool(*p), pool_parametric(pp),
       state_store(this, "pool-editor-win-" + std::to_string(static_cast<int>(type)))
 {
     set_type_hint(Gdk::WINDOW_TYPE_HINT_DIALOG);
@@ -98,10 +139,28 @@ EditorWindow::EditorWindow(ObjectType ty, const std::string &filename, Pool *p,
     set_titlebar(*hb);
 
     save_button = Gtk::manage(new Gtk::Button());
-    if (read_only)
-        save_button->set_sensitive(false);
     hb->pack_start(*save_button);
 
+    check_button = Gtk::manage(new Gtk::MenuButton());
+    {
+        auto box = Gtk::manage(new Gtk::Box(Gtk::ORIENTATION_HORIZONTAL, 5));
+        check_color_box = Gtk::manage(new ColorBox);
+        check_color_box->set_valign(Gtk::ALIGN_CENTER);
+        check_color_box->set_size_request(16, 16);
+        box->pack_start(*check_color_box, false, false, 0);
+        auto la = Gtk::manage(new Gtk::Label("Checks"));
+        box->pack_start(*la, false, false, 0);
+        check_button->add(*box);
+    }
+    check_popover = Gtk::manage(new Gtk::Popover);
+    check_button->set_popover(*check_popover);
+    check_label = Gtk::manage(new Gtk::Label("foo"));
+    check_label->property_margin() = 10;
+    check_popover->add(*check_label);
+    check_label->show();
+    hb->pack_end(*check_button);
+
+
     hb->show_all();
     hb->set_show_close_button(true);
 
@@ -111,7 +170,7 @@ EditorWindow::EditorWindow(ObjectType ty, const std::string &filename, Pool *p,
     case ObjectType::UNIT: {
         auto st = new UnitStore(filename);
         store.reset(st);
-        auto ed = UnitEditor::create(&st->unit, pool);
+        auto ed = UnitEditor::create(st->unit, pool);
         editor = ed;
         iface = ed;
         hb->set_title("Unit Editor");
@@ -119,7 +178,7 @@ EditorWindow::EditorWindow(ObjectType ty, const std::string &filename, Pool *p,
     case ObjectType::ENTITY: {
         auto st = new EntityStore(filename, pool);
         store.reset(st);
-        auto ed = EntityEditor::create(&st->entity, pool);
+        auto ed = EntityEditor::create(st->entity, pool);
         editor = ed;
         iface = ed;
         hb->set_title("Entity Editor");
@@ -127,17 +186,42 @@ EditorWindow::EditorWindow(ObjectType ty, const std::string &filename, Pool *p,
     case ObjectType::PART: {
         auto st = new PartStore(filename, pool);
         store.reset(st);
-        auto ed = PartEditor::create(&st->part, pool, pool_parametric);
+        auto ed = PartEditor::create(st->part, pool, *pool_parametric);
         editor = ed;
         iface = ed;
         hb->set_title("Part Editor");
     } break;
     default:;
     }
+
+    auto box = Gtk::manage(new Gtk::Box(Gtk::Orientation::ORIENTATION_VERTICAL, 0));
+    add(*box);
+    box->show();
+
+    {
+        const auto &version = store->get_version();
+        if (version.get_app() != version.get_file()) {
+            info_bar = Gtk::manage(new Gtk::InfoBar());
+            auto label = Gtk::manage(new Gtk::Label);
+            label->set_line_wrap(true);
+            dynamic_cast<Gtk::Container &>(*info_bar->get_content_area()).add(*label);
+            label->show();
+            label->set_markup(version.get_message(store->get_type()));
+            if (version.get_app() < version.get_file()) {
+                read_only = true;
+            }
+            info_bar->show();
+            box->pack_start(*info_bar, false, false, 0);
+        }
+    }
+
     editor->show();
-    add(*editor);
+    box->pack_start(*editor, true, true, 0);
     editor->unreference();
 
+    if (read_only)
+        save_button->set_sensitive(false);
+
     if (is_temp) {
         Gio::File::create_for_path(filename)->remove();
         store->filename.clear();
@@ -150,10 +234,18 @@ EditorWindow::EditorWindow(ObjectType ty, const std::string &filename, Pool *p,
         save_button->set_label("Save as..");
     }
 
-
-    if (iface) {
-        iface->signal_goto().connect([this](ObjectType t, UUID uu) { s_signal_goto.emit(t, uu); });
+    assert(iface);
+    iface->signal_goto().connect([this](ObjectType t, UUID uu) { s_signal_goto.emit(t, uu); });
+    if (!read_only) {
+        save_button->set_sensitive(iface->get_needs_save());
+        iface->signal_needs_save().connect([this] { save_button->set_sensitive(iface->get_needs_save()); });
     }
+    iface->signal_needs_save().connect([this] {
+        if (iface->get_needs_save()) {
+            run_checks();
+        }
+    });
+    run_checks();
 
     if (!state_store.get_default_set())
         set_default_size(-1, 600);
@@ -236,13 +328,13 @@ void EditorWindow::save()
         chooser->set_current_name(store->get_name() + ".json");
         switch (type) {
         case ObjectType::UNIT:
-            chooser->set_current_folder(Glib::build_filename(pool->get_base_path(), "units"));
+            chooser->set_current_folder(Glib::build_filename(pool.get_base_path(), "units"));
             break;
         case ObjectType::ENTITY:
-            chooser->set_current_folder(Glib::build_filename(pool->get_base_path(), "entities"));
+            chooser->set_current_folder(Glib::build_filename(pool.get_base_path(), "entities"));
             break;
         case ObjectType::PART:
-            chooser->set_current_folder(Glib::build_filename(pool->get_base_path(), "parts"));
+            chooser->set_current_folder(Glib::build_filename(pool.get_base_path(), "parts"));
             break;
         default:;
         }
@@ -260,6 +352,8 @@ void EditorWindow::save()
             need_update = true;
         }
     }
+    if (info_bar)
+        info_bar_hide(info_bar);
 }
 
 std::string EditorWindow::fix_filename(std::string s)
@@ -304,4 +398,23 @@ const UUID &EditorWindow::get_uuid() const
     return store->get_uuid();
 }
 
+void EditorWindow::run_checks()
+{
+    auto r = store->run_checks();
+    check_color_box->set_color(rules_check_error_level_to_color(r.level));
+    std::string s;
+    if (r.level == RulesCheckErrorLevel::PASS) {
+        s += "Checks passed";
+    }
+    else {
+        s += "Checks didn't pass";
+    }
+    s += "\n";
+    for (const auto &it : r.errors) {
+        s += " • " + it.comment + "\n";
+    }
+    trim(s);
+    check_label->set_text(s);
+}
+
 } // namespace horizon
