@@ -2,10 +2,10 @@
 #include <gtkmm.h>
 #include "common/common.hpp"
 #include <memory>
-#include "editor_interface.hpp"
 #include "util/window_state_store.hpp"
 #include "util/pool_goto_provider.hpp"
 #include "util/item_set.hpp"
+#include "rules/rules.hpp"
 
 namespace horizon {
 class EditorWindowStore {
@@ -15,7 +15,12 @@ public:
     virtual void save_as(const std::string &fn) = 0;
     virtual std::string get_name() const = 0;
     virtual const UUID &get_uuid() const = 0;
+    virtual const class FileVersion &get_version() const = 0;
+    virtual ObjectType get_type() const = 0;
     std::string filename;
+
+    virtual RulesCheckResult run_checks() const = 0;
+
     virtual ~EditorWindowStore()
     {
     }
@@ -23,7 +28,7 @@ public:
 
 class EditorWindow : public Gtk::Window, public PoolGotoProvider {
 public:
-    EditorWindow(ObjectType type, const std::string &filename, class Pool *p, class PoolParametric *pp, bool read_only,
+    EditorWindow(ObjectType type, const std::string &filename, class IPool *p, class PoolParametric *pp, bool read_only,
                  bool is_temp);
     void reload();
     bool get_need_update() const;
@@ -51,9 +56,14 @@ public:
 private:
     ObjectType type;
     std::unique_ptr<EditorWindowStore> store = nullptr;
-    PoolEditorInterface *iface = nullptr;
+    class PoolEditorInterface *iface = nullptr;
     Gtk::Button *save_button = nullptr;
-    class Pool *pool;
+    Gtk::MenuButton *check_button = nullptr;
+    class ColorBox *check_color_box = nullptr;
+    Gtk::Popover *check_popover = nullptr;
+    Gtk::Label *check_label = nullptr;
+    Gtk::InfoBar *info_bar = nullptr;
+    class IPool &pool;
     class PoolParametric *pool_parametric;
     bool need_update = false;
     std::string original_filename;
@@ -62,5 +72,6 @@ private:
     type_signal_filename_changed s_signal_saved;
 
     WindowStateStore state_store;
+    void run_checks();
 };
 } // namespace horizon
