@@ -1,6 +1,6 @@
 #include "gate_editor.hpp"
 #include "part_wizard.hpp"
-#include "location_entry.hpp"
+#include "widgets/location_entry.hpp"
 #include "util/util.hpp"
 #include "util/str_util.hpp"
 
