@@ -14,11 +14,7 @@
 #include "util/editor_process.hpp"
 #include "pool-update/pool-update.hpp"
 #include <zmq.hpp>
-#ifdef G_OS_WIN32
-#undef ERROR
-#undef DELETE
-#undef DUPLICATE
-#endif
+#include "util/win32_undef.hpp"
 
 namespace horizon {
 class PoolNotebook : public Gtk::Notebook {
@@ -52,12 +48,13 @@ private:
     Glib::Dispatcher pool_update_dispatcher;
     bool in_pool_update_handler = false;
     std::mutex pool_update_status_queue_mutex;
-    std::deque<std::tuple<PoolUpdateStatus, std::string, std::string>> pool_update_status_queue;
-    std::deque<std::tuple<PoolUpdateStatus, std::string, std::string>> pool_update_error_queue;
+    std::list<std::tuple<PoolUpdateStatus, std::string, std::string>> pool_update_status_queue;
+    std::list<std::tuple<PoolUpdateStatus, std::string, std::string>> pool_update_error_queue;
     bool pool_updating = false;
     void pool_updated(bool success);
     void reload();
     std::string pool_update_last_file;
+    std::string pool_update_last_info;
     unsigned int pool_update_n_files = 0;
     unsigned int pool_update_n_files_last = 0;
     std::function<void()> pool_update_done_cb = nullptr;
@@ -108,12 +105,18 @@ private:
     void handle_create_frame();
     void handle_duplicate_frame(const UUID &uu);
 
+    void construct_decals();
+    void handle_edit_decal(const UUID &uu);
+    void handle_create_decal();
+    void handle_duplicate_decal(const UUID &uu);
+
     Gtk::Button *add_action_button(const std::string &label, Gtk::Box *bbox, sigc::slot0<void>);
     Gtk::Button *add_action_button(const std::string &label, Gtk::Box *bbox, class PoolBrowser *br,
                                    sigc::slot1<void, UUID>);
     void add_preview_stack_switcher(Gtk::Box *bbox, Gtk::Stack *stack);
 
     void handle_delete(ObjectType ty, const UUID &uu);
+    void handle_move_rename(ObjectType ty, const UUID &uu);
     void handle_copy_path(ObjectType ty, const UUID &uu);
     void add_context_menu(class PoolBrowser *br);
 
