@@ -7,10 +7,7 @@
 #include "nlohmann/json.hpp"
 #include "pool-prj-mgr/pool-prj-mgr-app_win.hpp"
 #include "widgets/pool_browser_frame.hpp"
-
-#ifdef G_OS_WIN32
-#undef ERROR
-#endif
+#include "util/win32_undef.hpp"
 #include "widgets/preview_canvas.hpp"
 
 namespace horizon {
@@ -72,7 +69,7 @@ void PoolNotebook::handle_duplicate_frame(const UUID &uu)
 
 void PoolNotebook::construct_frames()
 {
-    auto br = Gtk::manage(new PoolBrowserFrame(&pool));
+    auto br = Gtk::manage(new PoolBrowserFrame(pool));
     br->set_show_path(true);
     browsers.emplace(ObjectType::FRAME, br);
     br->show();
