@@ -3,11 +3,7 @@
 #include <memory>
 #include "util/uuid.hpp"
 #include <zmq.hpp>
-#ifdef G_OS_WIN32
-#undef ERROR
-#undef DELETE
-#undef DUPLICATE
-#endif
+#include "util/win32_undef.hpp"
 #include "nlohmann/json_fwd.hpp"
 #include "util/editor_process.hpp"
 #include "util/window_state_store.hpp"
@@ -104,6 +100,7 @@ private:
     Gtk::Revealer *download_revealer = nullptr;
     Gtk::Label *download_label = nullptr;
     Gtk::Spinner *download_spinner = nullptr;
+    Gtk::ProgressBar *download_progress = nullptr;
     Gtk::MenuButton *hamburger_menu_button = nullptr;
 
     Gtk::Entry *download_gh_username_entry = nullptr;
@@ -137,6 +134,9 @@ private:
 
     Gtk::InfoBar *info_bar_pool_doc = nullptr;
 
+    Gtk::InfoBar *info_bar_version = nullptr;
+    Gtk::Label *version_label = nullptr;
+
     std::unique_ptr<Project> project = nullptr;
     std::string project_filename;
     bool project_needs_save = false;
@@ -202,9 +202,13 @@ private:
     bool check_autosave(PoolProjectManagerProcess::Type type, const std::vector<std::string> &filenames);
 
     static int git_transfer_cb(const git_transfer_progress *stats, void *payload);
+    static void git_checkout_progress_cb(const char *path, size_t completed_steps, size_t total_steps, void *payload);
     bool downloading = false;
     bool download_cancel = false;
 
+    void set_version_info(const std::string &s);
+    bool project_read_only = false;
+
 public:
     zmq::context_t &zctx;
     void set_pool_updating(bool v, bool success);
