@@ -254,6 +254,24 @@ MiscPreferencesEditor::MiscPreferencesEditor(Preferences &prefs) : preferences(p
             gr->add_row(*r);
         }
     }
+    {
+        auto gr = Gtk::manage(new PreferencesGroup("Mouse"));
+        box->pack_start(*gr, false, false, 0);
+        gr->show();
+        {
+            auto r = Gtk::manage(new PreferencesRowBool("Switch layers with navigation buttons",
+                                                        "Use back/forward buttons on mouse to move one layer down/up",
+                                                        preferences, preferences.mouse.switch_layers));
+            gr->add_row(*r);
+        }
+        {
+            auto r = Gtk::manage(new PreferencesRowBool(
+                    "Keep slope when dragging polygon edge",
+                    "Dragging a polgon edge will invoke the \"Drag polygon edge\" rather than the \"Move\" tool",
+                    preferences, preferences.mouse.drag_polygon_edges));
+            gr->add_row(*r);
+        }
+    }
     {
         auto gr = Gtk::manage(new PreferencesGroup("Action Bar"));
         box->pack_start(*gr, false, false, 0);
