@@ -18,11 +18,13 @@
 #include "nlohmann/json.hpp"
 #include "pool/pool_manager.hpp"
 #include "common/object_descr.hpp"
+#include "pool-update_pool.hpp"
 
 namespace horizon {
 
 using json = nlohmann::json;
 
+
 static void pkg_add_dir_to_graph(PoolUpdateGraph &graph, const std::string &directory, pool_update_cb_t status_cb)
 {
     Glib::Dir dir(directory);
@@ -54,34 +56,6 @@ static void pkg_add_dir_to_graph(PoolUpdateGraph &graph, const std::string &dire
     }
 }
 
-static void part_add_dir_to_graph(PoolUpdateGraph &graph, const std::string &directory, pool_update_cb_t status_cb)
-{
-    Glib::Dir dir(directory);
-    for (const auto &it : dir) {
-        std::string filename = Glib::build_filename(directory, it);
-        if (endswith(it, ".json")) {
-            try {
-                json j = load_json_from_file(filename);
-
-                std::set<UUID> dependencies;
-                UUID part_uuid = j.at("uuid").get<std::string>();
-                if (j.count("base")) {
-                    dependencies.emplace(j.at("base").get<std::string>());
-                }
-                graph.add_node(part_uuid, filename, dependencies);
-            }
-            catch (const std::exception &e) {
-                status_cb(PoolUpdateStatus::FILE_ERROR, filename, e.what());
-            }
-            catch (...) {
-                status_cb(PoolUpdateStatus::FILE_ERROR, filename, "unknown exception");
-            }
-        }
-        else if (Glib::file_test(filename, Glib::FILE_TEST_IS_DIR)) {
-            part_add_dir_to_graph(graph, filename, status_cb);
-        }
-    }
-}
 
 static std::set<UUID> uuids_from_missing(const std::set<std::pair<const PoolUpdateNode *, UUID>> &missing)
 {
@@ -103,11 +77,23 @@ public:
     void update_some(const std::string &pool_base_path, const std::vector<std::string> &filenames,
                      std::set<UUID> &all_parts_updated);
 
+    PoolUpdatePool &get_pool()
+    {
+        return *pool;
+    }
+
 private:
-    std::unique_ptr<Pool> pool;
+    std::optional<PoolUpdatePool> pool;
+    std::optional<SQLite::Query> q_exists;
+    std::optional<SQLite::Query> q_add_dependency;
+    std::optional<SQLite::Query> q_insert_part;
+    std::optional<SQLite::Query> q_add_tag;
+
+
     std::string base_path;
     pool_update_cb_t status_cb;
     void update_frames(const std::string &directory, const std::string &prefix = "");
+    void update_decals(const std::string &directory, const std::string &prefix = "");
     void update_units(const std::string &directory, const std::string &prefix = "");
     void update_entities(const std::string &directory, const std::string &prefix = "");
     void update_symbols(const std::string &directory, const std::string &prefix = "");
@@ -119,11 +105,13 @@ private:
     void update_parts(const std::string &directory);
     void update_part_node(const PoolUpdateNode &node, std::set<UUID> &visited);
     void add_dependency(ObjectType type, const UUID &uu, ObjectType dep_type, const UUID &dep_uuid);
+    void add_tag(ObjectType type, const UUID &uu, const std::string &tag);
     void clear_dependencies(ObjectType type, const UUID &uu);
     void clear_tags(ObjectType type, const UUID &uu);
     bool exists(ObjectType type, const UUID &uu);
 
     void update_frame(const std::string &filename, bool partial);
+    void update_decal(const std::string &filename, bool partial);
     void update_part(const std::string &filename, bool partial);
     void update_unit(const std::string &filename, bool partial);
     void update_symbol(const std::string &filename, bool partial);
@@ -131,6 +119,10 @@ private:
     void update_package(const std::string &filename, bool partial);
     void update_padstack(const std::string &filename);
 
+    void part_add_dir_to_graph(PoolUpdateGraph &graph, const std::string &directory);
+    std::map<std::string, json> json_cache;
+    const json &load_json(const std::string &filename);
+
     UUID pool_uuid;
     void set_pool_info(const std::string &bp);
     std::string get_path_rel(const std::string &filename) const;
@@ -138,10 +130,10 @@ private:
 
 bool PoolUpdater::exists(ObjectType type, const UUID &uu)
 {
-    SQLite::Query q(pool->db, "SELECT uuid FROM all_items_view WHERE uuid = ? AND type = ?");
-    q.bind(1, uu);
-    q.bind(2, object_type_lut.lookup_reverse(type));
-    return q.step();
+    q_exists->reset();
+    q_exists->bind(1, uu);
+    q_exists->bind(2, object_type_lut.lookup_reverse(type));
+    return q_exists->step();
 }
 
 void PoolUpdater::set_pool_info(const std::string &bp)
@@ -177,6 +169,9 @@ void PoolUpdater::update_some(const std::string &pool_base_path, const std::vect
         case ObjectType::FRAME:
             update_frame(filename, true);
             break;
+        case ObjectType::DECAL:
+            update_decal(filename, true);
+            break;
         case ObjectType::PART:
             update_part(filename, true);
             parts_updated.emplace(j.at("uuid").get<std::string>());
@@ -226,9 +221,11 @@ void PoolUpdater::update_some(const std::string &pool_base_path, const std::vect
 
 void PoolUpdater::update(const std::vector<std::string> &base_paths)
 {
-    status_cb(PoolUpdateStatus::INFO, "", "tags");
+    status_cb(PoolUpdateStatus::INFO, "", "Tags");
     pool->db.execute("DELETE FROM tags");
     pool->db.execute("DELETE FROM dependencies");
+
+    status_cb(PoolUpdateStatus::INFO, "", "Units");
     pool->db.execute("BEGIN TRANSACTION");
     pool->db.execute("DELETE FROM units");
     for (const auto &bp : base_paths) {
@@ -237,7 +234,7 @@ void PoolUpdater::update(const std::vector<std::string> &base_paths)
     }
     pool->db.execute("COMMIT");
 
-    status_cb(PoolUpdateStatus::INFO, "", "entities");
+    status_cb(PoolUpdateStatus::INFO, "", "Entities");
     pool->db.execute("BEGIN TRANSACTION");
     pool->db.execute("DELETE FROM entities");
     for (const auto &bp : base_paths) {
@@ -246,7 +243,7 @@ void PoolUpdater::update(const std::vector<std::string> &base_paths)
     }
     pool->db.execute("COMMIT");
 
-    status_cb(PoolUpdateStatus::INFO, "", "symbols");
+    status_cb(PoolUpdateStatus::INFO, "", "Symbols");
     pool->db.execute("BEGIN TRANSACTION");
     pool->db.execute("DELETE FROM symbols");
     for (const auto &bp : base_paths) {
@@ -255,7 +252,7 @@ void PoolUpdater::update(const std::vector<std::string> &base_paths)
     }
     pool->db.execute("COMMIT");
 
-    status_cb(PoolUpdateStatus::INFO, "", "padstacks");
+    status_cb(PoolUpdateStatus::INFO, "", "Padstacks");
     pool->db.execute("BEGIN TRANSACTION");
     pool->db.execute("DELETE FROM padstacks");
     for (const auto &bp : base_paths) {
@@ -265,7 +262,7 @@ void PoolUpdater::update(const std::vector<std::string> &base_paths)
     }
     pool->db.execute("COMMIT");
 
-    status_cb(PoolUpdateStatus::INFO, "", "packages");
+    status_cb(PoolUpdateStatus::INFO, "", "Packages");
     pool->db.execute("BEGIN TRANSACTION");
     pool->db.execute("DELETE FROM packages");
     pool->db.execute("DELETE FROM models");
@@ -275,7 +272,7 @@ void PoolUpdater::update(const std::vector<std::string> &base_paths)
     }
     pool->db.execute("COMMIT");
 
-    status_cb(PoolUpdateStatus::INFO, "", "parts");
+    status_cb(PoolUpdateStatus::INFO, "", "Parts");
     pool->db.execute("BEGIN TRANSACTION");
     pool->db.execute("DELETE FROM parts");
     pool->db.execute("DELETE FROM orderable_MPNs");
@@ -285,7 +282,7 @@ void PoolUpdater::update(const std::vector<std::string> &base_paths)
     }
     pool->db.execute("COMMIT");
 
-    status_cb(PoolUpdateStatus::INFO, "", "frames");
+    status_cb(PoolUpdateStatus::INFO, "", "Frames");
     pool->db.execute("BEGIN TRANSACTION");
     pool->db.execute("DELETE FROM frames");
     for (const auto &bp : base_paths) {
@@ -295,6 +292,17 @@ void PoolUpdater::update(const std::vector<std::string> &base_paths)
         }
     }
     pool->db.execute("COMMIT");
+
+    status_cb(PoolUpdateStatus::INFO, "", "Decals");
+    pool->db.execute("BEGIN TRANSACTION");
+    pool->db.execute("DELETE FROM decals");
+    for (const auto &bp : base_paths) {
+        if (Glib::file_test(Glib::build_filename(bp, "decals"), Glib::FILE_TEST_IS_DIR)) {
+            set_pool_info(bp);
+            update_decals(Glib::build_filename(bp, "decals"));
+        }
+    }
+    pool->db.execute("COMMIT");
 }
 
 PoolUpdater::PoolUpdater(const std::string &bp, pool_update_cb_t cb) : status_cb(cb)
@@ -314,7 +322,19 @@ PoolUpdater::PoolUpdater(const std::string &bp, pool_update_cb_t cb) : status_cb
             status_cb(PoolUpdateStatus::INFO, "", "created db from schema");
         }
     }
-    pool = std::make_unique<Pool>(bp, false);
+    pool.emplace(bp, false);
+    q_exists.emplace(pool->db, "SELECT uuid FROM all_items_view WHERE uuid = ? AND type = ?");
+    q_add_dependency.emplace(pool->db, "INSERT INTO dependencies VALUES (?, ?, ?, ?)");
+    q_insert_part.emplace(pool->db,
+                          "INSERT INTO parts "
+                          "(uuid, MPN, manufacturer, entity, package, description, filename, pool_uuid, overridden, "
+                          "parametric_table, base) "
+                          "VALUES "
+                          "($uuid, $MPN, $manufacturer, $entity, $package, $description, $filename, $pool_uuid, "
+                          "$overridden, $parametric_table, $base)");
+    q_add_tag.emplace(pool->db,
+                      "INSERT into tags (tag, uuid, type) "
+                      "VALUES ($tag, $uuid, $type)");
     pool->db.execute("PRAGMA journal_mode=WAL");
 }
 
@@ -366,6 +386,55 @@ void PoolUpdater::update_frame(const std::string &filename, bool partial)
     }
 }
 
+void PoolUpdater::update_decals(const std::string &directory, const std::string &prefix)
+{
+    Glib::Dir dir(directory);
+    for (const auto &it : dir) {
+        std::string filename = Glib::build_filename(directory, it);
+        if (endswith(it, ".json")) {
+            update_decal(filename, false);
+        }
+        else if (Glib::file_test(filename, Glib::FILE_TEST_IS_DIR)) {
+            update_decals(filename, Glib::build_filename(prefix, it));
+        }
+    }
+}
+
+
+void PoolUpdater::update_decal(const std::string &filename, bool partial)
+{
+    try {
+        status_cb(PoolUpdateStatus::FILE, filename, "");
+        auto decal = Decal::new_from_file(filename);
+        bool overridden = false;
+        if (exists(ObjectType::DECAL, decal.uuid)) {
+            overridden = true;
+            SQLite::Query q(pool->db, "DELETE FROM decals WHERE uuid = ?");
+            q.bind(1, decal.uuid);
+            q.step();
+        }
+        if (partial)
+            overridden = false;
+        SQLite::Query q(pool->db,
+                        "INSERT INTO DECALS "
+                        "(uuid, name, filename, pool_uuid, overridden) "
+                        "VALUES "
+                        "($uuid, $name, $filename, $pool_uuid, $overridden)");
+        q.bind("$uuid", decal.uuid);
+        q.bind("$name", decal.name);
+        q.bind("$filename", get_path_rel(filename));
+        q.bind("$pool_uuid", pool_uuid);
+        q.bind("$overridden", overridden);
+        q.step();
+    }
+    catch (const std::exception &e) {
+        status_cb(PoolUpdateStatus::FILE_ERROR, filename, e.what());
+    }
+    catch (...) {
+        status_cb(PoolUpdateStatus::FILE_ERROR, filename, "unknown exception");
+    }
+}
+
 void PoolUpdater::update_units(const std::string &directory, const std::string &prefix)
 {
     Glib::Dir dir(directory);
@@ -463,12 +532,7 @@ void PoolUpdater::update_entity(const std::string &filename, bool partial)
         q.bind("$filename", get_path_rel(filename));
         q.step();
         for (const auto &it_tag : entity.tags) {
-            SQLite::Query q2(pool->db,
-                             "INSERT into tags (tag, uuid, type) "
-                             "VALUES ($tag, $uuid, 'entity')");
-            q2.bind("$uuid", entity.uuid);
-            q2.bind("$tag", it_tag);
-            q2.step();
+            add_tag(ObjectType::ENTITY, entity.uuid, it_tag);
         }
         for (const auto &it_gate : entity.gates) {
             add_dependency(ObjectType::ENTITY, entity.uuid, ObjectType::UNIT, it_gate.second.unit->uuid);
@@ -693,6 +757,10 @@ void PoolUpdater::update_packages(const std::string &directory)
     std::set<UUID> visited;
     auto root = graph.get_root();
     update_package_node(root, visited);
+    for (const auto node : graph.get_not_visited(visited)) {
+        status_cb(PoolUpdateStatus::FILE_ERROR, node->filename,
+                  "package not visited (might be due to circular dependency)");
+    }
 }
 
 void PoolUpdater::update_package_node(const PoolUpdateNode &node, std::set<UUID> &visited)
@@ -755,12 +823,7 @@ void PoolUpdater::update_package(const std::string &filename, bool partial)
         q.bind("$overridden", overridden);
         q.step();
         for (const auto &it_tag : package.tags) {
-            SQLite::Query q2(pool->db,
-                             "INSERT into tags (tag, uuid, type) VALUES "
-                             "($tag, $uuid, 'package')");
-            q2.bind("$uuid", package.uuid);
-            q2.bind("$tag", it_tag);
-            q2.step();
+            add_tag(ObjectType::PACKAGE, package.uuid, it_tag);
         }
         for (const auto &it_model : package.models) {
             SQLite::Query q2(pool->db,
@@ -787,12 +850,48 @@ void PoolUpdater::update_package(const std::string &filename, bool partial)
     }
 }
 
+const json &PoolUpdater::load_json(const std::string &filename)
+{
+    if (!json_cache.count(filename))
+        json_cache.emplace(filename, load_json_from_file(filename));
+    return json_cache.at(filename);
+}
+
+void PoolUpdater::part_add_dir_to_graph(PoolUpdateGraph &graph, const std::string &directory)
+{
+    Glib::Dir dir(directory);
+    for (const auto &it : dir) {
+        std::string filename = Glib::build_filename(directory, it);
+        if (endswith(it, ".json")) {
+            try {
+                const auto &j = load_json(filename);
+
+                std::set<UUID> dependencies;
+                UUID part_uuid = j.at("uuid").get<std::string>();
+                if (j.count("base")) {
+                    dependencies.emplace(j.at("base").get<std::string>());
+                }
+                graph.add_node(part_uuid, filename, dependencies);
+            }
+            catch (const std::exception &e) {
+                status_cb(PoolUpdateStatus::FILE_ERROR, filename, e.what());
+            }
+            catch (...) {
+                status_cb(PoolUpdateStatus::FILE_ERROR, filename, "unknown exception");
+            }
+        }
+        else if (Glib::file_test(filename, Glib::FILE_TEST_IS_DIR)) {
+            part_add_dir_to_graph(graph, filename);
+        }
+    }
+}
+
 void PoolUpdater::update_part(const std::string &filename, bool partial)
 {
     try {
         if (filename.size()) {
             status_cb(PoolUpdateStatus::FILE, filename, "");
-            auto part = Part::new_from_file(filename, *pool);
+            auto part = Part::new_from_json(load_json(filename), *pool);
             bool overridden = false;
             if (exists(ObjectType::PART, part.uuid)) {
                 overridden = true;
@@ -814,33 +913,22 @@ void PoolUpdater::update_part(const std::string &filename, bool partial)
             std::string table;
             if (part.parametric.count("table"))
                 table = part.parametric.at("table");
-            SQLite::Query q(pool->db,
-                            "INSERT INTO parts "
-                            "(uuid, MPN, manufacturer, entity, package, description, filename, pool_uuid, overridden, "
-                            "parametric_table, base) "
-                            "VALUES "
-                            "($uuid, $MPN, $manufacturer, $entity, $package, $description, $filename, $pool_uuid, "
-                            "$overridden, $parametric_table, $base)");
-            q.bind("$uuid", part.uuid);
-            q.bind("$MPN", part.get_MPN());
-            q.bind("$manufacturer", part.get_manufacturer());
-            q.bind("$package", part.package->uuid);
-            q.bind("$entity", part.entity->uuid);
-            q.bind("$description", part.get_description());
-            q.bind("$pool_uuid", pool_uuid);
-            q.bind("$overridden", overridden);
-            q.bind("$parametric_table", table);
-            q.bind("$base", part.base ? part.base->uuid : UUID());
-            q.bind("$filename", get_path_rel(filename));
-            q.step();
+            q_insert_part->reset();
+            q_insert_part->bind("$uuid", part.uuid);
+            q_insert_part->bind("$MPN", part.get_MPN());
+            q_insert_part->bind("$manufacturer", part.get_manufacturer());
+            q_insert_part->bind("$package", part.package->uuid);
+            q_insert_part->bind("$entity", part.entity->uuid);
+            q_insert_part->bind("$description", part.get_description());
+            q_insert_part->bind("$pool_uuid", pool_uuid);
+            q_insert_part->bind("$overridden", overridden);
+            q_insert_part->bind("$parametric_table", table);
+            q_insert_part->bind("$base", part.base ? part.base->uuid : UUID());
+            q_insert_part->bind("$filename", get_path_rel(filename));
+            q_insert_part->step();
 
             for (const auto &it_tag : part.get_tags()) {
-                SQLite::Query q2(pool->db,
-                                 "INSERT into tags (tag, uuid, type) VALUES "
-                                 "($tag, $uuid, 'part')");
-                q2.bind("$uuid", part.uuid);
-                q2.bind("$tag", it_tag);
-                q2.step();
+                add_tag(ObjectType::PART, part.uuid, it_tag);
             }
             for (const auto &it_MPN : part.orderable_MPNs) {
                 SQLite::Query q2(pool->db,
@@ -858,6 +946,7 @@ void PoolUpdater::update_part(const std::string &filename, bool partial)
                 add_dependency(ObjectType::PART, part.uuid, ObjectType::ENTITY, part.entity->uuid);
                 add_dependency(ObjectType::PART, part.uuid, ObjectType::PACKAGE, part.package->uuid);
             }
+            pool->inject_part(part, filename, pool_uuid);
         }
     }
     catch (const std::exception &e) {
@@ -886,7 +975,7 @@ void PoolUpdater::update_part_node(const PoolUpdateNode &node, std::set<UUID> &v
 void PoolUpdater::update_parts(const std::string &directory)
 {
     PoolUpdateGraph graph;
-    part_add_dir_to_graph(graph, directory, status_cb);
+    part_add_dir_to_graph(graph, directory);
     {
         auto missing = graph.update_dependants();
         auto uuids_missing = uuids_from_missing(missing);
@@ -904,16 +993,29 @@ void PoolUpdater::update_parts(const std::string &directory)
     std::set<UUID> visited;
     auto root = graph.get_root();
     update_part_node(root, visited);
+    for (const auto node : graph.get_not_visited(visited)) {
+        status_cb(PoolUpdateStatus::FILE_ERROR, node->filename,
+                  "part not visited (might be due to circular dependency)");
+    }
 }
 
 void PoolUpdater::add_dependency(ObjectType type, const UUID &uu, ObjectType dep_type, const UUID &dep_uuid)
 {
-    SQLite::Query q(pool->db, "INSERT INTO dependencies VALUES (?, ?, ?, ?)");
-    q.bind(1, object_type_lut.lookup_reverse(type));
-    q.bind(2, uu);
-    q.bind(3, object_type_lut.lookup_reverse(dep_type));
-    q.bind(4, dep_uuid);
-    q.step();
+    q_add_dependency->reset();
+    q_add_dependency->bind(1, object_type_lut.lookup_reverse(type));
+    q_add_dependency->bind(2, uu);
+    q_add_dependency->bind(3, object_type_lut.lookup_reverse(dep_type));
+    q_add_dependency->bind(4, dep_uuid);
+    q_add_dependency->step();
+}
+
+void PoolUpdater::add_tag(ObjectType type, const UUID &uu, const std::string &tag)
+{
+    q_add_tag->reset();
+    q_add_tag->bind("$type", object_type_lut.lookup_reverse(type));
+    q_add_tag->bind("$uuid", uu);
+    q_add_tag->bind("$tag", tag);
+    q_add_tag->step();
 }
 
 void PoolUpdater::clear_tags(ObjectType type, const UUID &uu)
@@ -967,11 +1069,12 @@ void pool_update(const std::string &pool_base_path, pool_update_cb_t status_cb,
 
     if (parametric) {
         if (filenames.size() == 0) // complete update
-            pool_update_parametric(pool_base_path, status_cb);
+            pool_update_parametric(updater.get_pool(), status_cb);
         else if (parts_updated.size())
-            pool_update_parametric(pool_base_path, status_cb, parts_updated);
+            pool_update_parametric(updater.get_pool(), status_cb, parts_updated);
     }
-    status_cb(PoolUpdateStatus::DONE, "done", "");
+    status_cb(PoolUpdateStatus::INFO, "", "Done");
+    status_cb(PoolUpdateStatus::DONE, "", "");
 }
 
 } // namespace horizon
