@@ -2,6 +2,7 @@
 #include "pool/pool_parametric.hpp"
 #include "pool/pool.hpp"
 #include "pool/part.hpp"
+#include "pool-update_pool.hpp"
 #include <sstream>
 
 namespace horizon {
@@ -12,27 +13,51 @@ static void status_cb_nop(PoolUpdateStatus st, const std::string msg, const std:
 
 class PoolUpdaterParametric {
 public:
-    PoolUpdaterParametric(const std::string &pool_base_path, pool_update_cb_t status_cb);
+    PoolUpdaterParametric(PoolUpdatePool &pool, pool_update_cb_t status_cb);
     void update();
     void update(const std::set<UUID> &parts);
 
 private:
-    Pool pool;
+    PoolUpdatePool &pool;
     PoolParametric pool_parametric;
     const std::map<std::string, PoolParametric::Table> &tables;
     std::string base_path;
     pool_update_cb_t status_cb;
 
+    SQLite::Query &get_insert_query(const PoolParametric::Table &table);
+    std::map<std::string, SQLite::Query> insert_queries;
+
     void update_part(const UUID &uu, bool del);
 };
 
-PoolUpdaterParametric::PoolUpdaterParametric(const std::string &pool_base_path, pool_update_cb_t cb)
-    : pool(pool_base_path), pool_parametric(pool_base_path, false), tables(pool_parametric.get_tables()),
-      base_path(pool_base_path), status_cb(cb)
+PoolUpdaterParametric::PoolUpdaterParametric(PoolUpdatePool &apool, pool_update_cb_t cb)
+    : pool(apool), pool_parametric(pool.get_base_path(), false), tables(pool_parametric.get_tables()),
+      base_path(pool.get_base_path()), status_cb(cb)
 {
     pool_parametric.db.execute("PRAGMA journal_mode=WAL");
 }
 
+SQLite::Query &PoolUpdaterParametric::get_insert_query(const PoolParametric::Table &table)
+{
+    if (!insert_queries.count(table.name)) {
+        std::string qs = "INSERT INTO " + table.name + " VALUES (?, ";
+        for (size_t i = 0; i < table.columns.size(); i++) {
+            qs += "?,";
+        }
+        qs.pop_back();
+        qs += ")";
+        return insert_queries
+                .emplace(std::piecewise_construct, std::forward_as_tuple(table.name),
+                         std::forward_as_tuple(pool_parametric.db, qs))
+                .first->second;
+    }
+    else {
+        auto &q = insert_queries.at(table.name);
+        q.reset();
+        return q;
+    }
+}
+
 void PoolUpdaterParametric::update()
 {
     for (const auto &it : pool_parametric.get_tables()) {
@@ -83,8 +108,8 @@ void PoolUpdaterParametric::update(const std::set<UUID> &parts)
 
 void PoolUpdaterParametric::update_part(const UUID &uu, bool del)
 {
-    auto filename = pool.get_filename(ObjectType::PART, uu);
-    auto part = Part::new_from_file(filename, pool);
+    const auto &part = *pool.get_part(uu);
+    const auto filename = pool.get_part_filename(uu);
     status_cb(PoolUpdateStatus::FILE, filename, "");
     if (!part.parametric.count("table"))
         return;
@@ -97,14 +122,7 @@ void PoolUpdaterParametric::update_part(const UUID &uu, bool del)
             q.bind(1, uu);
             q.step();
         }
-
-        std::string qs = "INSERT INTO " + table.name + " VALUES (?, ";
-        for (size_t i = 0; i < table.columns.size(); i++) {
-            qs += "?,";
-        }
-        qs.pop_back();
-        qs += ")";
-        SQLite::Query q(pool_parametric.db, qs);
+        auto &q = get_insert_query(table);
         q.bind(1, part.uuid);
         for (size_t i = 0; i < table.columns.size(); i++) {
             auto &col = table.columns.at(i);
@@ -147,11 +165,12 @@ void PoolUpdaterParametric::update_part(const UUID &uu, bool del)
     }
 }
 
-void pool_update_parametric(const std::string &pool_base_path, pool_update_cb_t status_cb, const std::set<UUID> &parts)
+void pool_update_parametric(PoolUpdatePool &pool, pool_update_cb_t status_cb, const std::set<UUID> &parts)
 {
     if (!status_cb)
         status_cb = &status_cb_nop;
-    PoolUpdaterParametric updater(pool_base_path, status_cb);
+    status_cb(PoolUpdateStatus::INFO, "", "Parametric data");
+    PoolUpdaterParametric updater(pool, status_cb);
     if (parts.size() == 0) {
         updater.update();
     }
