@@ -4,6 +4,8 @@
 #include "nlohmann/json.hpp"
 #include "board/board_layers.hpp"
 #include "util/picture_load.hpp"
+#include "common/junction_util.hpp"
+#include "util/bbox_accumulator.hpp"
 
 namespace horizon {
 
@@ -16,24 +18,6 @@ std::map<UUID, Polygon> &Package::MyParameterProgram::get_polygons()
     return pkg->polygons;
 }
 
-ParameterProgram::CommandHandler Package::MyParameterProgram::get_command(const std::string &cmd)
-{
-    using namespace std::placeholders;
-    if (auto r = ParameterProgram::get_command(cmd)) {
-        return r;
-    }
-    else if (cmd == "set-polygon") {
-        return std::bind(std::mem_fn(&Package::MyParameterProgram::set_polygon), this, _1, _2);
-    }
-    else if (cmd == "set-polygon-vertices") {
-        return std::bind(std::mem_fn(&Package::MyParameterProgram::set_polygon_vertices), this, _1, _2);
-    }
-    else if (cmd == "expand-polygon") {
-        return std::bind(std::mem_fn(&Package::MyParameterProgram::expand_polygon), this, _1, _2);
-    }
-    return nullptr;
-}
-
 Package::Model::Model(const UUID &uu, const std::string &fn) : uuid(uu), filename(fn)
 {
 }
@@ -59,6 +43,11 @@ json Package::Model::serialize() const
 
 static const unsigned int app_version = 0;
 
+unsigned int Package::get_app_version()
+{
+    return app_version;
+}
+
 Package::Package(const UUID &uu, const json &j, IPool &pool)
     : uuid(uu), name(j.at("name").get<std::string>()), manufacturer(j.value("manufacturer", "")),
       parameter_program(this, j.value("parameter_program", "")), version(app_version, j)
@@ -267,13 +256,13 @@ static void copy_param(ParameterSet &dest, const ParameterSet &src, const std::s
     }
 }
 
-std::pair<bool, std::string> Package::apply_parameter_set(const ParameterSet &ps)
+std::optional<std::string> Package::apply_parameter_set(const ParameterSet &ps)
 {
     auto ps_this = parameter_set;
     copy_param(ps_this, ps, ParameterID::COURTYARD_EXPANSION);
     {
         auto r = parameter_program.run(ps_this);
-        if (r.first) {
+        if (r.has_value()) {
             return r;
         }
     }
@@ -283,41 +272,25 @@ std::pair<bool, std::string> Package::apply_parameter_set(const ParameterSet &ps
         copy_param(ps_pad, ps,
                    {ParameterID::SOLDER_MASK_EXPANSION, ParameterID::PASTE_MASK_CONTRACTION,
                     ParameterID::HOLE_SOLDER_MASK_EXPANSION});
-        auto r = it.second.padstack.apply_parameter_set(ps_pad);
-        if (r.first) {
-            return {r.first, "Pad " + it.second.name + ": " + r.second};
+        if (auto r = it.second.padstack.apply_parameter_set(ps_pad)) {
+            return "Pad " + it.second.name + ": " + r.value();
         }
     }
-    return {false, ""};
+    return {};
 }
 
 void Package::expand()
 {
     map_erase_if(keepouts, [this](auto &it) { return polygons.count(it.second.polygon.uuid) == 0; });
     for (auto &it : junctions) {
-        it.second.layer = 10000;
-        it.second.has_via = false;
-        it.second.needs_via = false;
-        it.second.connection_count = 0;
+        it.second.clear();
     }
+    JunctionUtil::update(lines);
+    JunctionUtil::update(arcs);
 
-    for (const auto &it : lines) {
-        it.second.from->connection_count++;
-        it.second.to->connection_count++;
-        for (auto &ju : {it.second.from, it.second.to}) {
-            ju->layer.merge(it.second.layer);
-        }
-    }
-    for (const auto &it : arcs) {
-        it.second.from->connection_count++;
-        it.second.to->connection_count++;
-        it.second.center->connection_count++;
-        for (auto &ju : {it.second.from, it.second.to}) {
-            ju->layer.merge(it.second.layer);
-        }
-    }
-
-    map_erase_if(junctions, [](const auto &it) { return it.second.connection_count == 0; });
+    map_erase_if(junctions, [](const auto &it) {
+        return (it.second.connected_lines.size() == 0) && (it.second.connected_arcs.size() == 0);
+    });
 }
 
 void Package::update_warnings()
@@ -339,22 +312,17 @@ void Package::update_warnings()
 
 std::pair<Coordi, Coordi> Package::get_bbox() const
 {
-    Coordi a;
-    Coordi b;
+    BBoxAccumulator<Coordi::type> acc;
     for (const auto &it : pads) {
         auto bb_pad = it.second.placement.transform_bb(it.second.padstack.get_bbox());
-        a = Coordi::min(a, bb_pad.first);
-        b = Coordi::max(b, bb_pad.second);
+        acc.accumulate(bb_pad);
     }
     for (const auto &it : polygons) {
         if (it.second.layer == BoardLayers::TOP_PACKAGE || it.second.layer == BoardLayers::BOTTOM_PACKAGE) {
-            for (const auto &v : it.second.vertices) {
-                a = Coordi::min(a, v.position);
-                b = Coordi::max(b, v.position);
-            }
+            acc.accumulate(it.second.get_bbox());
         }
     }
-    return std::make_pair(a, b);
+    return acc.get_or_0();
 }
 
 static std::map<int, Layer> pkg_layers;
