@@ -14,7 +14,6 @@
 #include "package/package_rules.hpp"
 #include "package/pad.hpp"
 #include "util/uuid.hpp"
-#include "util/uuid_provider.hpp"
 #include "util/warning.hpp"
 #include "parameter/program_polygon.hpp"
 #include "common/picture.hpp"
@@ -22,11 +21,12 @@
 #include <map>
 #include <set>
 #include <vector>
+#include "util/file_version.hpp"
 
 namespace horizon {
 using json = nlohmann::json;
 
-class Package : public ObjectProvider, public LayerProvider, public UUIDProvider {
+class Package : public ObjectProvider, public LayerProvider {
 public:
     class MyParameterProgram : public ParameterProgramPolygon {
         friend Package;
@@ -35,7 +35,6 @@ public:
         std::map<UUID, Polygon> &get_polygons() override;
 
     private:
-        ParameterProgram::CommandHandler get_command(const std::string &cmd) override;
         class Package *pkg = nullptr;
 
     public:
@@ -61,21 +60,22 @@ public:
         json serialize() const;
     };
 
-    Package(const UUID &uu, const json &j, class Pool &pool);
+    Package(const UUID &uu, const json &j, class IPool &pool);
     Package(const UUID &uu);
-    static Package new_from_file(const std::string &filename, class Pool &pool);
+    static Package new_from_file(const std::string &filename, class IPool &pool);
+    static unsigned int get_app_version();
 
     json serialize() const;
     Junction *get_junction(const UUID &uu) override;
     Polygon *get_polygon(const UUID &uu) override;
     std::pair<Coordi, Coordi> get_bbox() const;
     const std::map<int, Layer> &get_layers() const override;
-    std::pair<bool, std::string> apply_parameter_set(const ParameterSet &ps);
+    std::optional<std::string> apply_parameter_set(const ParameterSet &ps);
     void expand();
     void update_warnings();
     int get_max_pad_name() const;
 
-    UUID get_uuid() const override;
+    UUID get_uuid() const;
 
     Package(const Package &pkg);
     void operator=(Package const &pkg);
@@ -105,9 +105,11 @@ public:
 
     const class Package *alternate_for = nullptr;
 
+    FileVersion version;
+
     std::vector<Warning> warnings;
 
-    void update_refs(class Pool &pool);
+    void update_refs(class IPool &pool);
 
     void save_pictures(const std::string &dir) const;
     void load_pictures(const std::string &dir);
