@@ -3,6 +3,7 @@
 #include "common/lut.hpp"
 #include "util/util.hpp"
 #include "nlohmann/json.hpp"
+#include "util/bbox_accumulator.hpp"
 
 namespace horizon {
 
@@ -14,20 +15,19 @@ Padstack::MyParameterProgram::MyParameterProgram(Padstack *p, const std::string
 {
 }
 
-std::pair<bool, std::string> Padstack::MyParameterProgram::set_shape(const ParameterProgram::TokenCommand *cmd,
-                                                                     std::deque<int64_t> &stack)
+std::optional<std::string> Padstack::MyParameterProgram::set_shape(const TokenCommand &cmd)
 {
-    if (cmd->arguments.size() < 2 || cmd->arguments.at(0)->type != ParameterProgram::Token::Type::STR
-        || cmd->arguments.at(1)->type != ParameterProgram::Token::Type::STR)
-        return {true, "not enough arguments"};
+    if (cmd.arguments.size() < 2 || cmd.arguments.at(0)->type != Token::Type::STR
+        || cmd.arguments.at(1)->type != Token::Type::STR)
+        return "not enough arguments";
 
-    auto pclass = dynamic_cast<ParameterProgram::TokenString *>(cmd->arguments.at(0).get())->string;
-    auto form = dynamic_cast<ParameterProgram::TokenString *>(cmd->arguments.at(1).get())->string;
+    const auto &pclass = dynamic_cast<TokenString &>(*cmd.arguments.at(0).get()).string;
+    const auto &form = dynamic_cast<TokenString &>(*cmd.arguments.at(1).get()).string;
 
     if (form == "rectangle") {
         int64_t width, height;
-        if (stack_pop(stack, height) || stack_pop(stack, width))
-            return {true, "empty stack"};
+        if (stack_pop(height) || stack_pop(width))
+            return "empty stack";
         for (auto &it : ps->shapes) {
             if (it.second.parameter_class == pclass) {
                 it.second.form = Shape::Form::RECTANGLE;
@@ -37,8 +37,8 @@ std::pair<bool, std::string> Padstack::MyParameterProgram::set_shape(const Param
     }
     else if (form == "circle") {
         int64_t diameter;
-        if (stack_pop(stack, diameter))
-            return {true, "empty stack"};
+        if (stack_pop(diameter))
+            return "empty stack";
         for (auto &it : ps->shapes) {
             if (it.second.parameter_class == pclass) {
                 it.second.form = Shape::Form::CIRCLE;
@@ -48,8 +48,8 @@ std::pair<bool, std::string> Padstack::MyParameterProgram::set_shape(const Param
     }
     else if (form == "obround") {
         int64_t width, height;
-        if (stack_pop(stack, height) || stack_pop(stack, width))
-            return {true, "empty stack"};
+        if (stack_pop(height) || stack_pop(width))
+            return "empty stack";
         for (auto &it : ps->shapes) {
             if (it.second.parameter_class == pclass) {
                 it.second.form = Shape::Form::OBROUND;
@@ -59,8 +59,8 @@ std::pair<bool, std::string> Padstack::MyParameterProgram::set_shape(const Param
     }
     else if (form == "position") {
         int64_t x, y;
-        if (stack_pop(stack, y) || stack_pop(stack, x))
-            return {true, "empty stack"};
+        if (stack_pop(y) || stack_pop(x))
+            return "empty stack";
         for (auto &it : ps->shapes) {
             if (it.second.parameter_class == pclass) {
                 it.second.placement.shift = {x, y};
@@ -69,26 +69,25 @@ std::pair<bool, std::string> Padstack::MyParameterProgram::set_shape(const Param
     }
 
     else {
-        return {true, "unknown form " + form};
+        return "unknown form " + form;
     }
 
-    return {false, ""};
+    return {};
 }
 
-std::pair<bool, std::string> Padstack::MyParameterProgram::set_hole(const ParameterProgram::TokenCommand *cmd,
-                                                                    std::deque<int64_t> &stack)
+std::optional<std::string> Padstack::MyParameterProgram::set_hole(const TokenCommand &cmd)
 {
-    if (cmd->arguments.size() < 2 || cmd->arguments.at(0)->type != ParameterProgram::Token::Type::STR
-        || cmd->arguments.at(1)->type != ParameterProgram::Token::Type::STR)
-        return {true, "not enough arguments"};
+    if (cmd.arguments.size() < 2 || cmd.arguments.at(0)->type != Token::Type::STR
+        || cmd.arguments.at(1)->type != Token::Type::STR)
+        return "not enough arguments";
 
-    auto pclass = dynamic_cast<ParameterProgram::TokenString *>(cmd->arguments.at(0).get())->string;
-    auto shape = dynamic_cast<ParameterProgram::TokenString *>(cmd->arguments.at(1).get())->string;
+    const auto &pclass = dynamic_cast<TokenString &>(*cmd.arguments.at(0).get()).string;
+    const auto &shape = dynamic_cast<TokenString &>(*cmd.arguments.at(1).get()).string;
 
     if (shape == "round") {
         int64_t diameter;
-        if (stack_pop(stack, diameter))
-            return {true, "empty stack"};
+        if (stack_pop(diameter))
+            return "empty stack";
         for (auto &it : ps->holes) {
             if (it.second.parameter_class == pclass) {
                 it.second.shape = Hole::Shape::ROUND;
@@ -98,8 +97,8 @@ std::pair<bool, std::string> Padstack::MyParameterProgram::set_hole(const Parame
     }
     else if (shape == "slot") {
         int64_t diameter, length;
-        if (stack_pop(stack, length) || stack_pop(stack, diameter))
-            return {true, "empty stack"};
+        if (stack_pop(length) || stack_pop(diameter))
+            return "empty stack";
         for (auto &it : ps->holes) {
             if (it.second.parameter_class == pclass) {
                 it.second.shape = Hole::Shape::SLOT;
@@ -110,10 +109,10 @@ std::pair<bool, std::string> Padstack::MyParameterProgram::set_hole(const Parame
     }
 
     else {
-        return {true, "unknown shape " + shape};
+        return "unknown shape " + shape;
     }
 
-    return {false, ""};
+    return {};
 }
 
 std::map<UUID, Polygon> &Padstack::MyParameterProgram::get_polygons()
@@ -125,23 +124,14 @@ std::map<UUID, Polygon> &Padstack::MyParameterProgram::get_polygons()
 ParameterProgram::CommandHandler Padstack::MyParameterProgram::get_command(const std::string &cmd)
 {
     using namespace std::placeholders;
-    if (auto r = ParameterProgram::get_command(cmd)) {
+    if (auto r = ParameterProgramPolygon::get_command(cmd)) {
         return r;
     }
     else if (cmd == "set-shape") {
-        return std::bind(std::mem_fn(&Padstack::MyParameterProgram::set_shape), this, _1, _2);
+        return static_cast<CommandHandler>(&Padstack::MyParameterProgram::set_shape);
     }
     else if (cmd == "set-hole") {
-        return std::bind(std::mem_fn(&Padstack::MyParameterProgram::set_hole), this, _1, _2);
-    }
-    else if (cmd == "set-polygon") {
-        return std::bind(std::mem_fn(&Padstack::MyParameterProgram::set_polygon), this, _1, _2);
-    }
-    else if (cmd == "set-polygon-vertices") {
-        return std::bind(std::mem_fn(&Padstack::MyParameterProgram::set_polygon_vertices), this, _1, _2);
-    }
-    else if (cmd == "expand-polygon") {
-        return std::bind(std::mem_fn(&Padstack::MyParameterProgram::expand_polygon), this, _1, _2);
+        return static_cast<CommandHandler>(&Padstack::MyParameterProgram::set_hole);
     }
     return nullptr;
 }
@@ -176,6 +166,11 @@ void Padstack::update_refs()
 
 static const unsigned int app_version = 0;
 
+unsigned int Padstack::get_app_version()
+{
+    return app_version;
+}
+
 Padstack::Padstack(const UUID &uu, const json &j)
     : uuid(uu), name(j.at("name").get<std::string>()), well_known_name(j.value("well_known_name", "")),
       parameter_program(this, j.value("parameter_program", "")), version(app_version, j)
@@ -265,27 +260,19 @@ UUID Padstack::get_uuid() const
 
 std::pair<Coordi, Coordi> Padstack::get_bbox(bool copper_only) const
 {
-    Coordi a;
-    Coordi b;
+    BBoxAccumulator<Coordi::type> acc;
     for (const auto &it : polygons) {
         if (!copper_only || BoardLayers::is_copper(it.second.layer)) {
-            auto poly = it.second.remove_arcs(8);
-            for (const auto &v : poly.vertices) {
-                a = Coordi::min(a, v.position);
-                b = Coordi::max(b, v.position);
-            }
+            acc.accumulate(it.second.get_bbox());
         }
     }
     for (const auto &it : shapes) {
         if (!copper_only || BoardLayers::is_copper(it.second.layer)) {
-            auto bb = it.second.placement.transform_bb(it.second.get_bbox());
-
-            a = Coordi::min(a, bb.first);
-            b = Coordi::max(b, bb.second);
+            const auto bb = it.second.placement.transform_bb(it.second.get_bbox());
+            acc.accumulate(bb);
         }
     }
-
-    return std::make_pair(a, b);
+    return acc.get_or_0();
 }
 
 const std::map<int, Layer> &Padstack::get_layers() const
@@ -313,7 +300,7 @@ static void copy_param(ParameterSet &dest, const ParameterSet &src, const std::s
     }
 }
 
-std::pair<bool, std::string> Padstack::apply_parameter_set(const ParameterSet &ps)
+std::optional<std::string> Padstack::apply_parameter_set(const ParameterSet &ps)
 {
     auto ps_this = parameter_set;
     copy_param(ps_this, ps,
