@@ -73,6 +73,7 @@ public:
     Symbol(const UUID &uu, const json &j, class IPool &pool);
     Symbol(const UUID &uu);
     static Symbol new_from_file(const std::string &filename, IPool &pool);
+    static unsigned int get_app_version();
     std::pair<Coordi, Coordi> get_bbox(bool all = false) const;
     virtual Junction *get_junction(const UUID &uu) override;
 
@@ -86,6 +87,8 @@ public:
     Symbol(const Symbol &sym);
     void operator=(Symbol const &sym);
 
+    void apply_expand(const Symbol &ref, unsigned int ex);
+
     UUID uuid;
     uuid_ptr<const Unit> unit;
     std::string name;
