@@ -207,6 +207,7 @@ json ZoomPreferences::serialize() const
     j["smooth_zoom_2d"] = smooth_zoom_2d;
     j["smooth_zoom_3d"] = smooth_zoom_3d;
     j["touchpad_pan"] = touchpad_pan;
+    j["zoom_factor"] = zoom_factor;
     return j;
 }
 
@@ -215,6 +216,7 @@ void ZoomPreferences::load_from_json(const json &j)
     smooth_zoom_2d = j.value("smooth_zoom_2d", true);
     smooth_zoom_3d = j.value("smooth_zoom_3d", false);
     touchpad_pan = j.value("touchpad_pan", false);
+    zoom_factor = j.value("zoom_factor", 50);
 }
 
 json KeySequencesPreferences::serialize() const
@@ -373,6 +375,7 @@ json ActionBarPreferences::serialize() const
     json j;
     j["enable"] = enable;
     j["remember"] = remember;
+    j["show_in_tool"] = show_in_tool;
     return j;
 }
 
@@ -380,6 +383,21 @@ void ActionBarPreferences::load_from_json(const json &j)
 {
     enable = j.value("enable", true);
     remember = j.value("remember", true);
+    show_in_tool = j.value("show_in_tool", true);
+}
+
+json MousePreferences::serialize() const
+{
+    json j;
+    j["switch_layers"] = switch_layers;
+    j["drag_polygon_edges"] = drag_polygon_edges;
+    return j;
+}
+
+void MousePreferences::load_from_json(const json &j)
+{
+    switch_layers = j.value("switch_layers", true);
+    drag_polygon_edges = j.value("drag_polygon_edges", true);
 }
 
 json Preferences::serialize() const
@@ -395,6 +413,9 @@ json Preferences::serialize() const
     j["capture_output"] = capture_output;
     j["partinfo"] = partinfo.serialize();
     j["action_bar"] = action_bar.serialize();
+    j["mouse"] = mouse.serialize();
+    j["show_pull_request_tools"] = show_pull_request_tools;
+    j["hud_debug"] = hud_debug;
     return j;
 }
 
@@ -423,10 +444,14 @@ void Preferences::load_from_json(const json &j)
         in_tool_key_sequences.load_from_json(j.at("in_tool_key_sequences"));
     if (j.count("action_bar"))
         action_bar.load_from_json(j.at("action_bar"));
+    if (j.count("mouse"))
+        mouse.load_from_json(j.at("mouse"));
     key_sequences.append_from_json(json_from_resource("/org/horizon-eda/horizon/imp/keys_default.json"));
     in_tool_key_sequences.append_from_json(
             json_from_resource("/org/horizon-eda/horizon/imp/in_tool_keys_default.json"));
     capture_output = j.value("capture_output", capture_output_default);
+    show_pull_request_tools = j.value("show_pull_request_tools", false);
+    hud_debug = j.value("hud_debug", false);
     if (j.count("partinfo"))
         partinfo.load_from_json(j.at("partinfo"));
 }
