@@ -96,6 +96,15 @@ public:
     json serialize() const;
 };
 
+class MousePreferences {
+public:
+    bool switch_layers = true;
+    bool drag_polygon_edges = true;
+
+    void load_from_json(const json &j);
+    json serialize() const;
+};
+
 class Preferences {
 public:
     Preferences();
@@ -117,8 +126,10 @@ public:
     PartInfoPreferences partinfo;
     ActionBarPreferences action_bar;
     InToolKeySequencesPreferences in_tool_key_sequences;
+    MousePreferences mouse;
 
     bool show_pull_request_tools = false;
+    bool hud_debug = false;
 
     typedef sigc::signal<void> type_signal_changed;
     type_signal_changed signal_changed()
