@@ -33,41 +33,45 @@ public:
     {
         return &block;
     }
-    horizon::Pool *get_pool() override
+    horizon::IPool &get_pool() override
     {
-        return &pool;
+        return pool;
     }
     horizon::Rules *get_rules() override
     {
         return &board.rules;
     }
-    horizon::LayerProvider *get_layer_provider() override
+    horizon::LayerProvider &get_layer_provider() override
     {
-        return &board;
+        return board;
     }
-    horizon::ViaPadstackProvider *get_via_padstack_provider() override
+    horizon::ViaPadstackProvider &get_via_padstack_provider() override
     {
-        return &vpp;
+        return vpp;
     }
-    horizon::FabOutputSettings *get_fab_output_settings() override
+    horizon::FabOutputSettings &get_fab_output_settings() override
     {
-        return &board.fab_output_settings;
+        return board.fab_output_settings;
     }
-    horizon::PDFExportSettings *get_pdf_export_settings() override
+    horizon::PDFExportSettings &get_pdf_export_settings() override
     {
-        return &board.pdf_export_settings;
+        return board.pdf_export_settings;
     }
-    horizon::STEPExportSettings *get_step_export_settings() override
+    horizon::STEPExportSettings &get_step_export_settings() override
     {
-        return &board.step_export_settings;
+        return board.step_export_settings;
     }
-    horizon::PnPExportSettings *get_pnp_export_settings() override
+    horizon::PnPExportSettings &get_pnp_export_settings() override
     {
-        return &board.pnp_export_settings;
+        return board.pnp_export_settings;
     }
-    horizon::BoardColors *get_colors() override
+    horizon::BoardColors &get_colors() override
     {
-        return &board.colors;
+        return board.colors;
+    }
+    const horizon::FileVersion &get_version() const override
+    {
+        return board.version;
     }
 };
 
@@ -120,7 +124,7 @@ static PyObject *PyBoard_export_gerber(PyObject *pself, PyObject *args)
     try {
         auto settings_json = json_from_py(py_export_settings);
         horizon::FabOutputSettings settings(settings_json);
-        horizon::GerberExporter ex(&self->board->board, &settings);
+        horizon::GerberExporter ex(self->board->board, settings);
         ex.generate();
     }
     catch (const std::exception &e) {
@@ -301,7 +305,7 @@ static PyObject *PyBoard_run_checks(PyObject *pself, PyObject *args)
         horizon::RulesCheckCache cache(self->board);
         json j;
         for (auto id : ids) {
-            auto r = self->board->board.rules.check(id, &self->board->board, cache, &dummy_callback);
+            auto r = self->board->board.rules.check(id, self->board->board, cache, &dummy_callback);
             j[horizon::rule_id_lut.lookup_reverse(id)] = r.serialize();
         }
         return py_from_json(j);
