@@ -79,7 +79,7 @@ public:
     int DpCoupledNet(int aNet) override;
     int DpNetPolarity(int aNet) override;
     bool DpNetPair(PNS::ITEM *aItem, int &aNetP, int &aNetN) override;
-    std::string NetName(int aNet);
+    std::string NetName(int aNet) override;
 
 private:
     PNS::ROUTER *m_router;
@@ -359,6 +359,10 @@ public:
             auto pt = aLine.CPoint(i);
             pts.emplace_back(pt.x, pt.y);
         }
+        if (aLine.IsClosed()) {
+            auto pt = aLine.CPoint(0);
+            pts.emplace_back(pt.x, pt.y);
+        }
         lines.insert(m_canvas->add_line(pts, aWidth, horizon::ColorP::AIRWIRE_ROUTER, 10000));
     }
 
@@ -546,6 +550,8 @@ std::unique_ptr<PNS::SOLID> PNS_HORIZON_IFACE::syncPad(const horizon::BoardPacka
     }
     tr.accumulate(pad->placement);
     auto solid = syncPadstack(&pad->padstack, tr);
+    if (!solid)
+        return nullptr;
 
     if (pad->net)
         solid->SetNet(get_net_code(pad->net->uuid));
@@ -557,6 +563,8 @@ std::unique_ptr<PNS::SOLID> PNS_HORIZON_IFACE::syncPad(const horizon::BoardPacka
 std::unique_ptr<PNS::SOLID> PNS_HORIZON_IFACE::syncHole(const horizon::BoardHole *hole)
 {
     auto solid = syncPadstack(&hole->padstack, hole->placement);
+    if (!solid)
+        return nullptr;
 
     if (hole->net)
         solid->SetNet(get_net_code(hole->net->uuid));
@@ -689,6 +697,8 @@ std::unique_ptr<PNS::SOLID> PNS_HORIZON_IFACE::syncPadstack(const horizon::Padst
 
     ClipperLib::Paths poly_union;
     clipper.Execute(ClipperLib::ctUnion, poly_union, ClipperLib::pftNonZero);
+    if (poly_union.size() == 0) // nothing we care about
+        return nullptr;
     if (poly_union.size() != 1) {
         throw std::runtime_error("invalid pad polygons: " + std::to_string(poly_union.size()));
     }
@@ -740,6 +750,7 @@ void PNS_HORIZON_IFACE::SyncWorld(PNS::NODE *aWorld)
         return;
     }
     parents.clear();
+    junctions_maybe_erased.clear();
 
     for (const auto &it : board->tracks) {
         auto segment = syncTrack(&it.second);
@@ -844,6 +855,9 @@ void PNS_HORIZON_IFACE::DisplayItem(const PNS::ITEM *aItem, int aColor, int aCle
         m_preview_items.insert(
                 canvas->add_line(pts, via_item->Diameter(), horizon::ColorP::LAYER_HIGHLIGHT, layer_from_router(la)));
     }
+    else if (aItem->Kind() == PNS::ITEM::SOLID_T) {
+        // it's okay
+    }
     else {
         assert(false);
     }
@@ -871,6 +885,10 @@ void PNS_HORIZON_IFACE::RemoveItem(PNS::ITEM *aItem)
     // std::cout << "!!!iface remove item " << parent << " " << aItem->KindStr() << std::endl;
     if (parent) {
         if (parent->track) {
+            for (auto &it_ft : {parent->track->from, parent->track->to}) {
+                if (it_ft.junc)
+                    junctions_maybe_erased.insert(it_ft.junc);
+            }
             board->tracks.erase(parent->track->uuid);
         }
         else if (parent->via) {
@@ -902,7 +920,7 @@ std::pair<horizon::BoardPackage *, horizon::Pad *> PNS_HORIZON_IFACE::find_pad(i
     return {nullptr, nullptr};
 }
 
-horizon::Junction *PNS_HORIZON_IFACE::find_junction(int layer, const horizon::Coordi &c)
+horizon::BoardJunction *PNS_HORIZON_IFACE::find_junction(int layer, const horizon::Coordi &c)
 {
     for (auto &it : board->junctions) {
         if ((layer == 10000 || it.second.layer == layer || it.second.has_via) && it.second.position == c) {
@@ -924,11 +942,12 @@ void PNS_HORIZON_IFACE::AddItem(PNS::ITEM *aItem)
         horizon::Coordi from(s.A.x, s.A.y);
         horizon::Coordi to(s.B.x, s.B.y);
         track->width = seg->Width();
+        track->net = get_net_for_code(seg->Net());
 
         auto layer = layer_from_router(seg->Layer());
         track->layer = layer;
 
-        auto connect = [this, &layer](horizon::Track::Connection &conn, const horizon::Coordi &c) {
+        auto connect = [this, &layer, track](horizon::Track::Connection &conn, const horizon::Coordi &c) {
             auto p = find_pad(layer, c);
             if (p.first) {
                 conn.connect(p.first, p.second);
@@ -943,6 +962,7 @@ void PNS_HORIZON_IFACE::AddItem(PNS::ITEM *aItem)
                     auto ju = &board->junctions.emplace(juu, juu).first->second;
                     ju->layer = layer;
                     ju->position = c;
+                    ju->net = track->net;
                     conn.connect(ju);
                 }
             }
@@ -976,9 +996,11 @@ void PNS_HORIZON_IFACE::AddItem(PNS::ITEM *aItem)
                 auto juu = horizon::UUID::random();
                 auto ju = &board->junctions.emplace(juu, juu).first->second;
                 ju->position = c;
+                ju->net = net;
                 via->junction = ju;
             }
             via->junction->has_via = true;
+            via->expand(*board);
             aItem->SetParent(get_parent(via));
         }
     } break;
@@ -990,12 +1012,24 @@ void PNS_HORIZON_IFACE::AddItem(PNS::ITEM *aItem)
 
 void PNS_HORIZON_IFACE::Commit()
 {
-    board->expand(true);
+    board->update_junction_connections();
+    for (auto ju : junctions_maybe_erased) {
+        if (!(ju->connected_arcs.size() || ju->connected_lines.size() || ju->connected_vias.size()
+              || ju->connected_tracks.size())) {
+            for (auto &it : ju->connected_connection_lines)
+                board->connection_lines.erase(it);
+            board->junctions.erase(ju->uuid);
+        }
+    }
+    junctions_maybe_erased.clear();
     EraseView();
 }
 
 void PNS_HORIZON_IFACE::UpdateNet(int aNetCode)
 {
+    if (const auto net = get_net_for_code(aNetCode)) {
+        board->update_airwires(false, {net->uuid});
+    }
     wxLogTrace("PNS", "Update-net %d", aNetCode);
 }
 
