@@ -7,6 +7,7 @@
 #include "util/util.hpp"
 #include "logger/logger.hpp"
 #include "util/picture_load.hpp"
+#include "pool/ipool.hpp"
 
 namespace horizon {
 
@@ -46,9 +47,17 @@ json Schematic::Annotation::serialize() const
     return j;
 }
 
-Schematic::Schematic(const UUID &uu, const json &j, Block &iblock, Pool &pool)
+static const unsigned int app_version = 0;
+
+unsigned int Schematic::get_app_version()
+{
+    return app_version;
+}
+
+Schematic::Schematic(const UUID &uu, const json &j, Block &iblock, IPool &pool)
     : uuid(uu), block(&iblock), name(j.at("name").get<std::string>()),
-      group_tag_visible(j.value("group_tag_visible", false)), annotation(j.value("annotation", json()))
+      group_tag_visible(j.value("group_tag_visible", false)), annotation(j.value("annotation", json())),
+      version(app_version, j)
 {
     {
         const json &o = j["sheets"];
@@ -78,13 +87,13 @@ Schematic::Schematic(const UUID &uu, const json &j, Block &iblock, Pool &pool)
     update_refs();
 }
 
-Schematic Schematic::new_from_file(const std::string &filename, Block &block, Pool &pool)
+Schematic Schematic::new_from_file(const std::string &filename, Block &block, IPool &pool)
 {
     auto j = load_json_from_file(filename);
     return Schematic(UUID(j.at("uuid").get<std::string>()), j, block, pool);
 }
 
-Schematic::Schematic(const UUID &uu, Block &bl) : uuid(uu), block(&bl)
+Schematic::Schematic(const UUID &uu, Block &bl) : uuid(uu), block(&bl), version(app_version)
 {
     auto suu = UUID::random();
     sheets.emplace(suu, suu);
@@ -103,7 +112,8 @@ void Schematic::autoconnect_symbol(Sheet *sheet, SchematicSymbol *sym)
         for (auto it_junc = sheet->junctions.begin(); it_junc != sheet->junctions.end();) {
             bool erase = false;
             if (!it_junc->second.bus && it_junc->second.position == pin_pos
-                && (it_junc->second.net || it_junc->second.connection_count > 0)) {
+                && (it_junc->second.net || it_junc->second.connected_net_lines.size()
+                    || it_junc->second.connected_power_symbols.size())) {
                 erase = true;
                 bool net_created = false;
                 if (it_junc->second.net == nullptr) {
@@ -196,14 +206,14 @@ void Schematic::disconnect_symbol(Sheet *sheet, SchematicSymbol *sym)
 {
     assert(sheet == &sheets.at(sheet->uuid));
     assert(sym == &sheet->symbols.at(sym->uuid));
-    std::map<const SymbolPin *, Junction *> pin_junctions;
+    std::map<const SymbolPin *, SchematicJunction *> pin_junctions;
     for (auto &it_line : sheet->net_lines) {
         LineNet *line = &it_line.second;
         // if((line->to_symbol && line->to_symbol->uuid == it.uuid) ||
         // (line->from_symbol &&line->from_symbol->uuid == it.uuid)) {
         for (auto it_ft : {&line->to, &line->from}) {
             if (it_ft->symbol == sym) {
-                Junction *j = nullptr;
+                SchematicJunction *j = nullptr;
                 if (pin_junctions.count(it_ft->pin)) {
                     j = pin_junctions.at(it_ft->pin);
                 }
@@ -557,12 +567,11 @@ void Schematic::expand(bool careful)
         }
 
         sheet.delete_dependants();
-        if (!careful) {
-            sheet.simplify_net_lines(false);
-        }
+        sheet.update_junction_connections();
         sheet.propagate_net_segments();
         if (!careful)
             sheet.vacuum_junctions();
+        sheet.update_junction_connections();
 
         auto net_segments = sheet.analyze_net_segments();
 
@@ -621,24 +630,33 @@ void Schematic::expand(bool careful)
                 const Gate &gate_conn = comp->entity->gates.at(it_conn.first.at(0));
                 const Pin &pin = gate_conn.unit->pins.at(it_conn.first.at(1));
                 if ((gate_conn.uuid == schsym.gate->uuid)) { // connection with net
-                    SymbolPin &sympin = schsym.symbol.pins.at(pin.uuid);
-                    if (it_conn.second.net) {
-                        sympin.connector_style = SymbolPin::ConnectorStyle::NONE;
-                        if (sympin.net_segment) {
-                            auto &ns = net_segments.at(sympin.net_segment);
-                            if (ns.is_bus()) {
-                                throw std::runtime_error("illegal bus-pin connection");
-                            }
-                            if (ns.net == nullptr) {
-                                ns.net = it_conn.second.net;
-                            }
-                            if (ns.net != it_conn.second.net) {
-                                throw std::runtime_error("illegal connection");
+                    if (schsym.symbol.pins.count(pin.uuid)) {
+                        SymbolPin &sympin = schsym.symbol.pins.at(pin.uuid);
+                        if (it_conn.second.net) {
+                            sympin.connector_style = SymbolPin::ConnectorStyle::NONE;
+                            if (sympin.net_segment) {
+                                auto &ns = net_segments.at(sympin.net_segment);
+                                if (ns.is_bus()) {
+                                    throw std::runtime_error("illegal bus-pin connection");
+                                }
+                                if (ns.net == nullptr) {
+                                    ns.net = it_conn.second.net;
+                                }
+                                if (ns.net != it_conn.second.net) {
+                                    throw std::runtime_error("illegal connection");
+                                }
                             }
                         }
+                        else {
+                            sympin.connector_style = SymbolPin::ConnectorStyle::NC;
+                        }
                     }
                     else {
-                        sympin.connector_style = SymbolPin::ConnectorStyle::NC;
+                        Logger::log_critical("Pin " + gate_conn.name + "." + pin.primary_name + " not found on symbol "
+                                                     + schsym.component->refdes + schsym.gate->suffix
+                                                     + " but is connected to net "
+                                                     + block->get_net_name(it_conn.second.net->uuid),
+                                             Logger::Domain::SCHEMATIC);
                     }
                 }
             }
@@ -653,6 +671,7 @@ void Schematic::expand(bool careful)
                 it_junc.second.bus = net_segments.at(it_junc.second.net_segment).bus;
             }
         }
+        sheet.update_junction_connections();
     }
 
 
@@ -660,14 +679,22 @@ void Schematic::expand(bool careful)
         Sheet &sheet = it_sheet.second;
         if (!careful) {
             sheet.fix_junctions();
+            sheet.update_junction_connections();
             sheet.delete_duplicate_net_lines();
-            sheet.simplify_net_lines(true);
+            sheet.update_junction_connections();
+            sheet.simplify_net_lines();
+            sheet.update_junction_connections();
         }
         sheet.propagate_net_segments();
         sheet.analyze_net_segments(true);
     }
     update_refs();
 
+    for (auto &[uu, sheet] : sheets) {
+        sheet.update_bus_ripper_connections();
+    }
+
+
     // warn juncs
     for (auto &it_sheet : sheets) {
         std::set<Coordi> pin_coords;
@@ -796,6 +823,9 @@ void Schematic::expand(bool careful)
                 }
             }
         }
+        else {
+            sheet.frame = Frame(UUID());
+        }
     }
 
     if (!careful) {
@@ -996,7 +1026,8 @@ Glib::RefPtr<Glib::Regex> Schematic::get_sheetref_regex()
 
 Schematic::Schematic(const Schematic &sch)
     : uuid(sch.uuid), block(sch.block), name(sch.name), sheets(sch.sheets), rules(sch.rules),
-      group_tag_visible(sch.group_tag_visible), annotation(sch.annotation), pdf_export_settings(sch.pdf_export_settings)
+      group_tag_visible(sch.group_tag_visible), annotation(sch.annotation),
+      pdf_export_settings(sch.pdf_export_settings), version(sch.version)
 {
     update_refs();
 }
@@ -1058,6 +1089,7 @@ void Schematic::update_refs()
 json Schematic::serialize() const
 {
     json j;
+    version.serialize(j);
     j["type"] = "schematic_block";
     j["uuid"] = (std::string)uuid;
     j["block"] = (std::string)block->uuid;
@@ -1095,4 +1127,18 @@ void Schematic::load_pictures(const std::string &dir)
     pictures_load(pictures, dir, "sch");
 }
 
+ItemSet Schematic::get_pool_items_used() const
+{
+    ItemSet items_needed;
+
+    for (const auto &it_sheet : sheets) {
+        for (const auto &it_sym : it_sheet.second.symbols) {
+            items_needed.emplace(ObjectType::SYMBOL, it_sym.second.pool_symbol->uuid);
+        }
+        if (it_sheet.second.pool_frame)
+            items_needed.emplace(ObjectType::FRAME, it_sheet.second.pool_frame->uuid);
+    }
+    return items_needed;
+}
+
 } // namespace horizon
