@@ -28,12 +28,13 @@ using json = nlohmann::json;
  */
 class Schematic {
 private:
-    Schematic(const UUID &uu, const json &, Block &block, class IPool &pool);
     unsigned int update_nets();
 
 public:
+    Schematic(const UUID &uu, const json &, Block &block, class IPool &pool);
     static Schematic new_from_file(const std::string &filename, Block &block, IPool &pool);
     Schematic(const UUID &uu, Block &block);
+    static unsigned int get_app_version();
 
     /**
      * This is where the magic happens.
@@ -120,5 +121,7 @@ public:
     json serialize() const;
     void save_pictures(const std::string &dir) const;
     void load_pictures(const std::string &dir);
+
+    ItemSet get_pool_items_used() const;
 };
 } // namespace horizon
