@@ -10,6 +10,18 @@ public:
     autofree_ptr(std::function<void(T *)> ffn) : free_fn(ffn)
     {
     }
+
+    autofree_ptr(autofree_ptr &&other)
+    {
+        ptr = other.ptr;
+        free_fn = other.free_fn;
+        other.ptr = nullptr;
+    }
+    autofree_ptr &operator=(autofree_ptr &&) = delete;
+
+    autofree_ptr(autofree_ptr const &) = delete;
+    autofree_ptr &operator=(autofree_ptr const &) = delete;
+
     T *ptr = nullptr;
     std::function<void(T *)> free_fn;
 
@@ -30,7 +42,8 @@ public:
 
     ~autofree_ptr()
     {
-        free_fn(ptr);
+        if (ptr)
+            free_fn(ptr);
     }
 };
 } // namespace horizon
