@@ -15,6 +15,14 @@ json GitHubClient::login(const std::string &user, const std::string &passwd)
     return client.get("/user");
 }
 
+json GitHubClient::login_token(const std::string &token)
+{
+    client.append_header("authorization: Bearer " + token);
+    auto r = client.get("/user");
+    login_user = r.at("login");
+    return r;
+}
+
 json GitHubClient::get_repo(const std::string &owner, const std::string &repo)
 {
     return client.get("/repos/" + owner + "/" + repo);
@@ -42,4 +50,19 @@ json GitHubClient::get_pull_requests(const std::string &owner, const std::string
 {
     return client.get("/repos/" + owner + "/" + repo + "/pulls");
 }
+
+json GitHubClient::get_pull_request(const std::string &owner, const std::string &repo, unsigned int pr)
+{
+    return client.get("/repos/" + owner + "/" + repo + "/pulls/" + std::to_string(pr));
+}
+
+json GitHubClient::add_issue_comment(const std::string &owner, const std::string &repo, unsigned int id,
+                                     const std::string &body)
+{
+    json j;
+    j["body"] = body;
+
+    return client.post("/repos/" + owner + "/" + repo + "/issues/" + std::to_string(id) + "/comments", j);
+}
+
 } // namespace horizon
