@@ -3,7 +3,7 @@
 #include <curl/curl.h>
 #include <string>
 
-namespace HTTP {
+namespace horizon::HTTP {
 class Client {
     friend size_t read_callback(void *ptr, size_t size, size_t nmemb, void *userp);
 
@@ -19,6 +19,7 @@ public:
 
     std::string get(const std::string &url);
     std::string post(const std::string &url, const std::string &postdata = "");
+    std::string post_form(const std::string &url, const std::vector<std::pair<std::string, std::string>> &fields);
 
     ~Client();
 
@@ -50,4 +51,4 @@ public:
 private:
     const std::string base_url;
 };
-} // namespace HTTP
+} // namespace horizon::HTTP
