@@ -4,11 +4,7 @@
 #include "preferences/preferences_provider.hpp"
 #include "util/gtk_util.hpp"
 #include "util/util.hpp"
-#ifdef G_OS_WIN32
-#undef ERROR
-#undef DELETE
-#undef DUPLICATE
-#endif
+#include "util/win32_undef.hpp"
 #include "preferences/preferences.hpp"
 #include <list>
 #include <iomanip>
@@ -47,7 +43,7 @@ public:
         std::unique_lock<std::mutex> lk(mutex);
         std::string q = "{ match(parts: [";
         for (const auto &it : parts) {
-            q += "{mpn: {part: \"" + it.second.first + "\", manufacturer: \"" + it.second.second + "\"}},";
+            q += "{mpn: {part: \"" + it.second.first + "*\", manufacturer: \"" + it.second.second + "\"}},";
         }
         q += ",]) {\
         		datasheet\
@@ -126,7 +122,7 @@ private:
 
 class StockInfoRecordPartinfo : public StockInfoRecord {
 public:
-    const UUID &get_uuid() const
+    const UUID &get_uuid() const override
     {
         return uuid;
     }
@@ -518,7 +514,7 @@ void StockInfoProviderPartinfo::add_columns(Gtk::TreeView *treeview,
         auto mcr = dynamic_cast<Gtk::CellRendererText *>(tcr);
         auto v = row.get_value(column);
         if (v == nullptr) {
-            mcr->property_text() = "Loading...";
+            mcr->property_text() = "Loading…";
         }
         else {
             if (auto p = dynamic_cast<const StockInfoRecordPartinfo *>(v.get())) {
