@@ -8,8 +8,8 @@ namespace horizon {
 
 class PoolBrowserButton : public Gtk::Button {
 public:
-    PoolBrowserButton(ObjectType type, Pool *ipool);
-    class PoolBrowser *get_browser();
+    PoolBrowserButton(ObjectType type, IPool &ipool);
+    class PoolBrowser &get_browser();
     Glib::PropertyProxy<horizon::UUID> property_selected_uuid()
     {
         return p_property_selected_uuid.get_proxy();
@@ -17,7 +17,7 @@ public:
 
 private:
     Glib::Property<UUID> p_property_selected_uuid;
-    Pool *pool;
+    IPool &pool;
     ObjectType type;
     UUID selected_uuid;
     PoolBrowserDialog dia;
