@@ -1,8 +1,10 @@
 #include "preview_canvas.hpp"
-#include "pool/pool.hpp"
+#include "pool/ipool.hpp"
 #include "pool/symbol.hpp"
 #include "pool/package.hpp"
 #include "pool/part.hpp"
+#include "frame/frame.hpp"
+#include "pool/decal.hpp"
 #include "board/board_layers.hpp"
 #include "preferences/preferences_util.hpp"
 #include "canvas/canvas_gl.hpp"
@@ -60,7 +62,7 @@ private:
     float m_length = 1e6;
 };
 
-PreviewCanvas::PreviewCanvas(Pool &p, bool layered) : Glib::ObjectBase(typeid(PreviewCanvas)), pool(p)
+PreviewCanvas::PreviewCanvas(IPool &p, bool layered) : Glib::ObjectBase(typeid(PreviewCanvas)), pool(p)
 {
     canvas = Gtk::manage(new CanvasGL());
     if (layered)
@@ -223,6 +225,18 @@ void PreviewCanvas::load(ObjectType type, const UUID &uu, const Placement &pl, b
         canvas->update(fr, false);
         pad = 1_mm;
     } break;
+
+    case ObjectType::DECAL: {
+        const Decal &dec = *pool.get_decal(uu);
+        canvas->property_layer_opacity() = 75;
+        for (const auto &la : dec.get_layers()) {
+            auto ld = LayerDisplay::Mode::FILL_ONLY;
+            if (la.second.copper || la.first == BoardLayers::TOP_SILKSCREEN)
+                canvas->set_layer_display(la.first, LayerDisplay(true, ld));
+        }
+        canvas->update(dec, false);
+        pad = 1_mm;
+    } break;
     default:;
     }
     if (!fit) {
