@@ -1,5 +1,6 @@
 #include "spin_button_angle.hpp"
 #include "util/util.hpp"
+#include "util/gtk_util.hpp"
 #include <iomanip>
 
 namespace horizon {
@@ -16,11 +17,7 @@ SpinButtonAngle::SpinButtonAngle() : Gtk::SpinButton()
     // temporarily allowing smaller/larger values and then readjusting them.
     set_range(-page, 65536 + page);
 
-    auto attributes_list = pango_attr_list_new();
-    auto attribute_font_features = pango_attr_font_features_new("tnum 1");
-    pango_attr_list_insert(attributes_list, attribute_font_features);
-    gtk_entry_set_attributes(GTK_ENTRY(gobj()), attributes_list);
-    pango_attr_list_unref(attributes_list);
+    entry_set_tnum(*this);
 }
 
 bool SpinButtonAngle::on_output()
