@@ -1,6 +1,6 @@
 major = 1
-minor = 3
+minor = 4
 micro = 0
-name = "Daedalus"
+name = "Étoile"
 
 string = ".".join(str(x) for x in (major, minor, micro))
